/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Intrinsic Function Source Fragment                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_IR_INTRINSIC_AARCH64_ENUMS_H
#define LLVM_IR_INTRINSIC_AARCH64_ENUMS_H
namespace llvm::Intrinsic {
enum AARCH64Intrinsics : unsigned {
// Enum values for intrinsics.
    aarch64_addg = 521,                              // llvm.aarch64.addg (IntrinsicsAArch64.td:897)
    aarch64_break,                             // llvm.aarch64.break (IntrinsicsAArch64.td:66)
    aarch64_chkfeat,                           // llvm.aarch64.chkfeat (IntrinsicsAArch64.td:104)
    aarch64_clrex,                             // llvm.aarch64.clrex (IntrinsicsAArch64.td:35)
    aarch64_cls,                               // llvm.aarch64.cls (IntrinsicsAArch64.td:44)
    aarch64_cls64,                             // llvm.aarch64.cls64 (IntrinsicsAArch64.td:45)
    aarch64_crc32b,                            // llvm.aarch64.crc32b (IntrinsicsAArch64.td:874)
    aarch64_crc32cb,                           // llvm.aarch64.crc32cb (IntrinsicsAArch64.td:876)
    aarch64_crc32ch,                           // llvm.aarch64.crc32ch (IntrinsicsAArch64.td:880)
    aarch64_crc32cw,                           // llvm.aarch64.crc32cw (IntrinsicsAArch64.td:884)
    aarch64_crc32cx,                           // llvm.aarch64.crc32cx (IntrinsicsAArch64.td:888)
    aarch64_crc32h,                            // llvm.aarch64.crc32h (IntrinsicsAArch64.td:878)
    aarch64_crc32w,                            // llvm.aarch64.crc32w (IntrinsicsAArch64.td:882)
    aarch64_crc32x,                            // llvm.aarch64.crc32x (IntrinsicsAArch64.td:886)
    aarch64_crypto_aesd,                       // llvm.aarch64.crypto.aesd (IntrinsicsAArch64.td:825)
    aarch64_crypto_aese,                       // llvm.aarch64.crypto.aese (IntrinsicsAArch64.td:824)
    aarch64_crypto_aesimc,                     // llvm.aarch64.crypto.aesimc (IntrinsicsAArch64.td:827)
    aarch64_crypto_aesmc,                      // llvm.aarch64.crypto.aesmc (IntrinsicsAArch64.td:826)
    aarch64_crypto_bcaxs,                      // llvm.aarch64.crypto.bcaxs (IntrinsicsAArch64.td:847)
    aarch64_crypto_bcaxu,                      // llvm.aarch64.crypto.bcaxu (IntrinsicsAArch64.td:848)
    aarch64_crypto_eor3s,                      // llvm.aarch64.crypto.eor3s (IntrinsicsAArch64.td:845)
    aarch64_crypto_eor3u,                      // llvm.aarch64.crypto.eor3u (IntrinsicsAArch64.td:846)
    aarch64_crypto_rax1,                       // llvm.aarch64.crypto.rax1 (IntrinsicsAArch64.td:849)
    aarch64_crypto_sha1c,                      // llvm.aarch64.crypto.sha1c (IntrinsicsAArch64.td:830)
    aarch64_crypto_sha1h,                      // llvm.aarch64.crypto.sha1h (IntrinsicsAArch64.td:833)
    aarch64_crypto_sha1m,                      // llvm.aarch64.crypto.sha1m (IntrinsicsAArch64.td:832)
    aarch64_crypto_sha1p,                      // llvm.aarch64.crypto.sha1p (IntrinsicsAArch64.td:831)
    aarch64_crypto_sha1su0,                    // llvm.aarch64.crypto.sha1su0 (IntrinsicsAArch64.td:835)
    aarch64_crypto_sha1su1,                    // llvm.aarch64.crypto.sha1su1 (IntrinsicsAArch64.td:836)
    aarch64_crypto_sha256h,                    // llvm.aarch64.crypto.sha256h (IntrinsicsAArch64.td:839)
    aarch64_crypto_sha256h2,                   // llvm.aarch64.crypto.sha256h2 (IntrinsicsAArch64.td:840)
    aarch64_crypto_sha256su0,                  // llvm.aarch64.crypto.sha256su0 (IntrinsicsAArch64.td:841)
    aarch64_crypto_sha256su1,                  // llvm.aarch64.crypto.sha256su1 (IntrinsicsAArch64.td:842)
    aarch64_crypto_sha512h,                    // llvm.aarch64.crypto.sha512h (IntrinsicsAArch64.td:853)
    aarch64_crypto_sha512h2,                   // llvm.aarch64.crypto.sha512h2 (IntrinsicsAArch64.td:854)
    aarch64_crypto_sha512su0,                  // llvm.aarch64.crypto.sha512su0 (IntrinsicsAArch64.td:855)
    aarch64_crypto_sha512su1,                  // llvm.aarch64.crypto.sha512su1 (IntrinsicsAArch64.td:856)
    aarch64_crypto_sm3partw1,                  // llvm.aarch64.crypto.sm3partw1 (IntrinsicsAArch64.td:859)
    aarch64_crypto_sm3partw2,                  // llvm.aarch64.crypto.sm3partw2 (IntrinsicsAArch64.td:860)
    aarch64_crypto_sm3ss1,                     // llvm.aarch64.crypto.sm3ss1 (IntrinsicsAArch64.td:861)
    aarch64_crypto_sm3tt1a,                    // llvm.aarch64.crypto.sm3tt1a (IntrinsicsAArch64.td:862)
    aarch64_crypto_sm3tt1b,                    // llvm.aarch64.crypto.sm3tt1b (IntrinsicsAArch64.td:863)
    aarch64_crypto_sm3tt2a,                    // llvm.aarch64.crypto.sm3tt2a (IntrinsicsAArch64.td:864)
    aarch64_crypto_sm3tt2b,                    // llvm.aarch64.crypto.sm3tt2b (IntrinsicsAArch64.td:865)
    aarch64_crypto_sm4e,                       // llvm.aarch64.crypto.sm4e (IntrinsicsAArch64.td:866)
    aarch64_crypto_sm4ekey,                    // llvm.aarch64.crypto.sm4ekey (IntrinsicsAArch64.td:867)
    aarch64_crypto_xar,                        // llvm.aarch64.crypto.xar (IntrinsicsAArch64.td:850)
    aarch64_dmb,                               // llvm.aarch64.dmb (IntrinsicsAArch64.td:88)
    aarch64_dsb,                               // llvm.aarch64.dsb (IntrinsicsAArch64.td:90)
    aarch64_fjcvtzs,                           // llvm.aarch64.fjcvtzs (IntrinsicsAArch64.td:42)
    aarch64_frint32x,                          // llvm.aarch64.frint32x (IntrinsicsAArch64.td:53)
    aarch64_frint32z,                          // llvm.aarch64.frint32z (IntrinsicsAArch64.td:47)
    aarch64_frint64x,                          // llvm.aarch64.frint64x (IntrinsicsAArch64.td:56)
    aarch64_frint64z,                          // llvm.aarch64.frint64z (IntrinsicsAArch64.td:50)
    aarch64_gcspopm,                           // llvm.aarch64.gcspopm (IntrinsicsAArch64.td:111)
    aarch64_gcsss,                             // llvm.aarch64.gcsss (IntrinsicsAArch64.td:115)
    aarch64_get_fpcr,                          // llvm.aarch64.get.fpcr (IntrinsicsAArch64.td:744)
    aarch64_get_fpsr,                          // llvm.aarch64.get.fpsr (IntrinsicsAArch64.td:746)
    aarch64_gmi,                               // llvm.aarch64.gmi (IntrinsicsAArch64.td:899)
    aarch64_hint,                              // llvm.aarch64.hint (IntrinsicsAArch64.td:64)
    aarch64_hlt,                               // llvm.aarch64.hlt (IntrinsicsAArch64.td:69)
    aarch64_irg,                               // llvm.aarch64.irg (IntrinsicsAArch64.td:895)
    aarch64_irg_sp,                            // llvm.aarch64.irg.sp (IntrinsicsAArch64.td:911)
    aarch64_isb,                               // llvm.aarch64.isb (IntrinsicsAArch64.td:92)
    aarch64_ld64b,                             // llvm.aarch64.ld64b (IntrinsicsAArch64.td:954)
    aarch64_ldaxp,                             // llvm.aarch64.ldaxp (IntrinsicsAArch64.td:26)
    aarch64_ldaxr,                             // llvm.aarch64.ldaxr (IntrinsicsAArch64.td:17)
    aarch64_ldg,                               // llvm.aarch64.ldg (IntrinsicsAArch64.td:901)
    aarch64_ldxp,                              // llvm.aarch64.ldxp (IntrinsicsAArch64.td:24)
    aarch64_ldxr,                              // llvm.aarch64.ldxr (IntrinsicsAArch64.td:15)
    aarch64_mops_memset_tag,                   // llvm.aarch64.mops.memset.tag (IntrinsicsAArch64.td:947)
    aarch64_neon_abs,                          // llvm.aarch64.neon.abs (IntrinsicsAArch64.td:441)
    aarch64_neon_addhn,                        // llvm.aarch64.neon.addhn (IntrinsicsAArch64.td:256)
    aarch64_neon_addp,                         // llvm.aarch64.neon.addp (IntrinsicsAArch64.td:356)
    aarch64_neon_bfdot,                        // llvm.aarch64.neon.bfdot (IntrinsicsAArch64.td:509)
    aarch64_neon_bfmlalb,                      // llvm.aarch64.neon.bfmlalb (IntrinsicsAArch64.td:514)
    aarch64_neon_bfmlalt,                      // llvm.aarch64.neon.bfmlalt (IntrinsicsAArch64.td:515)
    aarch64_neon_bfmmla,                       // llvm.aarch64.neon.bfmmla (IntrinsicsAArch64.td:510)
    aarch64_neon_cls,                          // llvm.aarch64.neon.cls (IntrinsicsAArch64.td:450)
    aarch64_neon_fabd,                         // llvm.aarch64.neon.fabd (IntrinsicsAArch64.td:322)
    aarch64_neon_facge,                        // llvm.aarch64.neon.facge (IntrinsicsAArch64.td:314)
    aarch64_neon_facgt,                        // llvm.aarch64.neon.facgt (IntrinsicsAArch64.td:317)
    aarch64_neon_faddp,                        // llvm.aarch64.neon.faddp (IntrinsicsAArch64.td:357)
    aarch64_neon_faddv,                        // llvm.aarch64.neon.faddv (IntrinsicsAArch64.td:233)
    aarch64_neon_famax,                        // llvm.aarch64.neon.famax (IntrinsicsAArch64.td:4042)
    aarch64_neon_famin,                        // llvm.aarch64.neon.famin (IntrinsicsAArch64.td:4043)
    aarch64_neon_fcvtas,                       // llvm.aarch64.neon.fcvtas (IntrinsicsAArch64.td:473)
    aarch64_neon_fcvtau,                       // llvm.aarch64.neon.fcvtau (IntrinsicsAArch64.td:474)
    aarch64_neon_fcvtms,                       // llvm.aarch64.neon.fcvtms (IntrinsicsAArch64.td:475)
    aarch64_neon_fcvtmu,                       // llvm.aarch64.neon.fcvtmu (IntrinsicsAArch64.td:476)
    aarch64_neon_fcvtns,                       // llvm.aarch64.neon.fcvtns (IntrinsicsAArch64.td:477)
    aarch64_neon_fcvtnu,                       // llvm.aarch64.neon.fcvtnu (IntrinsicsAArch64.td:478)
    aarch64_neon_fcvtps,                       // llvm.aarch64.neon.fcvtps (IntrinsicsAArch64.td:479)
    aarch64_neon_fcvtpu,                       // llvm.aarch64.neon.fcvtpu (IntrinsicsAArch64.td:480)
    aarch64_neon_fcvtxn,                       // llvm.aarch64.neon.fcvtxn (IntrinsicsAArch64.td:493)
    aarch64_neon_fcvtzs,                       // llvm.aarch64.neon.fcvtzs (IntrinsicsAArch64.td:481)
    aarch64_neon_fcvtzu,                       // llvm.aarch64.neon.fcvtzu (IntrinsicsAArch64.td:482)
    aarch64_neon_fmax,                         // llvm.aarch64.neon.fmax (IntrinsicsAArch64.td:330)
    aarch64_neon_fmaxnm,                       // llvm.aarch64.neon.fmaxnm (IntrinsicsAArch64.td:347)
    aarch64_neon_fmaxnmp,                      // llvm.aarch64.neon.fmaxnmp (IntrinsicsAArch64.td:331)
    aarch64_neon_fmaxnmv,                      // llvm.aarch64.neon.fmaxnmv (IntrinsicsAArch64.td:337)
    aarch64_neon_fmaxp,                        // llvm.aarch64.neon.fmaxp (IntrinsicsAArch64.td:369)
    aarch64_neon_fmaxv,                        // llvm.aarch64.neon.fmaxv (IntrinsicsAArch64.td:336)
    aarch64_neon_fmin,                         // llvm.aarch64.neon.fmin (IntrinsicsAArch64.td:342)
    aarch64_neon_fminnm,                       // llvm.aarch64.neon.fminnm (IntrinsicsAArch64.td:346)
    aarch64_neon_fminnmp,                      // llvm.aarch64.neon.fminnmp (IntrinsicsAArch64.td:343)
    aarch64_neon_fminnmv,                      // llvm.aarch64.neon.fminnmv (IntrinsicsAArch64.td:353)
    aarch64_neon_fminp,                        // llvm.aarch64.neon.fminp (IntrinsicsAArch64.td:374)
    aarch64_neon_fminv,                        // llvm.aarch64.neon.fminv (IntrinsicsAArch64.td:352)
    aarch64_neon_fmlal,                        // llvm.aarch64.neon.fmlal (IntrinsicsAArch64.td:518)
    aarch64_neon_fmlal2,                       // llvm.aarch64.neon.fmlal2 (IntrinsicsAArch64.td:520)
    aarch64_neon_fmlsl,                        // llvm.aarch64.neon.fmlsl (IntrinsicsAArch64.td:519)
    aarch64_neon_fmlsl2,                       // llvm.aarch64.neon.fmlsl2 (IntrinsicsAArch64.td:521)
    aarch64_neon_fmmla,                        // llvm.aarch64.neon.fmmla (IntrinsicsAArch64.td:507)
    aarch64_neon_fmulx,                        // llvm.aarch64.neon.fmulx (IntrinsicsAArch64.td:289)
    aarch64_neon_fp8_cvtl1,                    // llvm.aarch64.neon.fp8.cvtl1 (IntrinsicsAArch64.td:967)
    aarch64_neon_fp8_cvtl2,                    // llvm.aarch64.neon.fp8.cvtl2 (IntrinsicsAArch64.td:968)
    aarch64_neon_fp8_fcvtn,                    // llvm.aarch64.neon.fp8.fcvtn (IntrinsicsAArch64.td:970)
    aarch64_neon_fp8_fcvtn2,                   // llvm.aarch64.neon.fp8.fcvtn2 (IntrinsicsAArch64.td:975)
    aarch64_neon_fp8_fdot2,                    // llvm.aarch64.neon.fp8.fdot2 (IntrinsicsAArch64.td:997)
    aarch64_neon_fp8_fdot2_lane,               // llvm.aarch64.neon.fp8.fdot2.lane (IntrinsicsAArch64.td:998)
    aarch64_neon_fp8_fdot4,                    // llvm.aarch64.neon.fp8.fdot4 (IntrinsicsAArch64.td:1000)
    aarch64_neon_fp8_fdot4_lane,               // llvm.aarch64.neon.fp8.fdot4.lane (IntrinsicsAArch64.td:1001)
    aarch64_neon_fp8_fmlalb,                   // llvm.aarch64.neon.fp8.fmlalb (IntrinsicsAArch64.td:1020)
    aarch64_neon_fp8_fmlalb_lane,              // llvm.aarch64.neon.fp8.fmlalb.lane (IntrinsicsAArch64.td:1028)
    aarch64_neon_fp8_fmlallbb,                 // llvm.aarch64.neon.fp8.fmlallbb (IntrinsicsAArch64.td:1023)
    aarch64_neon_fp8_fmlallbb_lane,            // llvm.aarch64.neon.fp8.fmlallbb.lane (IntrinsicsAArch64.td:1031)
    aarch64_neon_fp8_fmlallbt,                 // llvm.aarch64.neon.fp8.fmlallbt (IntrinsicsAArch64.td:1024)
    aarch64_neon_fp8_fmlallbt_lane,            // llvm.aarch64.neon.fp8.fmlallbt.lane (IntrinsicsAArch64.td:1032)
    aarch64_neon_fp8_fmlalltb,                 // llvm.aarch64.neon.fp8.fmlalltb (IntrinsicsAArch64.td:1025)
    aarch64_neon_fp8_fmlalltb_lane,            // llvm.aarch64.neon.fp8.fmlalltb.lane (IntrinsicsAArch64.td:1033)
    aarch64_neon_fp8_fmlalltt,                 // llvm.aarch64.neon.fp8.fmlalltt (IntrinsicsAArch64.td:1026)
    aarch64_neon_fp8_fmlalltt_lane,            // llvm.aarch64.neon.fp8.fmlalltt.lane (IntrinsicsAArch64.td:1034)
    aarch64_neon_fp8_fmlalt,                   // llvm.aarch64.neon.fp8.fmlalt (IntrinsicsAArch64.td:1021)
    aarch64_neon_fp8_fmlalt_lane,              // llvm.aarch64.neon.fp8.fmlalt.lane (IntrinsicsAArch64.td:1029)
    aarch64_neon_fp8_fscale,                   // llvm.aarch64.neon.fp8.fscale (IntrinsicsAArch64.td:533)
    aarch64_neon_frecpe,                       // llvm.aarch64.neon.frecpe (IntrinsicsAArch64.td:454)
    aarch64_neon_frecps,                       // llvm.aarch64.neon.frecps (IntrinsicsAArch64.td:377)
    aarch64_neon_frecpx,                       // llvm.aarch64.neon.frecpx (IntrinsicsAArch64.td:381)
    aarch64_neon_frint32x,                     // llvm.aarch64.neon.frint32x (IntrinsicsAArch64.td:485)
    aarch64_neon_frint32z,                     // llvm.aarch64.neon.frint32z (IntrinsicsAArch64.td:486)
    aarch64_neon_frint64x,                     // llvm.aarch64.neon.frint64x (IntrinsicsAArch64.td:487)
    aarch64_neon_frint64z,                     // llvm.aarch64.neon.frint64z (IntrinsicsAArch64.td:488)
    aarch64_neon_frsqrte,                      // llvm.aarch64.neon.frsqrte (IntrinsicsAArch64.td:458)
    aarch64_neon_frsqrts,                      // llvm.aarch64.neon.frsqrts (IntrinsicsAArch64.td:378)
    aarch64_neon_ld1x2,                        // llvm.aarch64.neon.ld1x2 (IntrinsicsAArch64.td:656)
    aarch64_neon_ld1x3,                        // llvm.aarch64.neon.ld1x3 (IntrinsicsAArch64.td:657)
    aarch64_neon_ld1x4,                        // llvm.aarch64.neon.ld1x4 (IntrinsicsAArch64.td:658)
    aarch64_neon_ld2,                          // llvm.aarch64.neon.ld2 (IntrinsicsAArch64.td:664)
    aarch64_neon_ld2lane,                      // llvm.aarch64.neon.ld2lane (IntrinsicsAArch64.td:668)
    aarch64_neon_ld2r,                         // llvm.aarch64.neon.ld2r (IntrinsicsAArch64.td:672)
    aarch64_neon_ld3,                          // llvm.aarch64.neon.ld3 (IntrinsicsAArch64.td:665)
    aarch64_neon_ld3lane,                      // llvm.aarch64.neon.ld3lane (IntrinsicsAArch64.td:669)
    aarch64_neon_ld3r,                         // llvm.aarch64.neon.ld3r (IntrinsicsAArch64.td:673)
    aarch64_neon_ld4,                          // llvm.aarch64.neon.ld4 (IntrinsicsAArch64.td:666)
    aarch64_neon_ld4lane,                      // llvm.aarch64.neon.ld4lane (IntrinsicsAArch64.td:670)
    aarch64_neon_ld4r,                         // llvm.aarch64.neon.ld4r (IntrinsicsAArch64.td:674)
    aarch64_neon_pmul,                         // llvm.aarch64.neon.pmul (IntrinsicsAArch64.td:276)
    aarch64_neon_pmull,                        // llvm.aarch64.neon.pmull (IntrinsicsAArch64.td:281)
    aarch64_neon_pmull64,                      // llvm.aarch64.neon.pmull64 (IntrinsicsAArch64.td:285)
    aarch64_neon_raddhn,                       // llvm.aarch64.neon.raddhn (IntrinsicsAArch64.td:259)
    aarch64_neon_rshrn,                        // llvm.aarch64.neon.rshrn (IntrinsicsAArch64.td:409)
    aarch64_neon_rsubhn,                       // llvm.aarch64.neon.rsubhn (IntrinsicsAArch64.td:311)
    aarch64_neon_sabd,                         // llvm.aarch64.neon.sabd (IntrinsicsAArch64.td:320)
    aarch64_neon_saddlp,                       // llvm.aarch64.neon.saddlp (IntrinsicsAArch64.td:363)
    aarch64_neon_saddlv,                       // llvm.aarch64.neon.saddlv (IntrinsicsAArch64.td:236)
    aarch64_neon_saddv,                        // llvm.aarch64.neon.saddv (IntrinsicsAArch64.td:231)
    aarch64_neon_scalar_sqxtn,                 // llvm.aarch64.neon.scalar.sqxtn (IntrinsicsAArch64.td:431)
    aarch64_neon_scalar_sqxtun,                // llvm.aarch64.neon.scalar.sqxtun (IntrinsicsAArch64.td:437)
    aarch64_neon_scalar_uqxtn,                 // llvm.aarch64.neon.scalar.uqxtn (IntrinsicsAArch64.td:432)
    aarch64_neon_sdot,                         // llvm.aarch64.neon.sdot (IntrinsicsAArch64.td:501)
    aarch64_neon_shadd,                        // llvm.aarch64.neon.shadd (IntrinsicsAArch64.td:240)
    aarch64_neon_shll,                         // llvm.aarch64.neon.shll (IntrinsicsAArch64.td:420)
    aarch64_neon_shsub,                        // llvm.aarch64.neon.shsub (IntrinsicsAArch64.td:298)
    aarch64_neon_smax,                         // llvm.aarch64.neon.smax (IntrinsicsAArch64.td:328)
    aarch64_neon_smaxp,                        // llvm.aarch64.neon.smaxp (IntrinsicsAArch64.td:367)
    aarch64_neon_smaxv,                        // llvm.aarch64.neon.smaxv (IntrinsicsAArch64.td:334)
    aarch64_neon_smin,                         // llvm.aarch64.neon.smin (IntrinsicsAArch64.td:340)
    aarch64_neon_sminp,                        // llvm.aarch64.neon.sminp (IntrinsicsAArch64.td:372)
    aarch64_neon_sminv,                        // llvm.aarch64.neon.sminv (IntrinsicsAArch64.td:350)
    aarch64_neon_smmla,                        // llvm.aarch64.neon.smmla (IntrinsicsAArch64.td:505)
    aarch64_neon_smull,                        // llvm.aarch64.neon.smull (IntrinsicsAArch64.td:279)
    aarch64_neon_sqabs,                        // llvm.aarch64.neon.sqabs (IntrinsicsAArch64.td:444)
    aarch64_neon_sqadd,                        // llvm.aarch64.neon.sqadd (IntrinsicsAArch64.td:248)
    aarch64_neon_sqdmulh,                      // llvm.aarch64.neon.sqdmulh (IntrinsicsAArch64.td:262)
    aarch64_neon_sqdmulh_lane,                 // llvm.aarch64.neon.sqdmulh.lane (IntrinsicsAArch64.td:263)
    aarch64_neon_sqdmulh_laneq,                // llvm.aarch64.neon.sqdmulh.laneq (IntrinsicsAArch64.td:264)
    aarch64_neon_sqdmull,                      // llvm.aarch64.neon.sqdmull (IntrinsicsAArch64.td:293)
    aarch64_neon_sqdmulls_scalar,              // llvm.aarch64.neon.sqdmulls.scalar (IntrinsicsAArch64.td:294)
    aarch64_neon_sqneg,                        // llvm.aarch64.neon.sqneg (IntrinsicsAArch64.td:447)
    aarch64_neon_sqrdmlah,                     // llvm.aarch64.neon.sqrdmlah (IntrinsicsAArch64.td:271)
    aarch64_neon_sqrdmlsh,                     // llvm.aarch64.neon.sqrdmlsh (IntrinsicsAArch64.td:272)
    aarch64_neon_sqrdmulh,                     // llvm.aarch64.neon.sqrdmulh (IntrinsicsAArch64.td:267)
    aarch64_neon_sqrdmulh_lane,                // llvm.aarch64.neon.sqrdmulh.lane (IntrinsicsAArch64.td:268)
    aarch64_neon_sqrdmulh_laneq,               // llvm.aarch64.neon.sqrdmulh.laneq (IntrinsicsAArch64.td:269)
    aarch64_neon_sqrshl,                       // llvm.aarch64.neon.sqrshl (IntrinsicsAArch64.td:392)
    aarch64_neon_sqrshrn,                      // llvm.aarch64.neon.sqrshrn (IntrinsicsAArch64.td:412)
    aarch64_neon_sqrshrun,                     // llvm.aarch64.neon.sqrshrun (IntrinsicsAArch64.td:402)
    aarch64_neon_sqshl,                        // llvm.aarch64.neon.sqshl (IntrinsicsAArch64.td:384)
    aarch64_neon_sqshlu,                       // llvm.aarch64.neon.sqshlu (IntrinsicsAArch64.td:396)
    aarch64_neon_sqshrn,                       // llvm.aarch64.neon.sqshrn (IntrinsicsAArch64.td:405)
    aarch64_neon_sqshrun,                      // llvm.aarch64.neon.sqshrun (IntrinsicsAArch64.td:399)
    aarch64_neon_sqsub,                        // llvm.aarch64.neon.sqsub (IntrinsicsAArch64.td:302)
    aarch64_neon_sqxtn,                        // llvm.aarch64.neon.sqxtn (IntrinsicsAArch64.td:433)
    aarch64_neon_sqxtun,                       // llvm.aarch64.neon.sqxtun (IntrinsicsAArch64.td:438)
    aarch64_neon_srhadd,                       // llvm.aarch64.neon.srhadd (IntrinsicsAArch64.td:244)
    aarch64_neon_srshl,                        // llvm.aarch64.neon.srshl (IntrinsicsAArch64.td:388)
    aarch64_neon_sshl,                         // llvm.aarch64.neon.sshl (IntrinsicsAArch64.td:416)
    aarch64_neon_sshll,                        // llvm.aarch64.neon.sshll (IntrinsicsAArch64.td:421)
    aarch64_neon_st1x2,                        // llvm.aarch64.neon.st1x2 (IntrinsicsAArch64.td:660)
    aarch64_neon_st1x3,                        // llvm.aarch64.neon.st1x3 (IntrinsicsAArch64.td:661)
    aarch64_neon_st1x4,                        // llvm.aarch64.neon.st1x4 (IntrinsicsAArch64.td:662)
    aarch64_neon_st2,                          // llvm.aarch64.neon.st2 (IntrinsicsAArch64.td:676)
    aarch64_neon_st2lane,                      // llvm.aarch64.neon.st2lane (IntrinsicsAArch64.td:680)
    aarch64_neon_st3,                          // llvm.aarch64.neon.st3 (IntrinsicsAArch64.td:677)
    aarch64_neon_st3lane,                      // llvm.aarch64.neon.st3lane (IntrinsicsAArch64.td:681)
    aarch64_neon_st4,                          // llvm.aarch64.neon.st4 (IntrinsicsAArch64.td:678)
    aarch64_neon_st4lane,                      // llvm.aarch64.neon.st4lane (IntrinsicsAArch64.td:682)
    aarch64_neon_subhn,                        // llvm.aarch64.neon.subhn (IntrinsicsAArch64.td:308)
    aarch64_neon_suqadd,                       // llvm.aarch64.neon.suqadd (IntrinsicsAArch64.td:249)
    aarch64_neon_tbl1,                         // llvm.aarch64.neon.tbl1 (IntrinsicsAArch64.td:722)
    aarch64_neon_tbl2,                         // llvm.aarch64.neon.tbl2 (IntrinsicsAArch64.td:723)
    aarch64_neon_tbl3,                         // llvm.aarch64.neon.tbl3 (IntrinsicsAArch64.td:724)
    aarch64_neon_tbl4,                         // llvm.aarch64.neon.tbl4 (IntrinsicsAArch64.td:725)
    aarch64_neon_tbx1,                         // llvm.aarch64.neon.tbx1 (IntrinsicsAArch64.td:727)
    aarch64_neon_tbx2,                         // llvm.aarch64.neon.tbx2 (IntrinsicsAArch64.td:728)
    aarch64_neon_tbx3,                         // llvm.aarch64.neon.tbx3 (IntrinsicsAArch64.td:729)
    aarch64_neon_tbx4,                         // llvm.aarch64.neon.tbx4 (IntrinsicsAArch64.td:730)
    aarch64_neon_uabd,                         // llvm.aarch64.neon.uabd (IntrinsicsAArch64.td:321)
    aarch64_neon_uaddlp,                       // llvm.aarch64.neon.uaddlp (IntrinsicsAArch64.td:364)
    aarch64_neon_uaddlv,                       // llvm.aarch64.neon.uaddlv (IntrinsicsAArch64.td:237)
    aarch64_neon_uaddv,                        // llvm.aarch64.neon.uaddv (IntrinsicsAArch64.td:232)
    aarch64_neon_udot,                         // llvm.aarch64.neon.udot (IntrinsicsAArch64.td:500)
    aarch64_neon_uhadd,                        // llvm.aarch64.neon.uhadd (IntrinsicsAArch64.td:241)
    aarch64_neon_uhsub,                        // llvm.aarch64.neon.uhsub (IntrinsicsAArch64.td:299)
    aarch64_neon_umax,                         // llvm.aarch64.neon.umax (IntrinsicsAArch64.td:329)
    aarch64_neon_umaxp,                        // llvm.aarch64.neon.umaxp (IntrinsicsAArch64.td:368)
    aarch64_neon_umaxv,                        // llvm.aarch64.neon.umaxv (IntrinsicsAArch64.td:335)
    aarch64_neon_umin,                         // llvm.aarch64.neon.umin (IntrinsicsAArch64.td:341)
    aarch64_neon_uminp,                        // llvm.aarch64.neon.uminp (IntrinsicsAArch64.td:373)
    aarch64_neon_uminv,                        // llvm.aarch64.neon.uminv (IntrinsicsAArch64.td:351)
    aarch64_neon_ummla,                        // llvm.aarch64.neon.ummla (IntrinsicsAArch64.td:504)
    aarch64_neon_umull,                        // llvm.aarch64.neon.umull (IntrinsicsAArch64.td:280)
    aarch64_neon_uqadd,                        // llvm.aarch64.neon.uqadd (IntrinsicsAArch64.td:251)
    aarch64_neon_uqrshl,                       // llvm.aarch64.neon.uqrshl (IntrinsicsAArch64.td:393)
    aarch64_neon_uqrshrn,                      // llvm.aarch64.neon.uqrshrn (IntrinsicsAArch64.td:413)
    aarch64_neon_uqshl,                        // llvm.aarch64.neon.uqshl (IntrinsicsAArch64.td:385)
    aarch64_neon_uqshrn,                       // llvm.aarch64.neon.uqshrn (IntrinsicsAArch64.td:406)
    aarch64_neon_uqsub,                        // llvm.aarch64.neon.uqsub (IntrinsicsAArch64.td:303)
    aarch64_neon_uqxtn,                        // llvm.aarch64.neon.uqxtn (IntrinsicsAArch64.td:434)
    aarch64_neon_urecpe,                       // llvm.aarch64.neon.urecpe (IntrinsicsAArch64.td:453)
    aarch64_neon_urhadd,                       // llvm.aarch64.neon.urhadd (IntrinsicsAArch64.td:245)
    aarch64_neon_urshl,                        // llvm.aarch64.neon.urshl (IntrinsicsAArch64.td:389)
    aarch64_neon_ursqrte,                      // llvm.aarch64.neon.ursqrte (IntrinsicsAArch64.td:457)
    aarch64_neon_usdot,                        // llvm.aarch64.neon.usdot (IntrinsicsAArch64.td:508)
    aarch64_neon_ushl,                         // llvm.aarch64.neon.ushl (IntrinsicsAArch64.td:417)
    aarch64_neon_ushll,                        // llvm.aarch64.neon.ushll (IntrinsicsAArch64.td:422)
    aarch64_neon_usmmla,                       // llvm.aarch64.neon.usmmla (IntrinsicsAArch64.td:506)
    aarch64_neon_usqadd,                       // llvm.aarch64.neon.usqadd (IntrinsicsAArch64.td:250)
    aarch64_neon_vcadd_rot270,                 // llvm.aarch64.neon.vcadd.rot270 (IntrinsicsAArch64.td:525)
    aarch64_neon_vcadd_rot90,                  // llvm.aarch64.neon.vcadd.rot90 (IntrinsicsAArch64.td:524)
    aarch64_neon_vcmla_rot0,                   // llvm.aarch64.neon.vcmla.rot0 (IntrinsicsAArch64.td:527)
    aarch64_neon_vcmla_rot180,                 // llvm.aarch64.neon.vcmla.rot180 (IntrinsicsAArch64.td:529)
    aarch64_neon_vcmla_rot270,                 // llvm.aarch64.neon.vcmla.rot270 (IntrinsicsAArch64.td:530)
    aarch64_neon_vcmla_rot90,                  // llvm.aarch64.neon.vcmla.rot90 (IntrinsicsAArch64.td:528)
    aarch64_neon_vcopy_lane,                   // llvm.aarch64.neon.vcopy.lane (IntrinsicsAArch64.td:583)
    aarch64_neon_vcvtfp2fxs,                   // llvm.aarch64.neon.vcvtfp2fxs (IntrinsicsAArch64.td:467)
    aarch64_neon_vcvtfp2fxu,                   // llvm.aarch64.neon.vcvtfp2fxu (IntrinsicsAArch64.td:468)
    aarch64_neon_vcvtfp2hf,                    // llvm.aarch64.neon.vcvtfp2hf (IntrinsicsAArch64.td:461)
    aarch64_neon_vcvtfxs2fp,                   // llvm.aarch64.neon.vcvtfxs2fp (IntrinsicsAArch64.td:469)
    aarch64_neon_vcvtfxu2fp,                   // llvm.aarch64.neon.vcvtfxu2fp (IntrinsicsAArch64.td:470)
    aarch64_neon_vcvthf2fp,                    // llvm.aarch64.neon.vcvthf2fp (IntrinsicsAArch64.td:463)
    aarch64_neon_vluti2_lane,                  // llvm.aarch64.neon.vluti2.lane (IntrinsicsAArch64.td:541)
    aarch64_neon_vluti2_laneq,                 // llvm.aarch64.neon.vluti2.laneq (IntrinsicsAArch64.td:546)
    aarch64_neon_vluti4q_lane,                 // llvm.aarch64.neon.vluti4q.lane (IntrinsicsAArch64.td:551)
    aarch64_neon_vluti4q_lane_x2,              // llvm.aarch64.neon.vluti4q.lane.x2 (IntrinsicsAArch64.td:562)
    aarch64_neon_vluti4q_laneq,                // llvm.aarch64.neon.vluti4q.laneq (IntrinsicsAArch64.td:556)
    aarch64_neon_vluti4q_laneq_x2,             // llvm.aarch64.neon.vluti4q.laneq.x2 (IntrinsicsAArch64.td:568)
    aarch64_neon_vsli,                         // llvm.aarch64.neon.vsli (IntrinsicsAArch64.td:428)
    aarch64_neon_vsri,                         // llvm.aarch64.neon.vsri (IntrinsicsAArch64.td:425)
    aarch64_prefetch,                          // llvm.aarch64.prefetch (IntrinsicsAArch64.td:72)
    aarch64_range_prefetch,                    // llvm.aarch64.range.prefetch (IntrinsicsAArch64.td:79)
    aarch64_rndr,                              // llvm.aarch64.rndr (IntrinsicsAArch64.td:751)
    aarch64_rndrrs,                            // llvm.aarch64.rndrrs (IntrinsicsAArch64.td:752)
    aarch64_sdiv,                              // llvm.aarch64.sdiv (IntrinsicsAArch64.td:37)
    aarch64_set_fpcr,                          // llvm.aarch64.set.fpcr (IntrinsicsAArch64.td:745)
    aarch64_set_fpmr,                          // llvm.aarch64.set.fpmr (IntrinsicsAArch64.td:748)
    aarch64_set_fpsr,                          // llvm.aarch64.set.fpsr (IntrinsicsAArch64.td:747)
    aarch64_settag,                            // llvm.aarch64.settag (IntrinsicsAArch64.td:930)
    aarch64_settag_zero,                       // llvm.aarch64.settag.zero (IntrinsicsAArch64.td:935)
    aarch64_sisd_fabd,                         // llvm.aarch64.sisd.fabd (IntrinsicsAArch64.td:325)
    aarch64_sisd_fcvtxn,                       // llvm.aarch64.sisd.fcvtxn (IntrinsicsAArch64.td:496)
    aarch64_sme_add_write_single_za_vg1x2,     // llvm.aarch64.sme.add.write.single.za.vg1x2 (IntrinsicsAArch64.td:3788)
    aarch64_sme_add_write_single_za_vg1x4,     // llvm.aarch64.sme.add.write.single.za.vg1x4 (IntrinsicsAArch64.td:3790)
    aarch64_sme_add_write_za_vg1x2,            // llvm.aarch64.sme.add.write.za.vg1x2 (IntrinsicsAArch64.td:3811)
    aarch64_sme_add_write_za_vg1x4,            // llvm.aarch64.sme.add.write.za.vg1x4 (IntrinsicsAArch64.td:3813)
    aarch64_sme_add_za16_vg1x2,                // llvm.aarch64.sme.add.za16.vg1x2 (IntrinsicsAArch64.td:3832)
    aarch64_sme_add_za16_vg1x4,                // llvm.aarch64.sme.add.za16.vg1x4 (IntrinsicsAArch64.td:3833)
    aarch64_sme_add_za32_vg1x2,                // llvm.aarch64.sme.add.za32.vg1x2 (IntrinsicsAArch64.td:3832)
    aarch64_sme_add_za32_vg1x4,                // llvm.aarch64.sme.add.za32.vg1x4 (IntrinsicsAArch64.td:3833)
    aarch64_sme_add_za64_vg1x2,                // llvm.aarch64.sme.add.za64.vg1x2 (IntrinsicsAArch64.td:3832)
    aarch64_sme_add_za64_vg1x4,                // llvm.aarch64.sme.add.za64.vg1x4 (IntrinsicsAArch64.td:3833)
    aarch64_sme_addha,                         // llvm.aarch64.sme.addha (IntrinsicsAArch64.td:3133)
    aarch64_sme_addva,                         // llvm.aarch64.sme.addva (IntrinsicsAArch64.td:3134)
    aarch64_sme_bmopa_za32,                    // llvm.aarch64.sme.bmopa.za32 (IntrinsicsAArch64.td:3546)
    aarch64_sme_bmops_za32,                    // llvm.aarch64.sme.bmops.za32 (IntrinsicsAArch64.td:3547)
    aarch64_sme_cntsd,                         // llvm.aarch64.sme.cntsd (IntrinsicsAArch64.td:3140)
    aarch64_sme_famax_x2,                      // llvm.aarch64.sme.famax.x2 (IntrinsicsAArch64.td:3705)
    aarch64_sme_famax_x4,                      // llvm.aarch64.sme.famax.x4 (IntrinsicsAArch64.td:3706)
    aarch64_sme_famin_x2,                      // llvm.aarch64.sme.famin.x2 (IntrinsicsAArch64.td:3705)
    aarch64_sme_famin_x4,                      // llvm.aarch64.sme.famin.x4 (IntrinsicsAArch64.td:3706)
    aarch64_sme_fdot_lane_za32_vg1x2,          // llvm.aarch64.sme.fdot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3897)
    aarch64_sme_fdot_lane_za32_vg1x4,          // llvm.aarch64.sme.fdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3898)
    aarch64_sme_fdot_single_za32_vg1x2,        // llvm.aarch64.sme.fdot.single.za32.vg1x2 (IntrinsicsAArch64.td:3891)
    aarch64_sme_fdot_single_za32_vg1x4,        // llvm.aarch64.sme.fdot.single.za32.vg1x4 (IntrinsicsAArch64.td:3892)
    aarch64_sme_fdot_za32_vg1x2,               // llvm.aarch64.sme.fdot.za32.vg1x2 (IntrinsicsAArch64.td:3894)
    aarch64_sme_fdot_za32_vg1x4,               // llvm.aarch64.sme.fdot.za32.vg1x4 (IntrinsicsAArch64.td:3895)
    aarch64_sme_fmla_lane_vg1x2,               // llvm.aarch64.sme.fmla.lane.vg1x2 (IntrinsicsAArch64.td:3532)
    aarch64_sme_fmla_lane_vg1x4,               // llvm.aarch64.sme.fmla.lane.vg1x4 (IntrinsicsAArch64.td:3534)
    aarch64_sme_fmla_single_vg1x2,             // llvm.aarch64.sme.fmla.single.vg1x2 (IntrinsicsAArch64.td:3522)
    aarch64_sme_fmla_single_vg1x4,             // llvm.aarch64.sme.fmla.single.vg1x4 (IntrinsicsAArch64.td:3524)
    aarch64_sme_fmla_vg1x2,                    // llvm.aarch64.sme.fmla.vg1x2 (IntrinsicsAArch64.td:3527)
    aarch64_sme_fmla_vg1x4,                    // llvm.aarch64.sme.fmla.vg1x4 (IntrinsicsAArch64.td:3529)
    aarch64_sme_fmlal_lane_vg2x1,              // llvm.aarch64.sme.fmlal.lane.vg2x1 (IntrinsicsAArch64.td:3594)
    aarch64_sme_fmlal_lane_vg2x2,              // llvm.aarch64.sme.fmlal.lane.vg2x2 (IntrinsicsAArch64.td:3595)
    aarch64_sme_fmlal_lane_vg2x4,              // llvm.aarch64.sme.fmlal.lane.vg2x4 (IntrinsicsAArch64.td:3596)
    aarch64_sme_fmlal_single_vg2x1,            // llvm.aarch64.sme.fmlal.single.vg2x1 (IntrinsicsAArch64.td:3587)
    aarch64_sme_fmlal_single_vg2x2,            // llvm.aarch64.sme.fmlal.single.vg2x2 (IntrinsicsAArch64.td:3588)
    aarch64_sme_fmlal_single_vg2x4,            // llvm.aarch64.sme.fmlal.single.vg2x4 (IntrinsicsAArch64.td:3589)
    aarch64_sme_fmlal_vg2x2,                   // llvm.aarch64.sme.fmlal.vg2x2 (IntrinsicsAArch64.td:3591)
    aarch64_sme_fmlal_vg2x4,                   // llvm.aarch64.sme.fmlal.vg2x4 (IntrinsicsAArch64.td:3592)
    aarch64_sme_fmls_lane_vg1x2,               // llvm.aarch64.sme.fmls.lane.vg1x2 (IntrinsicsAArch64.td:3533)
    aarch64_sme_fmls_lane_vg1x4,               // llvm.aarch64.sme.fmls.lane.vg1x4 (IntrinsicsAArch64.td:3535)
    aarch64_sme_fmls_single_vg1x2,             // llvm.aarch64.sme.fmls.single.vg1x2 (IntrinsicsAArch64.td:3523)
    aarch64_sme_fmls_single_vg1x4,             // llvm.aarch64.sme.fmls.single.vg1x4 (IntrinsicsAArch64.td:3525)
    aarch64_sme_fmls_vg1x2,                    // llvm.aarch64.sme.fmls.vg1x2 (IntrinsicsAArch64.td:3528)
    aarch64_sme_fmls_vg1x4,                    // llvm.aarch64.sme.fmls.vg1x4 (IntrinsicsAArch64.td:3530)
    aarch64_sme_fmlsl_lane_vg2x1,              // llvm.aarch64.sme.fmlsl.lane.vg2x1 (IntrinsicsAArch64.td:3594)
    aarch64_sme_fmlsl_lane_vg2x2,              // llvm.aarch64.sme.fmlsl.lane.vg2x2 (IntrinsicsAArch64.td:3595)
    aarch64_sme_fmlsl_lane_vg2x4,              // llvm.aarch64.sme.fmlsl.lane.vg2x4 (IntrinsicsAArch64.td:3596)
    aarch64_sme_fmlsl_single_vg2x1,            // llvm.aarch64.sme.fmlsl.single.vg2x1 (IntrinsicsAArch64.td:3587)
    aarch64_sme_fmlsl_single_vg2x2,            // llvm.aarch64.sme.fmlsl.single.vg2x2 (IntrinsicsAArch64.td:3588)
    aarch64_sme_fmlsl_single_vg2x4,            // llvm.aarch64.sme.fmlsl.single.vg2x4 (IntrinsicsAArch64.td:3589)
    aarch64_sme_fmlsl_vg2x2,                   // llvm.aarch64.sme.fmlsl.vg2x2 (IntrinsicsAArch64.td:3591)
    aarch64_sme_fmlsl_vg2x4,                   // llvm.aarch64.sme.fmlsl.vg2x4 (IntrinsicsAArch64.td:3592)
    aarch64_sme_fp8_fdot_lane_za16_vg1x2,      // llvm.aarch64.sme.fp8.fdot.lane.za16.vg1x2 (IntrinsicsAArch64.td:4236)
    aarch64_sme_fp8_fdot_lane_za16_vg1x4,      // llvm.aarch64.sme.fp8.fdot.lane.za16.vg1x4 (IntrinsicsAArch64.td:4239)
    aarch64_sme_fp8_fdot_lane_za32_vg1x2,      // llvm.aarch64.sme.fp8.fdot.lane.za32.vg1x2 (IntrinsicsAArch64.td:4237)
    aarch64_sme_fp8_fdot_lane_za32_vg1x4,      // llvm.aarch64.sme.fp8.fdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:4240)
    aarch64_sme_fp8_fdot_multi_za16_vg1x2,     // llvm.aarch64.sme.fp8.fdot.multi.za16.vg1x2 (IntrinsicsAArch64.td:4248)
    aarch64_sme_fp8_fdot_multi_za16_vg1x4,     // llvm.aarch64.sme.fp8.fdot.multi.za16.vg1x4 (IntrinsicsAArch64.td:4251)
    aarch64_sme_fp8_fdot_multi_za32_vg1x2,     // llvm.aarch64.sme.fp8.fdot.multi.za32.vg1x2 (IntrinsicsAArch64.td:4249)
    aarch64_sme_fp8_fdot_multi_za32_vg1x4,     // llvm.aarch64.sme.fp8.fdot.multi.za32.vg1x4 (IntrinsicsAArch64.td:4252)
    aarch64_sme_fp8_fdot_single_za16_vg1x2,    // llvm.aarch64.sme.fp8.fdot.single.za16.vg1x2 (IntrinsicsAArch64.td:4242)
    aarch64_sme_fp8_fdot_single_za16_vg1x4,    // llvm.aarch64.sme.fp8.fdot.single.za16.vg1x4 (IntrinsicsAArch64.td:4245)
    aarch64_sme_fp8_fdot_single_za32_vg1x2,    // llvm.aarch64.sme.fp8.fdot.single.za32.vg1x2 (IntrinsicsAArch64.td:4243)
    aarch64_sme_fp8_fdot_single_za32_vg1x4,    // llvm.aarch64.sme.fp8.fdot.single.za32.vg1x4 (IntrinsicsAArch64.td:4246)
    aarch64_sme_fp8_fmlal_lane_za16_vg2x1,     // llvm.aarch64.sme.fp8.fmlal.lane.za16.vg2x1 (IntrinsicsAArch64.td:4207)
    aarch64_sme_fp8_fmlal_lane_za16_vg2x2,     // llvm.aarch64.sme.fp8.fmlal.lane.za16.vg2x2 (IntrinsicsAArch64.td:4208)
    aarch64_sme_fp8_fmlal_lane_za16_vg2x4,     // llvm.aarch64.sme.fp8.fmlal.lane.za16.vg2x4 (IntrinsicsAArch64.td:4209)
    aarch64_sme_fp8_fmlal_multi_za16_vg2x2,    // llvm.aarch64.sme.fp8.fmlal.multi.za16.vg2x2 (IntrinsicsAArch64.td:4216)
    aarch64_sme_fp8_fmlal_multi_za16_vg2x4,    // llvm.aarch64.sme.fp8.fmlal.multi.za16.vg2x4 (IntrinsicsAArch64.td:4217)
    aarch64_sme_fp8_fmlal_single_za16_vg2x2,   // llvm.aarch64.sme.fp8.fmlal.single.za16.vg2x2 (IntrinsicsAArch64.td:4213)
    aarch64_sme_fp8_fmlal_single_za16_vg2x4,   // llvm.aarch64.sme.fp8.fmlal.single.za16.vg2x4 (IntrinsicsAArch64.td:4214)
    aarch64_sme_fp8_fmlal_za16_vg2x1,          // llvm.aarch64.sme.fp8.fmlal.za16.vg2x1 (IntrinsicsAArch64.td:4211)
    aarch64_sme_fp8_fmlall_lane_za32_vg4x1,    // llvm.aarch64.sme.fp8.fmlall.lane.za32.vg4x1 (IntrinsicsAArch64.td:4220)
    aarch64_sme_fp8_fmlall_lane_za32_vg4x2,    // llvm.aarch64.sme.fp8.fmlall.lane.za32.vg4x2 (IntrinsicsAArch64.td:4221)
    aarch64_sme_fp8_fmlall_lane_za32_vg4x4,    // llvm.aarch64.sme.fp8.fmlall.lane.za32.vg4x4 (IntrinsicsAArch64.td:4222)
    aarch64_sme_fp8_fmlall_multi_za32_vg4x2,   // llvm.aarch64.sme.fp8.fmlall.multi.za32.vg4x2 (IntrinsicsAArch64.td:4229)
    aarch64_sme_fp8_fmlall_multi_za32_vg4x4,   // llvm.aarch64.sme.fp8.fmlall.multi.za32.vg4x4 (IntrinsicsAArch64.td:4230)
    aarch64_sme_fp8_fmlall_single_za32_vg4x2,  // llvm.aarch64.sme.fp8.fmlall.single.za32.vg4x2 (IntrinsicsAArch64.td:4226)
    aarch64_sme_fp8_fmlall_single_za32_vg4x4,  // llvm.aarch64.sme.fp8.fmlall.single.za32.vg4x4 (IntrinsicsAArch64.td:4227)
    aarch64_sme_fp8_fmlall_za32_vg4x1,         // llvm.aarch64.sme.fp8.fmlall.za32.vg4x1 (IntrinsicsAArch64.td:4224)
    aarch64_sme_fp8_fmop4a_za16_1x1,           // llvm.aarch64.sme.fp8.fmop4a.za16.1x1 (IntrinsicsAArch64.td:3120)
    aarch64_sme_fp8_fmop4a_za16_1x2,           // llvm.aarch64.sme.fp8.fmop4a.za16.1x2 (IntrinsicsAArch64.td:3121)
    aarch64_sme_fp8_fmop4a_za16_2x1,           // llvm.aarch64.sme.fp8.fmop4a.za16.2x1 (IntrinsicsAArch64.td:3122)
    aarch64_sme_fp8_fmop4a_za16_2x2,           // llvm.aarch64.sme.fp8.fmop4a.za16.2x2 (IntrinsicsAArch64.td:3123)
    aarch64_sme_fp8_fmop4a_za32_1x1,           // llvm.aarch64.sme.fp8.fmop4a.za32.1x1 (IntrinsicsAArch64.td:3120)
    aarch64_sme_fp8_fmop4a_za32_1x2,           // llvm.aarch64.sme.fp8.fmop4a.za32.1x2 (IntrinsicsAArch64.td:3121)
    aarch64_sme_fp8_fmop4a_za32_2x1,           // llvm.aarch64.sme.fp8.fmop4a.za32.2x1 (IntrinsicsAArch64.td:3122)
    aarch64_sme_fp8_fmop4a_za32_2x2,           // llvm.aarch64.sme.fp8.fmop4a.za32.2x2 (IntrinsicsAArch64.td:3123)
    aarch64_sme_fp8_fmopa_za16,                // llvm.aarch64.sme.fp8.fmopa.za16 (IntrinsicsAArch64.td:4200)
    aarch64_sme_fp8_fmopa_za32,                // llvm.aarch64.sme.fp8.fmopa.za32 (IntrinsicsAArch64.td:4201)
    aarch64_sme_fp8_fvdot_lane_za16_vg1x2,     // llvm.aarch64.sme.fp8.fvdot.lane.za16.vg1x2 (IntrinsicsAArch64.td:4255)
    aarch64_sme_fp8_fvdotb_lane_za32_vg1x4,    // llvm.aarch64.sme.fp8.fvdotb.lane.za32.vg1x4 (IntrinsicsAArch64.td:4256)
    aarch64_sme_fp8_fvdott_lane_za32_vg1x4,    // llvm.aarch64.sme.fp8.fvdott.lane.za32.vg1x4 (IntrinsicsAArch64.td:4257)
    aarch64_sme_fp8_scale_single_x2,           // llvm.aarch64.sme.fp8.scale.single.x2 (IntrinsicsAArch64.td:3980)
    aarch64_sme_fp8_scale_single_x4,           // llvm.aarch64.sme.fp8.scale.single.x4 (IntrinsicsAArch64.td:3985)
    aarch64_sme_fp8_scale_x2,                  // llvm.aarch64.sme.fp8.scale.x2 (IntrinsicsAArch64.td:3990)
    aarch64_sme_fp8_scale_x4,                  // llvm.aarch64.sme.fp8.scale.x4 (IntrinsicsAArch64.td:3996)
    aarch64_sme_ftmopa_za16,                   // llvm.aarch64.sme.ftmopa.za16 (IntrinsicsAArch64.td:3111)
    aarch64_sme_ftmopa_za32,                   // llvm.aarch64.sme.ftmopa.za32 (IntrinsicsAArch64.td:3112)
    aarch64_sme_fvdot_lane_za32_vg1x2,         // llvm.aarch64.sme.fvdot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3713)
    aarch64_sme_get_tpidr2,                    // llvm.aarch64.sme.get.tpidr2 (IntrinsicsAArch64.td:3147)
    aarch64_sme_in_streaming_mode,             // llvm.aarch64.sme.in.streaming.mode (IntrinsicsAArch64.td:3032)
    aarch64_sme_ld1b_horiz,                    // llvm.aarch64.sme.ld1b.horiz (IntrinsicsAArch64.td:2936)
    aarch64_sme_ld1b_vert,                     // llvm.aarch64.sme.ld1b.vert (IntrinsicsAArch64.td:2941)
    aarch64_sme_ld1d_horiz,                    // llvm.aarch64.sme.ld1d.horiz (IntrinsicsAArch64.td:2939)
    aarch64_sme_ld1d_vert,                     // llvm.aarch64.sme.ld1d.vert (IntrinsicsAArch64.td:2944)
    aarch64_sme_ld1h_horiz,                    // llvm.aarch64.sme.ld1h.horiz (IntrinsicsAArch64.td:2937)
    aarch64_sme_ld1h_vert,                     // llvm.aarch64.sme.ld1h.vert (IntrinsicsAArch64.td:2942)
    aarch64_sme_ld1q_horiz,                    // llvm.aarch64.sme.ld1q.horiz (IntrinsicsAArch64.td:2940)
    aarch64_sme_ld1q_vert,                     // llvm.aarch64.sme.ld1q.vert (IntrinsicsAArch64.td:2945)
    aarch64_sme_ld1w_horiz,                    // llvm.aarch64.sme.ld1w.horiz (IntrinsicsAArch64.td:2938)
    aarch64_sme_ld1w_vert,                     // llvm.aarch64.sme.ld1w.vert (IntrinsicsAArch64.td:2943)
    aarch64_sme_ldr,                           // llvm.aarch64.sme.ldr (IntrinsicsAArch64.td:2962)
    aarch64_sme_ldr_zt,                        // llvm.aarch64.sme.ldr.zt (IntrinsicsAArch64.td:3932)
    aarch64_sme_luti2_lane_zt,                 // llvm.aarch64.sme.luti2.lane.zt (IntrinsicsAArch64.td:3943)
    aarch64_sme_luti2_lane_zt_x2,              // llvm.aarch64.sme.luti2.lane.zt.x2 (IntrinsicsAArch64.td:3952)
    aarch64_sme_luti2_lane_zt_x4,              // llvm.aarch64.sme.luti2.lane.zt.x4 (IntrinsicsAArch64.td:3962)
    aarch64_sme_luti4_lane_zt,                 // llvm.aarch64.sme.luti4.lane.zt (IntrinsicsAArch64.td:3946)
    aarch64_sme_luti4_lane_zt_x2,              // llvm.aarch64.sme.luti4.lane.zt.x2 (IntrinsicsAArch64.td:3955)
    aarch64_sme_luti4_lane_zt_x4,              // llvm.aarch64.sme.luti4.lane.zt.x4 (IntrinsicsAArch64.td:3966)
    aarch64_sme_luti4_zt_x4,                   // llvm.aarch64.sme.luti4.zt.x4 (IntrinsicsAArch64.td:3971)
    aarch64_sme_mop4a_1x1,                     // llvm.aarch64.sme.mop4a.1x1 (IntrinsicsAArch64.td:3093)
    aarch64_sme_mop4a_1x2,                     // llvm.aarch64.sme.mop4a.1x2 (IntrinsicsAArch64.td:3094)
    aarch64_sme_mop4a_2x1,                     // llvm.aarch64.sme.mop4a.2x1 (IntrinsicsAArch64.td:3095)
    aarch64_sme_mop4a_2x2,                     // llvm.aarch64.sme.mop4a.2x2 (IntrinsicsAArch64.td:3096)
    aarch64_sme_mop4a_wide_1x1,                // llvm.aarch64.sme.mop4a.wide.1x1 (IntrinsicsAArch64.td:3093)
    aarch64_sme_mop4a_wide_1x2,                // llvm.aarch64.sme.mop4a.wide.1x2 (IntrinsicsAArch64.td:3094)
    aarch64_sme_mop4a_wide_2x1,                // llvm.aarch64.sme.mop4a.wide.2x1 (IntrinsicsAArch64.td:3095)
    aarch64_sme_mop4a_wide_2x2,                // llvm.aarch64.sme.mop4a.wide.2x2 (IntrinsicsAArch64.td:3096)
    aarch64_sme_mop4s_1x1,                     // llvm.aarch64.sme.mop4s.1x1 (IntrinsicsAArch64.td:3093)
    aarch64_sme_mop4s_1x2,                     // llvm.aarch64.sme.mop4s.1x2 (IntrinsicsAArch64.td:3094)
    aarch64_sme_mop4s_2x1,                     // llvm.aarch64.sme.mop4s.2x1 (IntrinsicsAArch64.td:3095)
    aarch64_sme_mop4s_2x2,                     // llvm.aarch64.sme.mop4s.2x2 (IntrinsicsAArch64.td:3096)
    aarch64_sme_mop4s_wide_1x1,                // llvm.aarch64.sme.mop4s.wide.1x1 (IntrinsicsAArch64.td:3093)
    aarch64_sme_mop4s_wide_1x2,                // llvm.aarch64.sme.mop4s.wide.1x2 (IntrinsicsAArch64.td:3094)
    aarch64_sme_mop4s_wide_2x1,                // llvm.aarch64.sme.mop4s.wide.2x1 (IntrinsicsAArch64.td:3095)
    aarch64_sme_mop4s_wide_2x2,                // llvm.aarch64.sme.mop4s.wide.2x2 (IntrinsicsAArch64.td:3096)
    aarch64_sme_mopa,                          // llvm.aarch64.sme.mopa (IntrinsicsAArch64.td:3042)
    aarch64_sme_mopa_nonwide,                  // llvm.aarch64.sme.mopa.nonwide (IntrinsicsAArch64.td:4031)
    aarch64_sme_mopa_wide,                     // llvm.aarch64.sme.mopa.wide (IntrinsicsAArch64.td:3045)
    aarch64_sme_mops,                          // llvm.aarch64.sme.mops (IntrinsicsAArch64.td:3043)
    aarch64_sme_mops_nonwide,                  // llvm.aarch64.sme.mops.nonwide (IntrinsicsAArch64.td:4032)
    aarch64_sme_mops_wide,                     // llvm.aarch64.sme.mops.wide (IntrinsicsAArch64.td:3046)
    aarch64_sme_read_hor_vg2,                  // llvm.aarch64.sme.read.hor.vg2 (IntrinsicsAArch64.td:3841)
    aarch64_sme_read_hor_vg4,                  // llvm.aarch64.sme.read.hor.vg4 (IntrinsicsAArch64.td:3842)
    aarch64_sme_read_horiz,                    // llvm.aarch64.sme.read.horiz (IntrinsicsAArch64.td:2974)
    aarch64_sme_read_ver_vg2,                  // llvm.aarch64.sme.read.ver.vg2 (IntrinsicsAArch64.td:3844)
    aarch64_sme_read_ver_vg4,                  // llvm.aarch64.sme.read.ver.vg4 (IntrinsicsAArch64.td:3845)
    aarch64_sme_read_vert,                     // llvm.aarch64.sme.read.vert (IntrinsicsAArch64.td:2975)
    aarch64_sme_read_vg1x2,                    // llvm.aarch64.sme.read.vg1x2 (IntrinsicsAArch64.td:3847)
    aarch64_sme_read_vg1x4,                    // llvm.aarch64.sme.read.vg1x4 (IntrinsicsAArch64.td:3848)
    aarch64_sme_readq_horiz,                   // llvm.aarch64.sme.readq.horiz (IntrinsicsAArch64.td:2979)
    aarch64_sme_readq_vert,                    // llvm.aarch64.sme.readq.vert (IntrinsicsAArch64.td:2980)
    aarch64_sme_readz_horiz,                   // llvm.aarch64.sme.readz.horiz (IntrinsicsAArch64.td:3006)
    aarch64_sme_readz_horiz_x2,                // llvm.aarch64.sme.readz.horiz.x2 (IntrinsicsAArch64.td:2995)
    aarch64_sme_readz_horiz_x4,                // llvm.aarch64.sme.readz.horiz.x4 (IntrinsicsAArch64.td:2998)
    aarch64_sme_readz_q_horiz,                 // llvm.aarch64.sme.readz.q.horiz (IntrinsicsAArch64.td:3009)
    aarch64_sme_readz_q_vert,                  // llvm.aarch64.sme.readz.q.vert (IntrinsicsAArch64.td:3010)
    aarch64_sme_readz_vert,                    // llvm.aarch64.sme.readz.vert (IntrinsicsAArch64.td:3007)
    aarch64_sme_readz_vert_x2,                 // llvm.aarch64.sme.readz.vert.x2 (IntrinsicsAArch64.td:2996)
    aarch64_sme_readz_vert_x4,                 // llvm.aarch64.sme.readz.vert.x4 (IntrinsicsAArch64.td:2999)
    aarch64_sme_readz_x2,                      // llvm.aarch64.sme.readz.x2 (IntrinsicsAArch64.td:3012)
    aarch64_sme_readz_x4,                      // llvm.aarch64.sme.readz.x4 (IntrinsicsAArch64.td:3017)
    aarch64_sme_sdot_lane_za32_vg1x2,          // llvm.aarch64.sme.sdot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3874)
    aarch64_sme_sdot_lane_za32_vg1x4,          // llvm.aarch64.sme.sdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3875)
    aarch64_sme_sdot_lane_za64_vg1x2,          // llvm.aarch64.sme.sdot.lane.za64.vg1x2 (IntrinsicsAArch64.td:3874)
    aarch64_sme_sdot_lane_za64_vg1x4,          // llvm.aarch64.sme.sdot.lane.za64.vg1x4 (IntrinsicsAArch64.td:3875)
    aarch64_sme_sdot_single_za32_vg1x2,        // llvm.aarch64.sme.sdot.single.za32.vg1x2 (IntrinsicsAArch64.td:3868)
    aarch64_sme_sdot_single_za32_vg1x4,        // llvm.aarch64.sme.sdot.single.za32.vg1x4 (IntrinsicsAArch64.td:3869)
    aarch64_sme_sdot_single_za64_vg1x2,        // llvm.aarch64.sme.sdot.single.za64.vg1x2 (IntrinsicsAArch64.td:3868)
    aarch64_sme_sdot_single_za64_vg1x4,        // llvm.aarch64.sme.sdot.single.za64.vg1x4 (IntrinsicsAArch64.td:3869)
    aarch64_sme_sdot_za32_vg1x2,               // llvm.aarch64.sme.sdot.za32.vg1x2 (IntrinsicsAArch64.td:3871)
    aarch64_sme_sdot_za32_vg1x4,               // llvm.aarch64.sme.sdot.za32.vg1x4 (IntrinsicsAArch64.td:3872)
    aarch64_sme_sdot_za64_vg1x2,               // llvm.aarch64.sme.sdot.za64.vg1x2 (IntrinsicsAArch64.td:3871)
    aarch64_sme_sdot_za64_vg1x4,               // llvm.aarch64.sme.sdot.za64.vg1x4 (IntrinsicsAArch64.td:3872)
    aarch64_sme_set_tpidr2,                    // llvm.aarch64.sme.set.tpidr2 (IntrinsicsAArch64.td:3150)
    aarch64_sme_smla_za32_lane_vg4x1,          // llvm.aarch64.sme.smla.za32.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_smla_za32_lane_vg4x2,          // llvm.aarch64.sme.smla.za32.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_smla_za32_lane_vg4x4,          // llvm.aarch64.sme.smla.za32.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_smla_za32_single_vg4x1,        // llvm.aarch64.sme.smla.za32.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_smla_za32_single_vg4x2,        // llvm.aarch64.sme.smla.za32.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_smla_za32_single_vg4x4,        // llvm.aarch64.sme.smla.za32.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_smla_za32_vg4x2,               // llvm.aarch64.sme.smla.za32.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_smla_za32_vg4x4,               // llvm.aarch64.sme.smla.za32.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_smla_za64_lane_vg4x1,          // llvm.aarch64.sme.smla.za64.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_smla_za64_lane_vg4x2,          // llvm.aarch64.sme.smla.za64.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_smla_za64_lane_vg4x4,          // llvm.aarch64.sme.smla.za64.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_smla_za64_single_vg4x1,        // llvm.aarch64.sme.smla.za64.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_smla_za64_single_vg4x2,        // llvm.aarch64.sme.smla.za64.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_smla_za64_single_vg4x4,        // llvm.aarch64.sme.smla.za64.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_smla_za64_vg4x2,               // llvm.aarch64.sme.smla.za64.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_smla_za64_vg4x4,               // llvm.aarch64.sme.smla.za64.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_smlal_lane_vg2x1,              // llvm.aarch64.sme.smlal.lane.vg2x1 (IntrinsicsAArch64.td:3594)
    aarch64_sme_smlal_lane_vg2x2,              // llvm.aarch64.sme.smlal.lane.vg2x2 (IntrinsicsAArch64.td:3595)
    aarch64_sme_smlal_lane_vg2x4,              // llvm.aarch64.sme.smlal.lane.vg2x4 (IntrinsicsAArch64.td:3596)
    aarch64_sme_smlal_single_vg2x1,            // llvm.aarch64.sme.smlal.single.vg2x1 (IntrinsicsAArch64.td:3587)
    aarch64_sme_smlal_single_vg2x2,            // llvm.aarch64.sme.smlal.single.vg2x2 (IntrinsicsAArch64.td:3588)
    aarch64_sme_smlal_single_vg2x4,            // llvm.aarch64.sme.smlal.single.vg2x4 (IntrinsicsAArch64.td:3589)
    aarch64_sme_smlal_vg2x2,                   // llvm.aarch64.sme.smlal.vg2x2 (IntrinsicsAArch64.td:3591)
    aarch64_sme_smlal_vg2x4,                   // llvm.aarch64.sme.smlal.vg2x4 (IntrinsicsAArch64.td:3592)
    aarch64_sme_smls_za32_lane_vg4x1,          // llvm.aarch64.sme.smls.za32.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_smls_za32_lane_vg4x2,          // llvm.aarch64.sme.smls.za32.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_smls_za32_lane_vg4x4,          // llvm.aarch64.sme.smls.za32.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_smls_za32_single_vg4x1,        // llvm.aarch64.sme.smls.za32.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_smls_za32_single_vg4x2,        // llvm.aarch64.sme.smls.za32.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_smls_za32_single_vg4x4,        // llvm.aarch64.sme.smls.za32.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_smls_za32_vg4x2,               // llvm.aarch64.sme.smls.za32.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_smls_za32_vg4x4,               // llvm.aarch64.sme.smls.za32.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_smls_za64_lane_vg4x1,          // llvm.aarch64.sme.smls.za64.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_smls_za64_lane_vg4x2,          // llvm.aarch64.sme.smls.za64.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_smls_za64_lane_vg4x4,          // llvm.aarch64.sme.smls.za64.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_smls_za64_single_vg4x1,        // llvm.aarch64.sme.smls.za64.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_smls_za64_single_vg4x2,        // llvm.aarch64.sme.smls.za64.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_smls_za64_single_vg4x4,        // llvm.aarch64.sme.smls.za64.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_smls_za64_vg4x2,               // llvm.aarch64.sme.smls.za64.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_smls_za64_vg4x4,               // llvm.aarch64.sme.smls.za64.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_smlsl_lane_vg2x1,              // llvm.aarch64.sme.smlsl.lane.vg2x1 (IntrinsicsAArch64.td:3594)
    aarch64_sme_smlsl_lane_vg2x2,              // llvm.aarch64.sme.smlsl.lane.vg2x2 (IntrinsicsAArch64.td:3595)
    aarch64_sme_smlsl_lane_vg2x4,              // llvm.aarch64.sme.smlsl.lane.vg2x4 (IntrinsicsAArch64.td:3596)
    aarch64_sme_smlsl_single_vg2x1,            // llvm.aarch64.sme.smlsl.single.vg2x1 (IntrinsicsAArch64.td:3587)
    aarch64_sme_smlsl_single_vg2x2,            // llvm.aarch64.sme.smlsl.single.vg2x2 (IntrinsicsAArch64.td:3588)
    aarch64_sme_smlsl_single_vg2x4,            // llvm.aarch64.sme.smlsl.single.vg2x4 (IntrinsicsAArch64.td:3589)
    aarch64_sme_smlsl_vg2x2,                   // llvm.aarch64.sme.smlsl.vg2x2 (IntrinsicsAArch64.td:3591)
    aarch64_sme_smlsl_vg2x4,                   // llvm.aarch64.sme.smlsl.vg2x4 (IntrinsicsAArch64.td:3592)
    aarch64_sme_smop4a_wide_1x1,               // llvm.aarch64.sme.smop4a.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_smop4a_wide_1x2,               // llvm.aarch64.sme.smop4a.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_smop4a_wide_2x1,               // llvm.aarch64.sme.smop4a.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_smop4a_wide_2x2,               // llvm.aarch64.sme.smop4a.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_smop4a_za64_wide_1x1,          // llvm.aarch64.sme.smop4a.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_smop4a_za64_wide_1x2,          // llvm.aarch64.sme.smop4a.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_smop4a_za64_wide_2x1,          // llvm.aarch64.sme.smop4a.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_smop4a_za64_wide_2x2,          // llvm.aarch64.sme.smop4a.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_smop4s_wide_1x1,               // llvm.aarch64.sme.smop4s.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_smop4s_wide_1x2,               // llvm.aarch64.sme.smop4s.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_smop4s_wide_2x1,               // llvm.aarch64.sme.smop4s.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_smop4s_wide_2x2,               // llvm.aarch64.sme.smop4s.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_smop4s_za64_wide_1x1,          // llvm.aarch64.sme.smop4s.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_smop4s_za64_wide_1x2,          // llvm.aarch64.sme.smop4s.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_smop4s_za64_wide_2x1,          // llvm.aarch64.sme.smop4s.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_smop4s_za64_wide_2x2,          // llvm.aarch64.sme.smop4s.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_smopa_wide,                    // llvm.aarch64.sme.smopa.wide (IntrinsicsAArch64.td:3048)
    aarch64_sme_smopa_za32,                    // llvm.aarch64.sme.smopa.za32 (IntrinsicsAArch64.td:3541)
    aarch64_sme_smops_wide,                    // llvm.aarch64.sme.smops.wide (IntrinsicsAArch64.td:3049)
    aarch64_sme_smops_za32,                    // llvm.aarch64.sme.smops.za32 (IntrinsicsAArch64.td:3543)
    aarch64_sme_st1b_horiz,                    // llvm.aarch64.sme.st1b.horiz (IntrinsicsAArch64.td:2948)
    aarch64_sme_st1b_vert,                     // llvm.aarch64.sme.st1b.vert (IntrinsicsAArch64.td:2953)
    aarch64_sme_st1d_horiz,                    // llvm.aarch64.sme.st1d.horiz (IntrinsicsAArch64.td:2951)
    aarch64_sme_st1d_vert,                     // llvm.aarch64.sme.st1d.vert (IntrinsicsAArch64.td:2956)
    aarch64_sme_st1h_horiz,                    // llvm.aarch64.sme.st1h.horiz (IntrinsicsAArch64.td:2949)
    aarch64_sme_st1h_vert,                     // llvm.aarch64.sme.st1h.vert (IntrinsicsAArch64.td:2954)
    aarch64_sme_st1q_horiz,                    // llvm.aarch64.sme.st1q.horiz (IntrinsicsAArch64.td:2952)
    aarch64_sme_st1q_vert,                     // llvm.aarch64.sme.st1q.vert (IntrinsicsAArch64.td:2957)
    aarch64_sme_st1w_horiz,                    // llvm.aarch64.sme.st1w.horiz (IntrinsicsAArch64.td:2950)
    aarch64_sme_st1w_vert,                     // llvm.aarch64.sme.st1w.vert (IntrinsicsAArch64.td:2955)
    aarch64_sme_stmopa_za32,                   // llvm.aarch64.sme.stmopa.za32 (IntrinsicsAArch64.td:3113)
    aarch64_sme_str,                           // llvm.aarch64.sme.str (IntrinsicsAArch64.td:2963)
    aarch64_sme_str_zt,                        // llvm.aarch64.sme.str.zt (IntrinsicsAArch64.td:3933)
    aarch64_sme_sub_write_single_za_vg1x2,     // llvm.aarch64.sme.sub.write.single.za.vg1x2 (IntrinsicsAArch64.td:3789)
    aarch64_sme_sub_write_single_za_vg1x4,     // llvm.aarch64.sme.sub.write.single.za.vg1x4 (IntrinsicsAArch64.td:3791)
    aarch64_sme_sub_write_za_vg1x2,            // llvm.aarch64.sme.sub.write.za.vg1x2 (IntrinsicsAArch64.td:3812)
    aarch64_sme_sub_write_za_vg1x4,            // llvm.aarch64.sme.sub.write.za.vg1x4 (IntrinsicsAArch64.td:3814)
    aarch64_sme_sub_za16_vg1x2,                // llvm.aarch64.sme.sub.za16.vg1x2 (IntrinsicsAArch64.td:3832)
    aarch64_sme_sub_za16_vg1x4,                // llvm.aarch64.sme.sub.za16.vg1x4 (IntrinsicsAArch64.td:3833)
    aarch64_sme_sub_za32_vg1x2,                // llvm.aarch64.sme.sub.za32.vg1x2 (IntrinsicsAArch64.td:3832)
    aarch64_sme_sub_za32_vg1x4,                // llvm.aarch64.sme.sub.za32.vg1x4 (IntrinsicsAArch64.td:3833)
    aarch64_sme_sub_za64_vg1x2,                // llvm.aarch64.sme.sub.za64.vg1x2 (IntrinsicsAArch64.td:3832)
    aarch64_sme_sub_za64_vg1x4,                // llvm.aarch64.sme.sub.za64.vg1x4 (IntrinsicsAArch64.td:3833)
    aarch64_sme_sudot_lane_za32_vg1x2,         // llvm.aarch64.sme.sudot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3883)
    aarch64_sme_sudot_lane_za32_vg1x4,         // llvm.aarch64.sme.sudot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3884)
    aarch64_sme_sudot_single_za32_vg1x2,       // llvm.aarch64.sme.sudot.single.za32.vg1x2 (IntrinsicsAArch64.td:3880)
    aarch64_sme_sudot_single_za32_vg1x4,       // llvm.aarch64.sme.sudot.single.za32.vg1x4 (IntrinsicsAArch64.td:3881)
    aarch64_sme_sumla_za32_lane_vg4x1,         // llvm.aarch64.sme.sumla.za32.lane.vg4x1 (IntrinsicsAArch64.td:3624)
    aarch64_sme_sumla_za32_lane_vg4x2,         // llvm.aarch64.sme.sumla.za32.lane.vg4x2 (IntrinsicsAArch64.td:3625)
    aarch64_sme_sumla_za32_lane_vg4x4,         // llvm.aarch64.sme.sumla.za32.lane.vg4x4 (IntrinsicsAArch64.td:3626)
    aarch64_sme_sumla_za32_single_vg4x2,       // llvm.aarch64.sme.sumla.za32.single.vg4x2 (IntrinsicsAArch64.td:3621)
    aarch64_sme_sumla_za32_single_vg4x4,       // llvm.aarch64.sme.sumla.za32.single.vg4x4 (IntrinsicsAArch64.td:3622)
    aarch64_sme_sumop4a_wide_1x1,              // llvm.aarch64.sme.sumop4a.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_sumop4a_wide_1x2,              // llvm.aarch64.sme.sumop4a.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_sumop4a_wide_2x1,              // llvm.aarch64.sme.sumop4a.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_sumop4a_wide_2x2,              // llvm.aarch64.sme.sumop4a.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_sumop4a_za64_wide_1x1,         // llvm.aarch64.sme.sumop4a.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_sumop4a_za64_wide_1x2,         // llvm.aarch64.sme.sumop4a.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_sumop4a_za64_wide_2x1,         // llvm.aarch64.sme.sumop4a.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_sumop4a_za64_wide_2x2,         // llvm.aarch64.sme.sumop4a.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_sumop4s_wide_1x1,              // llvm.aarch64.sme.sumop4s.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_sumop4s_wide_1x2,              // llvm.aarch64.sme.sumop4s.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_sumop4s_wide_2x1,              // llvm.aarch64.sme.sumop4s.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_sumop4s_wide_2x2,              // llvm.aarch64.sme.sumop4s.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_sumop4s_za64_wide_1x1,         // llvm.aarch64.sme.sumop4s.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_sumop4s_za64_wide_1x2,         // llvm.aarch64.sme.sumop4s.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_sumop4s_za64_wide_2x1,         // llvm.aarch64.sme.sumop4s.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_sumop4s_za64_wide_2x2,         // llvm.aarch64.sme.sumop4s.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_sumopa_wide,                   // llvm.aarch64.sme.sumopa.wide (IntrinsicsAArch64.td:3052)
    aarch64_sme_sumops_wide,                   // llvm.aarch64.sme.sumops.wide (IntrinsicsAArch64.td:3053)
    aarch64_sme_sutmopa_za32,                  // llvm.aarch64.sme.sutmopa.za32 (IntrinsicsAArch64.td:3115)
    aarch64_sme_suvdot_lane_za32_vg1x4,        // llvm.aarch64.sme.suvdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3721)
    aarch64_sme_svdot_lane_za32_vg1x2,         // llvm.aarch64.sme.svdot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3716)
    aarch64_sme_svdot_lane_za32_vg1x4,         // llvm.aarch64.sme.svdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3717)
    aarch64_sme_svdot_lane_za64_vg1x4,         // llvm.aarch64.sme.svdot.lane.za64.vg1x4 (IntrinsicsAArch64.td:3718)
    aarch64_sme_udot_lane_za32_vg1x2,          // llvm.aarch64.sme.udot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3874)
    aarch64_sme_udot_lane_za32_vg1x4,          // llvm.aarch64.sme.udot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3875)
    aarch64_sme_udot_lane_za64_vg1x2,          // llvm.aarch64.sme.udot.lane.za64.vg1x2 (IntrinsicsAArch64.td:3874)
    aarch64_sme_udot_lane_za64_vg1x4,          // llvm.aarch64.sme.udot.lane.za64.vg1x4 (IntrinsicsAArch64.td:3875)
    aarch64_sme_udot_single_za32_vg1x2,        // llvm.aarch64.sme.udot.single.za32.vg1x2 (IntrinsicsAArch64.td:3868)
    aarch64_sme_udot_single_za32_vg1x4,        // llvm.aarch64.sme.udot.single.za32.vg1x4 (IntrinsicsAArch64.td:3869)
    aarch64_sme_udot_single_za64_vg1x2,        // llvm.aarch64.sme.udot.single.za64.vg1x2 (IntrinsicsAArch64.td:3868)
    aarch64_sme_udot_single_za64_vg1x4,        // llvm.aarch64.sme.udot.single.za64.vg1x4 (IntrinsicsAArch64.td:3869)
    aarch64_sme_udot_za32_vg1x2,               // llvm.aarch64.sme.udot.za32.vg1x2 (IntrinsicsAArch64.td:3871)
    aarch64_sme_udot_za32_vg1x4,               // llvm.aarch64.sme.udot.za32.vg1x4 (IntrinsicsAArch64.td:3872)
    aarch64_sme_udot_za64_vg1x2,               // llvm.aarch64.sme.udot.za64.vg1x2 (IntrinsicsAArch64.td:3871)
    aarch64_sme_udot_za64_vg1x4,               // llvm.aarch64.sme.udot.za64.vg1x4 (IntrinsicsAArch64.td:3872)
    aarch64_sme_umla_za32_lane_vg4x1,          // llvm.aarch64.sme.umla.za32.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_umla_za32_lane_vg4x2,          // llvm.aarch64.sme.umla.za32.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_umla_za32_lane_vg4x4,          // llvm.aarch64.sme.umla.za32.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_umla_za32_single_vg4x1,        // llvm.aarch64.sme.umla.za32.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_umla_za32_single_vg4x2,        // llvm.aarch64.sme.umla.za32.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_umla_za32_single_vg4x4,        // llvm.aarch64.sme.umla.za32.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_umla_za32_vg4x2,               // llvm.aarch64.sme.umla.za32.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_umla_za32_vg4x4,               // llvm.aarch64.sme.umla.za32.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_umla_za64_lane_vg4x1,          // llvm.aarch64.sme.umla.za64.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_umla_za64_lane_vg4x2,          // llvm.aarch64.sme.umla.za64.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_umla_za64_lane_vg4x4,          // llvm.aarch64.sme.umla.za64.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_umla_za64_single_vg4x1,        // llvm.aarch64.sme.umla.za64.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_umla_za64_single_vg4x2,        // llvm.aarch64.sme.umla.za64.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_umla_za64_single_vg4x4,        // llvm.aarch64.sme.umla.za64.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_umla_za64_vg4x2,               // llvm.aarch64.sme.umla.za64.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_umla_za64_vg4x4,               // llvm.aarch64.sme.umla.za64.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_umlal_lane_vg2x1,              // llvm.aarch64.sme.umlal.lane.vg2x1 (IntrinsicsAArch64.td:3594)
    aarch64_sme_umlal_lane_vg2x2,              // llvm.aarch64.sme.umlal.lane.vg2x2 (IntrinsicsAArch64.td:3595)
    aarch64_sme_umlal_lane_vg2x4,              // llvm.aarch64.sme.umlal.lane.vg2x4 (IntrinsicsAArch64.td:3596)
    aarch64_sme_umlal_single_vg2x1,            // llvm.aarch64.sme.umlal.single.vg2x1 (IntrinsicsAArch64.td:3587)
    aarch64_sme_umlal_single_vg2x2,            // llvm.aarch64.sme.umlal.single.vg2x2 (IntrinsicsAArch64.td:3588)
    aarch64_sme_umlal_single_vg2x4,            // llvm.aarch64.sme.umlal.single.vg2x4 (IntrinsicsAArch64.td:3589)
    aarch64_sme_umlal_vg2x2,                   // llvm.aarch64.sme.umlal.vg2x2 (IntrinsicsAArch64.td:3591)
    aarch64_sme_umlal_vg2x4,                   // llvm.aarch64.sme.umlal.vg2x4 (IntrinsicsAArch64.td:3592)
    aarch64_sme_umls_za32_lane_vg4x1,          // llvm.aarch64.sme.umls.za32.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_umls_za32_lane_vg4x2,          // llvm.aarch64.sme.umls.za32.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_umls_za32_lane_vg4x4,          // llvm.aarch64.sme.umls.za32.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_umls_za32_single_vg4x1,        // llvm.aarch64.sme.umls.za32.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_umls_za32_single_vg4x2,        // llvm.aarch64.sme.umls.za32.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_umls_za32_single_vg4x4,        // llvm.aarch64.sme.umls.za32.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_umls_za32_vg4x2,               // llvm.aarch64.sme.umls.za32.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_umls_za32_vg4x4,               // llvm.aarch64.sme.umls.za32.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_umls_za64_lane_vg4x1,          // llvm.aarch64.sme.umls.za64.lane.vg4x1 (IntrinsicsAArch64.td:3614)
    aarch64_sme_umls_za64_lane_vg4x2,          // llvm.aarch64.sme.umls.za64.lane.vg4x2 (IntrinsicsAArch64.td:3615)
    aarch64_sme_umls_za64_lane_vg4x4,          // llvm.aarch64.sme.umls.za64.lane.vg4x4 (IntrinsicsAArch64.td:3616)
    aarch64_sme_umls_za64_single_vg4x1,        // llvm.aarch64.sme.umls.za64.single.vg4x1 (IntrinsicsAArch64.td:3607)
    aarch64_sme_umls_za64_single_vg4x2,        // llvm.aarch64.sme.umls.za64.single.vg4x2 (IntrinsicsAArch64.td:3608)
    aarch64_sme_umls_za64_single_vg4x4,        // llvm.aarch64.sme.umls.za64.single.vg4x4 (IntrinsicsAArch64.td:3609)
    aarch64_sme_umls_za64_vg4x2,               // llvm.aarch64.sme.umls.za64.vg4x2 (IntrinsicsAArch64.td:3611)
    aarch64_sme_umls_za64_vg4x4,               // llvm.aarch64.sme.umls.za64.vg4x4 (IntrinsicsAArch64.td:3612)
    aarch64_sme_umlsl_lane_vg2x1,              // llvm.aarch64.sme.umlsl.lane.vg2x1 (IntrinsicsAArch64.td:3594)
    aarch64_sme_umlsl_lane_vg2x2,              // llvm.aarch64.sme.umlsl.lane.vg2x2 (IntrinsicsAArch64.td:3595)
    aarch64_sme_umlsl_lane_vg2x4,              // llvm.aarch64.sme.umlsl.lane.vg2x4 (IntrinsicsAArch64.td:3596)
    aarch64_sme_umlsl_single_vg2x1,            // llvm.aarch64.sme.umlsl.single.vg2x1 (IntrinsicsAArch64.td:3587)
    aarch64_sme_umlsl_single_vg2x2,            // llvm.aarch64.sme.umlsl.single.vg2x2 (IntrinsicsAArch64.td:3588)
    aarch64_sme_umlsl_single_vg2x4,            // llvm.aarch64.sme.umlsl.single.vg2x4 (IntrinsicsAArch64.td:3589)
    aarch64_sme_umlsl_vg2x2,                   // llvm.aarch64.sme.umlsl.vg2x2 (IntrinsicsAArch64.td:3591)
    aarch64_sme_umlsl_vg2x4,                   // llvm.aarch64.sme.umlsl.vg2x4 (IntrinsicsAArch64.td:3592)
    aarch64_sme_umop4a_wide_1x1,               // llvm.aarch64.sme.umop4a.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_umop4a_wide_1x2,               // llvm.aarch64.sme.umop4a.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_umop4a_wide_2x1,               // llvm.aarch64.sme.umop4a.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_umop4a_wide_2x2,               // llvm.aarch64.sme.umop4a.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_umop4a_za64_wide_1x1,          // llvm.aarch64.sme.umop4a.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_umop4a_za64_wide_1x2,          // llvm.aarch64.sme.umop4a.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_umop4a_za64_wide_2x1,          // llvm.aarch64.sme.umop4a.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_umop4a_za64_wide_2x2,          // llvm.aarch64.sme.umop4a.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_umop4s_wide_1x1,               // llvm.aarch64.sme.umop4s.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_umop4s_wide_1x2,               // llvm.aarch64.sme.umop4s.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_umop4s_wide_2x1,               // llvm.aarch64.sme.umop4s.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_umop4s_wide_2x2,               // llvm.aarch64.sme.umop4s.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_umop4s_za64_wide_1x1,          // llvm.aarch64.sme.umop4s.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_umop4s_za64_wide_1x2,          // llvm.aarch64.sme.umop4s.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_umop4s_za64_wide_2x1,          // llvm.aarch64.sme.umop4s.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_umop4s_za64_wide_2x2,          // llvm.aarch64.sme.umop4s.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_umopa_wide,                    // llvm.aarch64.sme.umopa.wide (IntrinsicsAArch64.td:3050)
    aarch64_sme_umopa_za32,                    // llvm.aarch64.sme.umopa.za32 (IntrinsicsAArch64.td:3542)
    aarch64_sme_umops_wide,                    // llvm.aarch64.sme.umops.wide (IntrinsicsAArch64.td:3051)
    aarch64_sme_umops_za32,                    // llvm.aarch64.sme.umops.za32 (IntrinsicsAArch64.td:3544)
    aarch64_sme_usdot_lane_za32_vg1x2,         // llvm.aarch64.sme.usdot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3883)
    aarch64_sme_usdot_lane_za32_vg1x4,         // llvm.aarch64.sme.usdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3884)
    aarch64_sme_usdot_single_za32_vg1x2,       // llvm.aarch64.sme.usdot.single.za32.vg1x2 (IntrinsicsAArch64.td:3880)
    aarch64_sme_usdot_single_za32_vg1x4,       // llvm.aarch64.sme.usdot.single.za32.vg1x4 (IntrinsicsAArch64.td:3881)
    aarch64_sme_usdot_za32_vg1x2,              // llvm.aarch64.sme.usdot.za32.vg1x2 (IntrinsicsAArch64.td:3887)
    aarch64_sme_usdot_za32_vg1x4,              // llvm.aarch64.sme.usdot.za32.vg1x4 (IntrinsicsAArch64.td:3888)
    aarch64_sme_usmla_za32_lane_vg4x1,         // llvm.aarch64.sme.usmla.za32.lane.vg4x1 (IntrinsicsAArch64.td:3635)
    aarch64_sme_usmla_za32_lane_vg4x2,         // llvm.aarch64.sme.usmla.za32.lane.vg4x2 (IntrinsicsAArch64.td:3636)
    aarch64_sme_usmla_za32_lane_vg4x4,         // llvm.aarch64.sme.usmla.za32.lane.vg4x4 (IntrinsicsAArch64.td:3637)
    aarch64_sme_usmla_za32_single_vg4x1,       // llvm.aarch64.sme.usmla.za32.single.vg4x1 (IntrinsicsAArch64.td:3628)
    aarch64_sme_usmla_za32_single_vg4x2,       // llvm.aarch64.sme.usmla.za32.single.vg4x2 (IntrinsicsAArch64.td:3629)
    aarch64_sme_usmla_za32_single_vg4x4,       // llvm.aarch64.sme.usmla.za32.single.vg4x4 (IntrinsicsAArch64.td:3630)
    aarch64_sme_usmla_za32_vg4x2,              // llvm.aarch64.sme.usmla.za32.vg4x2 (IntrinsicsAArch64.td:3632)
    aarch64_sme_usmla_za32_vg4x4,              // llvm.aarch64.sme.usmla.za32.vg4x4 (IntrinsicsAArch64.td:3633)
    aarch64_sme_usmop4a_wide_1x1,              // llvm.aarch64.sme.usmop4a.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_usmop4a_wide_1x2,              // llvm.aarch64.sme.usmop4a.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_usmop4a_wide_2x1,              // llvm.aarch64.sme.usmop4a.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_usmop4a_wide_2x2,              // llvm.aarch64.sme.usmop4a.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_usmop4a_za64_wide_1x1,         // llvm.aarch64.sme.usmop4a.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_usmop4a_za64_wide_1x2,         // llvm.aarch64.sme.usmop4a.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_usmop4a_za64_wide_2x1,         // llvm.aarch64.sme.usmop4a.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_usmop4a_za64_wide_2x2,         // llvm.aarch64.sme.usmop4a.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_usmop4s_wide_1x1,              // llvm.aarch64.sme.usmop4s.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_usmop4s_wide_1x2,              // llvm.aarch64.sme.usmop4s.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_usmop4s_wide_2x1,              // llvm.aarch64.sme.usmop4s.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_usmop4s_wide_2x2,              // llvm.aarch64.sme.usmop4s.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_usmop4s_za64_wide_1x1,         // llvm.aarch64.sme.usmop4s.za64.wide.1x1 (IntrinsicsAArch64.td:3082)
    aarch64_sme_usmop4s_za64_wide_1x2,         // llvm.aarch64.sme.usmop4s.za64.wide.1x2 (IntrinsicsAArch64.td:3083)
    aarch64_sme_usmop4s_za64_wide_2x1,         // llvm.aarch64.sme.usmop4s.za64.wide.2x1 (IntrinsicsAArch64.td:3084)
    aarch64_sme_usmop4s_za64_wide_2x2,         // llvm.aarch64.sme.usmop4s.za64.wide.2x2 (IntrinsicsAArch64.td:3085)
    aarch64_sme_usmopa_wide,                   // llvm.aarch64.sme.usmopa.wide (IntrinsicsAArch64.td:3054)
    aarch64_sme_usmops_wide,                   // llvm.aarch64.sme.usmops.wide (IntrinsicsAArch64.td:3055)
    aarch64_sme_ustmopa_za32,                  // llvm.aarch64.sme.ustmopa.za32 (IntrinsicsAArch64.td:3116)
    aarch64_sme_usvdot_lane_za32_vg1x4,        // llvm.aarch64.sme.usvdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3722)
    aarch64_sme_utmopa_za32,                   // llvm.aarch64.sme.utmopa.za32 (IntrinsicsAArch64.td:3114)
    aarch64_sme_uvdot_lane_za32_vg1x2,         // llvm.aarch64.sme.uvdot.lane.za32.vg1x2 (IntrinsicsAArch64.td:3716)
    aarch64_sme_uvdot_lane_za32_vg1x4,         // llvm.aarch64.sme.uvdot.lane.za32.vg1x4 (IntrinsicsAArch64.td:3717)
    aarch64_sme_uvdot_lane_za64_vg1x4,         // llvm.aarch64.sme.uvdot.lane.za64.vg1x4 (IntrinsicsAArch64.td:3718)
    aarch64_sme_write_hor_vg2,                 // llvm.aarch64.sme.write.hor.vg2 (IntrinsicsAArch64.td:3850)
    aarch64_sme_write_hor_vg4,                 // llvm.aarch64.sme.write.hor.vg4 (IntrinsicsAArch64.td:3851)
    aarch64_sme_write_horiz,                   // llvm.aarch64.sme.write.horiz (IntrinsicsAArch64.td:2976)
    aarch64_sme_write_lane_zt,                 // llvm.aarch64.sme.write.lane.zt (IntrinsicsAArch64.td:3022)
    aarch64_sme_write_ver_vg2,                 // llvm.aarch64.sme.write.ver.vg2 (IntrinsicsAArch64.td:3853)
    aarch64_sme_write_ver_vg4,                 // llvm.aarch64.sme.write.ver.vg4 (IntrinsicsAArch64.td:3854)
    aarch64_sme_write_vert,                    // llvm.aarch64.sme.write.vert (IntrinsicsAArch64.td:2977)
    aarch64_sme_write_vg1x2,                   // llvm.aarch64.sme.write.vg1x2 (IntrinsicsAArch64.td:3856)
    aarch64_sme_write_vg1x4,                   // llvm.aarch64.sme.write.vg1x4 (IntrinsicsAArch64.td:3857)
    aarch64_sme_write_zt,                      // llvm.aarch64.sme.write.zt (IntrinsicsAArch64.td:3026)
    aarch64_sme_writeq_horiz,                  // llvm.aarch64.sme.writeq.horiz (IntrinsicsAArch64.td:2981)
    aarch64_sme_writeq_vert,                   // llvm.aarch64.sme.writeq.vert (IntrinsicsAArch64.td:2982)
    aarch64_sme_za_disable,                    // llvm.aarch64.sme.za.disable (IntrinsicsAArch64.td:3156)
    aarch64_sme_za_enable,                     // llvm.aarch64.sme.za.enable (IntrinsicsAArch64.td:3154)
    aarch64_sme_zero,                          // llvm.aarch64.sme.zero (IntrinsicsAArch64.td:3031)
    aarch64_sme_zero_za64_vg1x2,               // llvm.aarch64.sme.zero.za64.vg1x2 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_za64_vg1x4,               // llvm.aarch64.sme.zero.za64.vg1x4 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_za64_vg2x1,               // llvm.aarch64.sme.zero.za64.vg2x1 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_za64_vg2x2,               // llvm.aarch64.sme.zero.za64.vg2x2 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_za64_vg2x4,               // llvm.aarch64.sme.zero.za64.vg2x4 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_za64_vg4x1,               // llvm.aarch64.sme.zero.za64.vg4x1 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_za64_vg4x2,               // llvm.aarch64.sme.zero.za64.vg4x2 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_za64_vg4x4,               // llvm.aarch64.sme.zero.za64.vg4x4 (IntrinsicsAArch64.td:3648)
    aarch64_sme_zero_zt,                       // llvm.aarch64.sme.zero.zt (IntrinsicsAArch64.td:3938)
    aarch64_space,                             // llvm.aarch64.space (IntrinsicsAArch64.td:99)
    aarch64_st64b,                             // llvm.aarch64.st64b (IntrinsicsAArch64.td:955)
    aarch64_st64bv,                            // llvm.aarch64.st64bv (IntrinsicsAArch64.td:956)
    aarch64_st64bv0,                           // llvm.aarch64.st64bv0 (IntrinsicsAArch64.td:957)
    aarch64_stg,                               // llvm.aarch64.stg (IntrinsicsAArch64.td:903)
    aarch64_stgp,                              // llvm.aarch64.stgp (IntrinsicsAArch64.td:939)
    aarch64_stlxp,                             // llvm.aarch64.stlxp (IntrinsicsAArch64.td:31)
    aarch64_stlxr,                             // llvm.aarch64.stlxr (IntrinsicsAArch64.td:21)
    aarch64_stxp,                              // llvm.aarch64.stxp (IntrinsicsAArch64.td:28)
    aarch64_stxr,                              // llvm.aarch64.stxr (IntrinsicsAArch64.td:19)
    aarch64_subp,                              // llvm.aarch64.subp (IntrinsicsAArch64.td:905)
    aarch64_sve_abs,                           // llvm.aarch64.sve.abs (IntrinsicsAArch64.td:1849)
    aarch64_sve_adclb,                         // llvm.aarch64.sve.adclb (IntrinsicsAArch64.td:2720)
    aarch64_sve_adclt,                         // llvm.aarch64.sve.adclt (IntrinsicsAArch64.td:2721)
    aarch64_sve_add,                           // llvm.aarch64.sve.add (IntrinsicsAArch64.td:1792)
    aarch64_sve_add_single_x2,                 // llvm.aarch64.sve.add.single.x2 (IntrinsicsAArch64.td:3862)
    aarch64_sve_add_single_x4,                 // llvm.aarch64.sve.add.single.x4 (IntrinsicsAArch64.td:3863)
    aarch64_sve_add_u,                         // llvm.aarch64.sve.add.u (IntrinsicsAArch64.td:1793)
    aarch64_sve_addhnb,                        // llvm.aarch64.sve.addhnb (IntrinsicsAArch64.td:2636)
    aarch64_sve_addhnt,                        // llvm.aarch64.sve.addhnt (IntrinsicsAArch64.td:2637)
    aarch64_sve_addp,                          // llvm.aarch64.sve.addp (IntrinsicsAArch64.td:2545)
    aarch64_sve_addqv,                         // llvm.aarch64.sve.addqv (IntrinsicsAArch64.td:1866)
    aarch64_sve_adrb,                          // llvm.aarch64.sve.adrb (IntrinsicsAArch64.td:1783)
    aarch64_sve_adrd,                          // llvm.aarch64.sve.adrd (IntrinsicsAArch64.td:1786)
    aarch64_sve_adrh,                          // llvm.aarch64.sve.adrh (IntrinsicsAArch64.td:1784)
    aarch64_sve_adrw,                          // llvm.aarch64.sve.adrw (IntrinsicsAArch64.td:1785)
    aarch64_sve_aesd,                          // llvm.aarch64.sve.aesd (IntrinsicsAArch64.td:2748)
    aarch64_sve_aesd_lane_x2,                  // llvm.aarch64.sve.aesd.lane.x2 (IntrinsicsAArch64.td:4270)
    aarch64_sve_aesd_lane_x4,                  // llvm.aarch64.sve.aesd.lane.x4 (IntrinsicsAArch64.td:4275)
    aarch64_sve_aesdimc_lane_x2,               // llvm.aarch64.sve.aesdimc.lane.x2 (IntrinsicsAArch64.td:4271)
    aarch64_sve_aesdimc_lane_x4,               // llvm.aarch64.sve.aesdimc.lane.x4 (IntrinsicsAArch64.td:4276)
    aarch64_sve_aese,                          // llvm.aarch64.sve.aese (IntrinsicsAArch64.td:2756)
    aarch64_sve_aese_lane_x2,                  // llvm.aarch64.sve.aese.lane.x2 (IntrinsicsAArch64.td:4272)
    aarch64_sve_aese_lane_x4,                  // llvm.aarch64.sve.aese.lane.x4 (IntrinsicsAArch64.td:4277)
    aarch64_sve_aesemc_lane_x2,                // llvm.aarch64.sve.aesemc.lane.x2 (IntrinsicsAArch64.td:4273)
    aarch64_sve_aesemc_lane_x4,                // llvm.aarch64.sve.aesemc.lane.x4 (IntrinsicsAArch64.td:4278)
    aarch64_sve_aesimc,                        // llvm.aarch64.sve.aesimc (IntrinsicsAArch64.td:2752)
    aarch64_sve_aesmc,                         // llvm.aarch64.sve.aesmc (IntrinsicsAArch64.td:2760)
    aarch64_sve_and,                           // llvm.aarch64.sve.and (IntrinsicsAArch64.td:2075)
    aarch64_sve_and_u,                         // llvm.aarch64.sve.and.u (IntrinsicsAArch64.td:2076)
    aarch64_sve_and_z,                         // llvm.aarch64.sve.and.z (IntrinsicsAArch64.td:2272)
    aarch64_sve_andqv,                         // llvm.aarch64.sve.andqv (IntrinsicsAArch64.td:1865)
    aarch64_sve_andv,                          // llvm.aarch64.sve.andv (IntrinsicsAArch64.td:1847)
    aarch64_sve_asr,                           // llvm.aarch64.sve.asr (IntrinsicsAArch64.td:1874)
    aarch64_sve_asr_u,                         // llvm.aarch64.sve.asr.u (IntrinsicsAArch64.td:1875)
    aarch64_sve_asr_wide,                      // llvm.aarch64.sve.asr.wide (IntrinsicsAArch64.td:1876)
    aarch64_sve_asrd,                          // llvm.aarch64.sve.asrd (IntrinsicsAArch64.td:1877)
    aarch64_sve_bcax,                          // llvm.aarch64.sve.bcax (IntrinsicsAArch64.td:2737)
    aarch64_sve_bdep_x,                        // llvm.aarch64.sve.bdep.x (IntrinsicsAArch64.td:2800)
    aarch64_sve_bext_x,                        // llvm.aarch64.sve.bext.x (IntrinsicsAArch64.td:2801)
    aarch64_sve_bfclamp_single_x2,             // llvm.aarch64.sve.bfclamp.single.x2 (IntrinsicsAArch64.td:3820)
    aarch64_sve_bfclamp_single_x4,             // llvm.aarch64.sve.bfclamp.single.x4 (IntrinsicsAArch64.td:3825)
    aarch64_sve_bfcvt_x2,                      // llvm.aarch64.sve.bfcvt.x2 (IntrinsicsAArch64.td:3740)
    aarch64_sve_bfcvtn_x2,                     // llvm.aarch64.sve.bfcvtn.x2 (IntrinsicsAArch64.td:3734)
    aarch64_sve_bfdot,                         // llvm.aarch64.sve.bfdot (IntrinsicsAArch64.td:2834)
    aarch64_sve_bfdot_lane_v2,                 // llvm.aarch64.sve.bfdot.lane.v2 (IntrinsicsAArch64.td:2840)
    aarch64_sve_bfmlalb,                       // llvm.aarch64.sve.bfmlalb (IntrinsicsAArch64.td:2835)
    aarch64_sve_bfmlalb_lane_v2,               // llvm.aarch64.sve.bfmlalb.lane.v2 (IntrinsicsAArch64.td:2841)
    aarch64_sve_bfmlalt,                       // llvm.aarch64.sve.bfmlalt (IntrinsicsAArch64.td:2836)
    aarch64_sve_bfmlalt_lane_v2,               // llvm.aarch64.sve.bfmlalt.lane.v2 (IntrinsicsAArch64.td:2842)
    aarch64_sve_bfmlslb,                       // llvm.aarch64.sve.bfmlslb (IntrinsicsAArch64.td:3639)
    aarch64_sve_bfmlslb_lane,                  // llvm.aarch64.sve.bfmlslb.lane (IntrinsicsAArch64.td:3640)
    aarch64_sve_bfmlslt,                       // llvm.aarch64.sve.bfmlslt (IntrinsicsAArch64.td:3642)
    aarch64_sve_bfmlslt_lane,                  // llvm.aarch64.sve.bfmlslt.lane (IntrinsicsAArch64.td:3643)
    aarch64_sve_bfmmla,                        // llvm.aarch64.sve.bfmmla (IntrinsicsAArch64.td:2838)
    aarch64_sve_bgrp_x,                        // llvm.aarch64.sve.bgrp.x (IntrinsicsAArch64.td:2802)
    aarch64_sve_bic,                           // llvm.aarch64.sve.bic (IntrinsicsAArch64.td:2077)
    aarch64_sve_bic_u,                         // llvm.aarch64.sve.bic.u (IntrinsicsAArch64.td:2078)
    aarch64_sve_bic_z,                         // llvm.aarch64.sve.bic.z (IntrinsicsAArch64.td:2273)
    aarch64_sve_brka,                          // llvm.aarch64.sve.brka (IntrinsicsAArch64.td:2274)
    aarch64_sve_brka_z,                        // llvm.aarch64.sve.brka.z (IntrinsicsAArch64.td:2275)
    aarch64_sve_brkb,                          // llvm.aarch64.sve.brkb (IntrinsicsAArch64.td:2276)
    aarch64_sve_brkb_z,                        // llvm.aarch64.sve.brkb.z (IntrinsicsAArch64.td:2277)
    aarch64_sve_brkn_z,                        // llvm.aarch64.sve.brkn.z (IntrinsicsAArch64.td:2278)
    aarch64_sve_brkpa_z,                       // llvm.aarch64.sve.brkpa.z (IntrinsicsAArch64.td:2279)
    aarch64_sve_brkpb_z,                       // llvm.aarch64.sve.brkpb.z (IntrinsicsAArch64.td:2280)
    aarch64_sve_bsl,                           // llvm.aarch64.sve.bsl (IntrinsicsAArch64.td:2738)
    aarch64_sve_bsl1n,                         // llvm.aarch64.sve.bsl1n (IntrinsicsAArch64.td:2739)
    aarch64_sve_bsl2n,                         // llvm.aarch64.sve.bsl2n (IntrinsicsAArch64.td:2740)
    aarch64_sve_cadd_x,                        // llvm.aarch64.sve.cadd.x (IntrinsicsAArch64.td:2567)
    aarch64_sve_cdot,                          // llvm.aarch64.sve.cdot (IntrinsicsAArch64.td:2586)
    aarch64_sve_cdot_lane,                     // llvm.aarch64.sve.cdot.lane (IntrinsicsAArch64.td:2587)
    aarch64_sve_clasta,                        // llvm.aarch64.sve.clasta (IntrinsicsAArch64.td:2019)
    aarch64_sve_clasta_n,                      // llvm.aarch64.sve.clasta.n (IntrinsicsAArch64.td:2020)
    aarch64_sve_clastb,                        // llvm.aarch64.sve.clastb (IntrinsicsAArch64.td:2021)
    aarch64_sve_clastb_n,                      // llvm.aarch64.sve.clastb.n (IntrinsicsAArch64.td:2022)
    aarch64_sve_cls,                           // llvm.aarch64.sve.cls (IntrinsicsAArch64.td:1912)
    aarch64_sve_clz,                           // llvm.aarch64.sve.clz (IntrinsicsAArch64.td:1913)
    aarch64_sve_cmla_lane_x,                   // llvm.aarch64.sve.cmla.lane.x (IntrinsicsAArch64.td:2570)
    aarch64_sve_cmla_x,                        // llvm.aarch64.sve.cmla.x (IntrinsicsAArch64.td:2569)
    aarch64_sve_cmpeq,                         // llvm.aarch64.sve.cmpeq (IntrinsicsAArch64.td:1890)
    aarch64_sve_cmpeq_wide,                    // llvm.aarch64.sve.cmpeq.wide (IntrinsicsAArch64.td:1897)
    aarch64_sve_cmpge,                         // llvm.aarch64.sve.cmpge (IntrinsicsAArch64.td:1891)
    aarch64_sve_cmpge_wide,                    // llvm.aarch64.sve.cmpge.wide (IntrinsicsAArch64.td:1898)
    aarch64_sve_cmpgt,                         // llvm.aarch64.sve.cmpgt (IntrinsicsAArch64.td:1892)
    aarch64_sve_cmpgt_wide,                    // llvm.aarch64.sve.cmpgt.wide (IntrinsicsAArch64.td:1899)
    aarch64_sve_cmphi,                         // llvm.aarch64.sve.cmphi (IntrinsicsAArch64.td:1893)
    aarch64_sve_cmphi_wide,                    // llvm.aarch64.sve.cmphi.wide (IntrinsicsAArch64.td:1900)
    aarch64_sve_cmphs,                         // llvm.aarch64.sve.cmphs (IntrinsicsAArch64.td:1894)
    aarch64_sve_cmphs_wide,                    // llvm.aarch64.sve.cmphs.wide (IntrinsicsAArch64.td:1901)
    aarch64_sve_cmple_wide,                    // llvm.aarch64.sve.cmple.wide (IntrinsicsAArch64.td:1902)
    aarch64_sve_cmplo_wide,                    // llvm.aarch64.sve.cmplo.wide (IntrinsicsAArch64.td:1903)
    aarch64_sve_cmpls_wide,                    // llvm.aarch64.sve.cmpls.wide (IntrinsicsAArch64.td:1904)
    aarch64_sve_cmplt_wide,                    // llvm.aarch64.sve.cmplt.wide (IntrinsicsAArch64.td:1905)
    aarch64_sve_cmpne,                         // llvm.aarch64.sve.cmpne (IntrinsicsAArch64.td:1895)
    aarch64_sve_cmpne_wide,                    // llvm.aarch64.sve.cmpne.wide (IntrinsicsAArch64.td:1906)
    aarch64_sve_cnot,                          // llvm.aarch64.sve.cnot (IntrinsicsAArch64.td:2079)
    aarch64_sve_cnt,                           // llvm.aarch64.sve.cnt (IntrinsicsAArch64.td:1914)
    aarch64_sve_cntb,                          // llvm.aarch64.sve.cntb (IntrinsicsAArch64.td:1920)
    aarch64_sve_cntd,                          // llvm.aarch64.sve.cntd (IntrinsicsAArch64.td:1923)
    aarch64_sve_cnth,                          // llvm.aarch64.sve.cnth (IntrinsicsAArch64.td:1921)
    aarch64_sve_cntp,                          // llvm.aarch64.sve.cntp (IntrinsicsAArch64.td:1925)
    aarch64_sve_cntp_c16,                      // llvm.aarch64.sve.cntp.c16 (IntrinsicsAArch64.td:3218)
    aarch64_sve_cntp_c32,                      // llvm.aarch64.sve.cntp.c32 (IntrinsicsAArch64.td:3221)
    aarch64_sve_cntp_c64,                      // llvm.aarch64.sve.cntp.c64 (IntrinsicsAArch64.td:3224)
    aarch64_sve_cntp_c8,                       // llvm.aarch64.sve.cntp.c8 (IntrinsicsAArch64.td:3215)
    aarch64_sve_cntw,                          // llvm.aarch64.sve.cntw (IntrinsicsAArch64.td:1922)
    aarch64_sve_compact,                       // llvm.aarch64.sve.compact (IntrinsicsAArch64.td:2023)
    aarch64_sve_convert_from_svbool,           // llvm.aarch64.sve.convert.from.svbool (IntrinsicsAArch64.td:2303)
    aarch64_sve_convert_to_svbool,             // llvm.aarch64.sve.convert.to.svbool (IntrinsicsAArch64.td:2307)
    aarch64_sve_dup,                           // llvm.aarch64.sve.dup (IntrinsicsAArch64.td:1774)
    aarch64_sve_dup_laneq,                     // llvm.aarch64.sve.dup.laneq (IntrinsicsAArch64.td:2026)
    aarch64_sve_dup_x,                         // llvm.aarch64.sve.dup.x (IntrinsicsAArch64.td:1775)
    aarch64_sve_dupq_lane,                     // llvm.aarch64.sve.dupq.lane (IntrinsicsAArch64.td:2025)
    aarch64_sve_eor,                           // llvm.aarch64.sve.eor (IntrinsicsAArch64.td:2080)
    aarch64_sve_eor_u,                         // llvm.aarch64.sve.eor.u (IntrinsicsAArch64.td:2081)
    aarch64_sve_eor_z,                         // llvm.aarch64.sve.eor.z (IntrinsicsAArch64.td:2281)
    aarch64_sve_eor3,                          // llvm.aarch64.sve.eor3 (IntrinsicsAArch64.td:2736)
    aarch64_sve_eorbt,                         // llvm.aarch64.sve.eorbt (IntrinsicsAArch64.td:2728)
    aarch64_sve_eorqv,                         // llvm.aarch64.sve.eorqv (IntrinsicsAArch64.td:1864)
    aarch64_sve_eortb,                         // llvm.aarch64.sve.eortb (IntrinsicsAArch64.td:2729)
    aarch64_sve_eorv,                          // llvm.aarch64.sve.eorv (IntrinsicsAArch64.td:1846)
    aarch64_sve_expand,                        // llvm.aarch64.sve.expand (IntrinsicsAArch64.td:2024)
    aarch64_sve_ext,                           // llvm.aarch64.sve.ext (IntrinsicsAArch64.td:2027)
    aarch64_sve_extq,                          // llvm.aarch64.sve.extq (IntrinsicsAArch64.td:4019)
    aarch64_sve_fabd,                          // llvm.aarch64.sve.fabd (IntrinsicsAArch64.td:2114)
    aarch64_sve_fabd_u,                        // llvm.aarch64.sve.fabd.u (IntrinsicsAArch64.td:2115)
    aarch64_sve_fabs,                          // llvm.aarch64.sve.fabs (IntrinsicsAArch64.td:2116)
    aarch64_sve_facge,                         // llvm.aarch64.sve.facge (IntrinsicsAArch64.td:2210)
    aarch64_sve_facgt,                         // llvm.aarch64.sve.facgt (IntrinsicsAArch64.td:2211)
    aarch64_sve_fadd,                          // llvm.aarch64.sve.fadd (IntrinsicsAArch64.td:2117)
    aarch64_sve_fadd_u,                        // llvm.aarch64.sve.fadd.u (IntrinsicsAArch64.td:2118)
    aarch64_sve_fadda,                         // llvm.aarch64.sve.fadda (IntrinsicsAArch64.td:2183)
    aarch64_sve_faddp,                         // llvm.aarch64.sve.faddp (IntrinsicsAArch64.td:2546)
    aarch64_sve_faddqv,                        // llvm.aarch64.sve.faddqv (IntrinsicsAArch64.td:2190)
    aarch64_sve_faddv,                         // llvm.aarch64.sve.faddv (IntrinsicsAArch64.td:2184)
    aarch64_sve_famax,                         // llvm.aarch64.sve.famax (IntrinsicsAArch64.td:4036)
    aarch64_sve_famax_u,                       // llvm.aarch64.sve.famax.u (IntrinsicsAArch64.td:4037)
    aarch64_sve_famin,                         // llvm.aarch64.sve.famin (IntrinsicsAArch64.td:4039)
    aarch64_sve_famin_u,                       // llvm.aarch64.sve.famin.u (IntrinsicsAArch64.td:4040)
    aarch64_sve_fcadd,                         // llvm.aarch64.sve.fcadd (IntrinsicsAArch64.td:2119)
    aarch64_sve_fclamp,                        // llvm.aarch64.sve.fclamp (IntrinsicsAArch64.td:3164)
    aarch64_sve_fclamp_single_x2,              // llvm.aarch64.sve.fclamp.single.x2 (IntrinsicsAArch64.td:3819)
    aarch64_sve_fclamp_single_x4,              // llvm.aarch64.sve.fclamp.single.x4 (IntrinsicsAArch64.td:3824)
    aarch64_sve_fcmla,                         // llvm.aarch64.sve.fcmla (IntrinsicsAArch64.td:2120)
    aarch64_sve_fcmla_lane,                    // llvm.aarch64.sve.fcmla.lane (IntrinsicsAArch64.td:2121)
    aarch64_sve_fcmpeq,                        // llvm.aarch64.sve.fcmpeq (IntrinsicsAArch64.td:2213)
    aarch64_sve_fcmpge,                        // llvm.aarch64.sve.fcmpge (IntrinsicsAArch64.td:2214)
    aarch64_sve_fcmpgt,                        // llvm.aarch64.sve.fcmpgt (IntrinsicsAArch64.td:2215)
    aarch64_sve_fcmpne,                        // llvm.aarch64.sve.fcmpne (IntrinsicsAArch64.td:2216)
    aarch64_sve_fcmpuo,                        // llvm.aarch64.sve.fcmpuo (IntrinsicsAArch64.td:2217)
    aarch64_sve_fcvt,                          // llvm.aarch64.sve.fcvt (IntrinsicsAArch64.td:2200)
    aarch64_sve_fcvt_bf16f32_v2,               // llvm.aarch64.sve.fcvt.bf16f32.v2 (IntrinsicsAArch64.td:2224)
    aarch64_sve_fcvt_f16f32,                   // llvm.aarch64.sve.fcvt.f16f32 (IntrinsicsAArch64.td:2233)
    aarch64_sve_fcvt_f16f64,                   // llvm.aarch64.sve.fcvt.f16f64 (IntrinsicsAArch64.td:2234)
    aarch64_sve_fcvt_f32f16,                   // llvm.aarch64.sve.fcvt.f32f16 (IntrinsicsAArch64.td:2237)
    aarch64_sve_fcvt_f32f64,                   // llvm.aarch64.sve.fcvt.f32f64 (IntrinsicsAArch64.td:2235)
    aarch64_sve_fcvt_f64f16,                   // llvm.aarch64.sve.fcvt.f64f16 (IntrinsicsAArch64.td:2238)
    aarch64_sve_fcvt_f64f32,                   // llvm.aarch64.sve.fcvt.f64f32 (IntrinsicsAArch64.td:2239)
    aarch64_sve_fcvt_widen_x2,                 // llvm.aarch64.sve.fcvt.widen.x2 (IntrinsicsAArch64.td:3749)
    aarch64_sve_fcvt_x2,                       // llvm.aarch64.sve.fcvt.x2 (IntrinsicsAArch64.td:3739)
    aarch64_sve_fcvtl_widen_x2,                // llvm.aarch64.sve.fcvtl.widen.x2 (IntrinsicsAArch64.td:3728)
    aarch64_sve_fcvtlt_f32f16,                 // llvm.aarch64.sve.fcvtlt.f32f16 (IntrinsicsAArch64.td:2241)
    aarch64_sve_fcvtlt_f64f32,                 // llvm.aarch64.sve.fcvtlt.f64f32 (IntrinsicsAArch64.td:2242)
    aarch64_sve_fcvtn_x2,                      // llvm.aarch64.sve.fcvtn.x2 (IntrinsicsAArch64.td:3733)
    aarch64_sve_fcvtnt_bf16f32_v2,             // llvm.aarch64.sve.fcvtnt.bf16f32.v2 (IntrinsicsAArch64.td:2225)
    aarch64_sve_fcvtnt_f16f32,                 // llvm.aarch64.sve.fcvtnt.f16f32 (IntrinsicsAArch64.td:2243)
    aarch64_sve_fcvtnt_f32f64,                 // llvm.aarch64.sve.fcvtnt.f32f64 (IntrinsicsAArch64.td:2245)
    aarch64_sve_fcvtnt_z_bf16f32,              // llvm.aarch64.sve.fcvtnt.z.bf16f32 (IntrinsicsAArch64.td:2226)
    aarch64_sve_fcvtnt_z_f16f32,               // llvm.aarch64.sve.fcvtnt.z.f16f32 (IntrinsicsAArch64.td:2244)
    aarch64_sve_fcvtnt_z_f32f64,               // llvm.aarch64.sve.fcvtnt.z.f32f64 (IntrinsicsAArch64.td:2246)
    aarch64_sve_fcvtx_f32f64,                  // llvm.aarch64.sve.fcvtx.f32f64 (IntrinsicsAArch64.td:2248)
    aarch64_sve_fcvtxnt_f32f64,                // llvm.aarch64.sve.fcvtxnt.f32f64 (IntrinsicsAArch64.td:2249)
    aarch64_sve_fcvtxnt_z_f32f64,              // llvm.aarch64.sve.fcvtxnt.z.f32f64 (IntrinsicsAArch64.td:2250)
    aarch64_sve_fcvtzs,                        // llvm.aarch64.sve.fcvtzs (IntrinsicsAArch64.td:2201)
    aarch64_sve_fcvtzs_i32f16,                 // llvm.aarch64.sve.fcvtzs.i32f16 (IntrinsicsAArch64.td:2219)
    aarch64_sve_fcvtzs_i32f64,                 // llvm.aarch64.sve.fcvtzs.i32f64 (IntrinsicsAArch64.td:2220)
    aarch64_sve_fcvtzs_i64f16,                 // llvm.aarch64.sve.fcvtzs.i64f16 (IntrinsicsAArch64.td:2221)
    aarch64_sve_fcvtzs_i64f32,                 // llvm.aarch64.sve.fcvtzs.i64f32 (IntrinsicsAArch64.td:2222)
    aarch64_sve_fcvtzs_x2,                     // llvm.aarch64.sve.fcvtzs.x2 (IntrinsicsAArch64.td:3741)
    aarch64_sve_fcvtzs_x4,                     // llvm.aarch64.sve.fcvtzs.x4 (IntrinsicsAArch64.td:3745)
    aarch64_sve_fcvtzu,                        // llvm.aarch64.sve.fcvtzu (IntrinsicsAArch64.td:2202)
    aarch64_sve_fcvtzu_i32f16,                 // llvm.aarch64.sve.fcvtzu.i32f16 (IntrinsicsAArch64.td:2228)
    aarch64_sve_fcvtzu_i32f64,                 // llvm.aarch64.sve.fcvtzu.i32f64 (IntrinsicsAArch64.td:2229)
    aarch64_sve_fcvtzu_i64f16,                 // llvm.aarch64.sve.fcvtzu.i64f16 (IntrinsicsAArch64.td:2230)
    aarch64_sve_fcvtzu_i64f32,                 // llvm.aarch64.sve.fcvtzu.i64f32 (IntrinsicsAArch64.td:2231)
    aarch64_sve_fcvtzu_x2,                     // llvm.aarch64.sve.fcvtzu.x2 (IntrinsicsAArch64.td:3742)
    aarch64_sve_fcvtzu_x4,                     // llvm.aarch64.sve.fcvtzu.x4 (IntrinsicsAArch64.td:3746)
    aarch64_sve_fdiv,                          // llvm.aarch64.sve.fdiv (IntrinsicsAArch64.td:2122)
    aarch64_sve_fdiv_u,                        // llvm.aarch64.sve.fdiv.u (IntrinsicsAArch64.td:2123)
    aarch64_sve_fdivr,                         // llvm.aarch64.sve.fdivr (IntrinsicsAArch64.td:2124)
    aarch64_sve_fdot_lane_x2,                  // llvm.aarch64.sve.fdot.lane.x2 (IntrinsicsAArch64.td:3916)
    aarch64_sve_fdot_x2,                       // llvm.aarch64.sve.fdot.x2 (IntrinsicsAArch64.td:3913)
    aarch64_sve_fexpa_x,                       // llvm.aarch64.sve.fexpa.x (IntrinsicsAArch64.td:2125)
    aarch64_sve_firstp,                        // llvm.aarch64.sve.firstp (IntrinsicsAArch64.td:1926)
    aarch64_sve_flogb,                         // llvm.aarch64.sve.flogb (IntrinsicsAArch64.td:2606)
    aarch64_sve_fmad,                          // llvm.aarch64.sve.fmad (IntrinsicsAArch64.td:2126)
    aarch64_sve_fmax,                          // llvm.aarch64.sve.fmax (IntrinsicsAArch64.td:2127)
    aarch64_sve_fmax_single_x2,                // llvm.aarch64.sve.fmax.single.x2 (IntrinsicsAArch64.td:3670)
    aarch64_sve_fmax_single_x4,                // llvm.aarch64.sve.fmax.single.x4 (IntrinsicsAArch64.td:3671)
    aarch64_sve_fmax_u,                        // llvm.aarch64.sve.fmax.u (IntrinsicsAArch64.td:2128)
    aarch64_sve_fmax_x2,                       // llvm.aarch64.sve.fmax.x2 (IntrinsicsAArch64.td:3673)
    aarch64_sve_fmax_x4,                       // llvm.aarch64.sve.fmax.x4 (IntrinsicsAArch64.td:3674)
    aarch64_sve_fmaxnm,                        // llvm.aarch64.sve.fmaxnm (IntrinsicsAArch64.td:2129)
    aarch64_sve_fmaxnm_single_x2,              // llvm.aarch64.sve.fmaxnm.single.x2 (IntrinsicsAArch64.td:3683)
    aarch64_sve_fmaxnm_single_x4,              // llvm.aarch64.sve.fmaxnm.single.x4 (IntrinsicsAArch64.td:3684)
    aarch64_sve_fmaxnm_u,                      // llvm.aarch64.sve.fmaxnm.u (IntrinsicsAArch64.td:2130)
    aarch64_sve_fmaxnm_x2,                     // llvm.aarch64.sve.fmaxnm.x2 (IntrinsicsAArch64.td:3686)
    aarch64_sve_fmaxnm_x4,                     // llvm.aarch64.sve.fmaxnm.x4 (IntrinsicsAArch64.td:3687)
    aarch64_sve_fmaxnmp,                       // llvm.aarch64.sve.fmaxnmp (IntrinsicsAArch64.td:2548)
    aarch64_sve_fmaxnmqv,                      // llvm.aarch64.sve.fmaxnmqv (IntrinsicsAArch64.td:2191)
    aarch64_sve_fmaxnmv,                       // llvm.aarch64.sve.fmaxnmv (IntrinsicsAArch64.td:2186)
    aarch64_sve_fmaxp,                         // llvm.aarch64.sve.fmaxp (IntrinsicsAArch64.td:2547)
    aarch64_sve_fmaxqv,                        // llvm.aarch64.sve.fmaxqv (IntrinsicsAArch64.td:2193)
    aarch64_sve_fmaxv,                         // llvm.aarch64.sve.fmaxv (IntrinsicsAArch64.td:2185)
    aarch64_sve_fmin,                          // llvm.aarch64.sve.fmin (IntrinsicsAArch64.td:2131)
    aarch64_sve_fmin_single_x2,                // llvm.aarch64.sve.fmin.single.x2 (IntrinsicsAArch64.td:3670)
    aarch64_sve_fmin_single_x4,                // llvm.aarch64.sve.fmin.single.x4 (IntrinsicsAArch64.td:3671)
    aarch64_sve_fmin_u,                        // llvm.aarch64.sve.fmin.u (IntrinsicsAArch64.td:2132)
    aarch64_sve_fmin_x2,                       // llvm.aarch64.sve.fmin.x2 (IntrinsicsAArch64.td:3673)
    aarch64_sve_fmin_x4,                       // llvm.aarch64.sve.fmin.x4 (IntrinsicsAArch64.td:3674)
    aarch64_sve_fminnm,                        // llvm.aarch64.sve.fminnm (IntrinsicsAArch64.td:2133)
    aarch64_sve_fminnm_single_x2,              // llvm.aarch64.sve.fminnm.single.x2 (IntrinsicsAArch64.td:3683)
    aarch64_sve_fminnm_single_x4,              // llvm.aarch64.sve.fminnm.single.x4 (IntrinsicsAArch64.td:3684)
    aarch64_sve_fminnm_u,                      // llvm.aarch64.sve.fminnm.u (IntrinsicsAArch64.td:2134)
    aarch64_sve_fminnm_x2,                     // llvm.aarch64.sve.fminnm.x2 (IntrinsicsAArch64.td:3686)
    aarch64_sve_fminnm_x4,                     // llvm.aarch64.sve.fminnm.x4 (IntrinsicsAArch64.td:3687)
    aarch64_sve_fminnmp,                       // llvm.aarch64.sve.fminnmp (IntrinsicsAArch64.td:2550)
    aarch64_sve_fminnmqv,                      // llvm.aarch64.sve.fminnmqv (IntrinsicsAArch64.td:2192)
    aarch64_sve_fminnmv,                       // llvm.aarch64.sve.fminnmv (IntrinsicsAArch64.td:2188)
    aarch64_sve_fminp,                         // llvm.aarch64.sve.fminp (IntrinsicsAArch64.td:2549)
    aarch64_sve_fminqv,                        // llvm.aarch64.sve.fminqv (IntrinsicsAArch64.td:2194)
    aarch64_sve_fminv,                         // llvm.aarch64.sve.fminv (IntrinsicsAArch64.td:2187)
    aarch64_sve_fmla,                          // llvm.aarch64.sve.fmla (IntrinsicsAArch64.td:2135)
    aarch64_sve_fmla_lane,                     // llvm.aarch64.sve.fmla.lane (IntrinsicsAArch64.td:2136)
    aarch64_sve_fmla_u,                        // llvm.aarch64.sve.fmla.u (IntrinsicsAArch64.td:2137)
    aarch64_sve_fmlalb,                        // llvm.aarch64.sve.fmlalb (IntrinsicsAArch64.td:2593)
    aarch64_sve_fmlalb_lane,                   // llvm.aarch64.sve.fmlalb.lane (IntrinsicsAArch64.td:2594)
    aarch64_sve_fmlalt,                        // llvm.aarch64.sve.fmlalt (IntrinsicsAArch64.td:2595)
    aarch64_sve_fmlalt_lane,                   // llvm.aarch64.sve.fmlalt.lane (IntrinsicsAArch64.td:2596)
    aarch64_sve_fmls,                          // llvm.aarch64.sve.fmls (IntrinsicsAArch64.td:2138)
    aarch64_sve_fmls_lane,                     // llvm.aarch64.sve.fmls.lane (IntrinsicsAArch64.td:2139)
    aarch64_sve_fmls_u,                        // llvm.aarch64.sve.fmls.u (IntrinsicsAArch64.td:2140)
    aarch64_sve_fmlslb,                        // llvm.aarch64.sve.fmlslb (IntrinsicsAArch64.td:2597)
    aarch64_sve_fmlslb_lane,                   // llvm.aarch64.sve.fmlslb.lane (IntrinsicsAArch64.td:2598)
    aarch64_sve_fmlslt,                        // llvm.aarch64.sve.fmlslt (IntrinsicsAArch64.td:2599)
    aarch64_sve_fmlslt_lane,                   // llvm.aarch64.sve.fmlslt.lane (IntrinsicsAArch64.td:2600)
    aarch64_sve_fmmla,                         // llvm.aarch64.sve.fmmla (IntrinsicsAArch64.td:2820)
    aarch64_sve_fmsb,                          // llvm.aarch64.sve.fmsb (IntrinsicsAArch64.td:2141)
    aarch64_sve_fmul,                          // llvm.aarch64.sve.fmul (IntrinsicsAArch64.td:2142)
    aarch64_sve_fmul_lane,                     // llvm.aarch64.sve.fmul.lane (IntrinsicsAArch64.td:2143)
    aarch64_sve_fmul_single_x2,                // llvm.aarch64.sve.fmul.single.x2 (IntrinsicsAArch64.td:3683)
    aarch64_sve_fmul_single_x4,                // llvm.aarch64.sve.fmul.single.x4 (IntrinsicsAArch64.td:3684)
    aarch64_sve_fmul_u,                        // llvm.aarch64.sve.fmul.u (IntrinsicsAArch64.td:2144)
    aarch64_sve_fmul_x2,                       // llvm.aarch64.sve.fmul.x2 (IntrinsicsAArch64.td:3686)
    aarch64_sve_fmul_x4,                       // llvm.aarch64.sve.fmul.x4 (IntrinsicsAArch64.td:3687)
    aarch64_sve_fmulx,                         // llvm.aarch64.sve.fmulx (IntrinsicsAArch64.td:2145)
    aarch64_sve_fmulx_u,                       // llvm.aarch64.sve.fmulx.u (IntrinsicsAArch64.td:2146)
    aarch64_sve_fneg,                          // llvm.aarch64.sve.fneg (IntrinsicsAArch64.td:2147)
    aarch64_sve_fnmad,                         // llvm.aarch64.sve.fnmad (IntrinsicsAArch64.td:2148)
    aarch64_sve_fnmla,                         // llvm.aarch64.sve.fnmla (IntrinsicsAArch64.td:2149)
    aarch64_sve_fnmla_u,                       // llvm.aarch64.sve.fnmla.u (IntrinsicsAArch64.td:2150)
    aarch64_sve_fnmls,                         // llvm.aarch64.sve.fnmls (IntrinsicsAArch64.td:2151)
    aarch64_sve_fnmls_u,                       // llvm.aarch64.sve.fnmls.u (IntrinsicsAArch64.td:2152)
    aarch64_sve_fnmsb,                         // llvm.aarch64.sve.fnmsb (IntrinsicsAArch64.td:2153)
    aarch64_sve_fp8_cvt_x2,                    // llvm.aarch64.sve.fp8.cvt.x2 (IntrinsicsAArch64.td:4191)
    aarch64_sve_fp8_cvt_x4,                    // llvm.aarch64.sve.fp8.cvt.x4 (IntrinsicsAArch64.td:4196)
    aarch64_sve_fp8_cvt1,                      // llvm.aarch64.sve.fp8.cvt1 (IntrinsicsAArch64.td:4056)
    aarch64_sve_fp8_cvt1_x2,                   // llvm.aarch64.sve.fp8.cvt1.x2 (IntrinsicsAArch64.td:4179)
    aarch64_sve_fp8_cvt2,                      // llvm.aarch64.sve.fp8.cvt2 (IntrinsicsAArch64.td:4057)
    aarch64_sve_fp8_cvt2_x2,                   // llvm.aarch64.sve.fp8.cvt2.x2 (IntrinsicsAArch64.td:4180)
    aarch64_sve_fp8_cvtl1_x2,                  // llvm.aarch64.sve.fp8.cvtl1.x2 (IntrinsicsAArch64.td:4185)
    aarch64_sve_fp8_cvtl2_x2,                  // llvm.aarch64.sve.fp8.cvtl2.x2 (IntrinsicsAArch64.td:4186)
    aarch64_sve_fp8_cvtlt1,                    // llvm.aarch64.sve.fp8.cvtlt1 (IntrinsicsAArch64.td:4058)
    aarch64_sve_fp8_cvtlt2,                    // llvm.aarch64.sve.fp8.cvtlt2 (IntrinsicsAArch64.td:4059)
    aarch64_sve_fp8_cvtn,                      // llvm.aarch64.sve.fp8.cvtn (IntrinsicsAArch64.td:4067)
    aarch64_sve_fp8_cvtn_x4,                   // llvm.aarch64.sve.fp8.cvtn.x4 (IntrinsicsAArch64.td:4197)
    aarch64_sve_fp8_cvtnb,                     // llvm.aarch64.sve.fp8.cvtnb (IntrinsicsAArch64.td:4068)
    aarch64_sve_fp8_cvtnt,                     // llvm.aarch64.sve.fp8.cvtnt (IntrinsicsAArch64.td:4070)
    aarch64_sve_fp8_fdot,                      // llvm.aarch64.sve.fp8.fdot (IntrinsicsAArch64.td:4088)
    aarch64_sve_fp8_fdot_lane,                 // llvm.aarch64.sve.fp8.fdot.lane (IntrinsicsAArch64.td:4089)
    aarch64_sve_fp8_fmlalb,                    // llvm.aarch64.sve.fp8.fmlalb (IntrinsicsAArch64.td:4092)
    aarch64_sve_fp8_fmlalb_lane,               // llvm.aarch64.sve.fp8.fmlalb.lane (IntrinsicsAArch64.td:4093)
    aarch64_sve_fp8_fmlallbb,                  // llvm.aarch64.sve.fp8.fmlallbb (IntrinsicsAArch64.td:4098)
    aarch64_sve_fp8_fmlallbb_lane,             // llvm.aarch64.sve.fp8.fmlallbb.lane (IntrinsicsAArch64.td:4099)
    aarch64_sve_fp8_fmlallbt,                  // llvm.aarch64.sve.fp8.fmlallbt (IntrinsicsAArch64.td:4101)
    aarch64_sve_fp8_fmlallbt_lane,             // llvm.aarch64.sve.fp8.fmlallbt.lane (IntrinsicsAArch64.td:4102)
    aarch64_sve_fp8_fmlalltb,                  // llvm.aarch64.sve.fp8.fmlalltb (IntrinsicsAArch64.td:4104)
    aarch64_sve_fp8_fmlalltb_lane,             // llvm.aarch64.sve.fp8.fmlalltb.lane (IntrinsicsAArch64.td:4105)
    aarch64_sve_fp8_fmlalltt,                  // llvm.aarch64.sve.fp8.fmlalltt (IntrinsicsAArch64.td:4107)
    aarch64_sve_fp8_fmlalltt_lane,             // llvm.aarch64.sve.fp8.fmlalltt.lane (IntrinsicsAArch64.td:4108)
    aarch64_sve_fp8_fmlalt,                    // llvm.aarch64.sve.fp8.fmlalt (IntrinsicsAArch64.td:4095)
    aarch64_sve_fp8_fmlalt_lane,               // llvm.aarch64.sve.fp8.fmlalt.lane (IntrinsicsAArch64.td:4096)
    aarch64_sve_fp8_fmmla,                     // llvm.aarch64.sve.fp8.fmmla (IntrinsicsAArch64.td:2825)
    aarch64_sve_frecpe_x,                      // llvm.aarch64.sve.frecpe.x (IntrinsicsAArch64.td:2154)
    aarch64_sve_frecps_x,                      // llvm.aarch64.sve.frecps.x (IntrinsicsAArch64.td:2155)
    aarch64_sve_frecpx,                        // llvm.aarch64.sve.frecpx (IntrinsicsAArch64.td:2156)
    aarch64_sve_frint32x,                      // llvm.aarch64.sve.frint32x (IntrinsicsAArch64.td:2164)
    aarch64_sve_frint32z,                      // llvm.aarch64.sve.frint32z (IntrinsicsAArch64.td:2165)
    aarch64_sve_frint64x,                      // llvm.aarch64.sve.frint64x (IntrinsicsAArch64.td:2166)
    aarch64_sve_frint64z,                      // llvm.aarch64.sve.frint64z (IntrinsicsAArch64.td:2167)
    aarch64_sve_frinta,                        // llvm.aarch64.sve.frinta (IntrinsicsAArch64.td:2157)
    aarch64_sve_frinta_x2,                     // llvm.aarch64.sve.frinta.x2 (IntrinsicsAArch64.td:3660)
    aarch64_sve_frinta_x4,                     // llvm.aarch64.sve.frinta.x4 (IntrinsicsAArch64.td:3661)
    aarch64_sve_frinti,                        // llvm.aarch64.sve.frinti (IntrinsicsAArch64.td:2158)
    aarch64_sve_frintm,                        // llvm.aarch64.sve.frintm (IntrinsicsAArch64.td:2159)
    aarch64_sve_frintm_x2,                     // llvm.aarch64.sve.frintm.x2 (IntrinsicsAArch64.td:3660)
    aarch64_sve_frintm_x4,                     // llvm.aarch64.sve.frintm.x4 (IntrinsicsAArch64.td:3661)
    aarch64_sve_frintn,                        // llvm.aarch64.sve.frintn (IntrinsicsAArch64.td:2160)
    aarch64_sve_frintn_x2,                     // llvm.aarch64.sve.frintn.x2 (IntrinsicsAArch64.td:3660)
    aarch64_sve_frintn_x4,                     // llvm.aarch64.sve.frintn.x4 (IntrinsicsAArch64.td:3661)
    aarch64_sve_frintp,                        // llvm.aarch64.sve.frintp (IntrinsicsAArch64.td:2161)
    aarch64_sve_frintp_x2,                     // llvm.aarch64.sve.frintp.x2 (IntrinsicsAArch64.td:3660)
    aarch64_sve_frintp_x4,                     // llvm.aarch64.sve.frintp.x4 (IntrinsicsAArch64.td:3661)
    aarch64_sve_frintx,                        // llvm.aarch64.sve.frintx (IntrinsicsAArch64.td:2162)
    aarch64_sve_frintz,                        // llvm.aarch64.sve.frintz (IntrinsicsAArch64.td:2163)
    aarch64_sve_frsqrte_x,                     // llvm.aarch64.sve.frsqrte.x (IntrinsicsAArch64.td:2168)
    aarch64_sve_frsqrts_x,                     // llvm.aarch64.sve.frsqrts.x (IntrinsicsAArch64.td:2169)
    aarch64_sve_fscale,                        // llvm.aarch64.sve.fscale (IntrinsicsAArch64.td:2170)
    aarch64_sve_fscale_single_x2,              // llvm.aarch64.sve.fscale.single.x2 (IntrinsicsAArch64.td:3694)
    aarch64_sve_fscale_single_x4,              // llvm.aarch64.sve.fscale.single.x4 (IntrinsicsAArch64.td:3695)
    aarch64_sve_fscale_x2,                     // llvm.aarch64.sve.fscale.x2 (IntrinsicsAArch64.td:3697)
    aarch64_sve_fscale_x4,                     // llvm.aarch64.sve.fscale.x4 (IntrinsicsAArch64.td:3698)
    aarch64_sve_fsqrt,                         // llvm.aarch64.sve.fsqrt (IntrinsicsAArch64.td:2171)
    aarch64_sve_fsub,                          // llvm.aarch64.sve.fsub (IntrinsicsAArch64.td:2172)
    aarch64_sve_fsub_u,                        // llvm.aarch64.sve.fsub.u (IntrinsicsAArch64.td:2173)
    aarch64_sve_fsubr,                         // llvm.aarch64.sve.fsubr (IntrinsicsAArch64.td:2174)
    aarch64_sve_ftmad_x,                       // llvm.aarch64.sve.ftmad.x (IntrinsicsAArch64.td:2175)
    aarch64_sve_ftsmul_x,                      // llvm.aarch64.sve.ftsmul.x (IntrinsicsAArch64.td:2176)
    aarch64_sve_ftssel_x,                      // llvm.aarch64.sve.ftssel.x (IntrinsicsAArch64.td:2177)
    aarch64_sve_histcnt,                       // llvm.aarch64.sve.histcnt (IntrinsicsAArch64.td:2612)
    aarch64_sve_histseg,                       // llvm.aarch64.sve.histseg (IntrinsicsAArch64.td:2613)
    aarch64_sve_index,                         // llvm.aarch64.sve.index (IntrinsicsAArch64.td:1777)
    aarch64_sve_insr,                          // llvm.aarch64.sve.insr (IntrinsicsAArch64.td:1878)
    aarch64_sve_lasta,                         // llvm.aarch64.sve.lasta (IntrinsicsAArch64.td:2029)
    aarch64_sve_lastb,                         // llvm.aarch64.sve.lastb (IntrinsicsAArch64.td:2030)
    aarch64_sve_lastp,                         // llvm.aarch64.sve.lastp (IntrinsicsAArch64.td:1927)
    aarch64_sve_ld1,                           // llvm.aarch64.sve.ld1 (IntrinsicsAArch64.td:1712)
    aarch64_sve_ld1_gather,                    // llvm.aarch64.sve.ld1.gather (IntrinsicsAArch64.td:2316)
    aarch64_sve_ld1_gather_index,              // llvm.aarch64.sve.ld1.gather.index (IntrinsicsAArch64.td:2319)
    aarch64_sve_ld1_gather_scalar_offset,      // llvm.aarch64.sve.ld1.gather.scalar.offset (IntrinsicsAArch64.td:2339)
    aarch64_sve_ld1_gather_sxtw,               // llvm.aarch64.sve.ld1.gather.sxtw (IntrinsicsAArch64.td:2322)
    aarch64_sve_ld1_gather_sxtw_index,         // llvm.aarch64.sve.ld1.gather.sxtw.index (IntrinsicsAArch64.td:2326)
    aarch64_sve_ld1_gather_uxtw,               // llvm.aarch64.sve.ld1.gather.uxtw (IntrinsicsAArch64.td:2323)
    aarch64_sve_ld1_gather_uxtw_index,         // llvm.aarch64.sve.ld1.gather.uxtw.index (IntrinsicsAArch64.td:2327)
    aarch64_sve_ld1_pn_x2,                     // llvm.aarch64.sve.ld1.pn.x2 (IntrinsicsAArch64.td:2859)
    aarch64_sve_ld1_pn_x4,                     // llvm.aarch64.sve.ld1.pn.x4 (IntrinsicsAArch64.td:2860)
    aarch64_sve_ld1q_gather_index,             // llvm.aarch64.sve.ld1q.gather.index (IntrinsicsAArch64.td:2330)
    aarch64_sve_ld1q_gather_scalar_offset,     // llvm.aarch64.sve.ld1q.gather.scalar.offset (IntrinsicsAArch64.td:2342)
    aarch64_sve_ld1q_gather_vector_offset,     // llvm.aarch64.sve.ld1q.gather.vector.offset (IntrinsicsAArch64.td:2333)
    aarch64_sve_ld1ro,                         // llvm.aarch64.sve.ld1ro (IntrinsicsAArch64.td:1723)
    aarch64_sve_ld1rq,                         // llvm.aarch64.sve.ld1rq (IntrinsicsAArch64.td:1722)
    aarch64_sve_ld1udq,                        // llvm.aarch64.sve.ld1udq (IntrinsicsAArch64.td:2873)
    aarch64_sve_ld1uwq,                        // llvm.aarch64.sve.ld1uwq (IntrinsicsAArch64.td:2872)
    aarch64_sve_ld2_sret,                      // llvm.aarch64.sve.ld2.sret (IntrinsicsAArch64.td:1714)
    aarch64_sve_ld2q_sret,                     // llvm.aarch64.sve.ld2q.sret (IntrinsicsAArch64.td:2887)
    aarch64_sve_ld3_sret,                      // llvm.aarch64.sve.ld3.sret (IntrinsicsAArch64.td:1715)
    aarch64_sve_ld3q_sret,                     // llvm.aarch64.sve.ld3q.sret (IntrinsicsAArch64.td:2888)
    aarch64_sve_ld4_sret,                      // llvm.aarch64.sve.ld4.sret (IntrinsicsAArch64.td:1716)
    aarch64_sve_ld4q_sret,                     // llvm.aarch64.sve.ld4q.sret (IntrinsicsAArch64.td:2889)
    aarch64_sve_ldff1,                         // llvm.aarch64.sve.ldff1 (IntrinsicsAArch64.td:1720)
    aarch64_sve_ldff1_gather,                  // llvm.aarch64.sve.ldff1.gather (IntrinsicsAArch64.td:2349)
    aarch64_sve_ldff1_gather_index,            // llvm.aarch64.sve.ldff1.gather.index (IntrinsicsAArch64.td:2352)
    aarch64_sve_ldff1_gather_scalar_offset,    // llvm.aarch64.sve.ldff1.gather.scalar.offset (IntrinsicsAArch64.td:2366)
    aarch64_sve_ldff1_gather_sxtw,             // llvm.aarch64.sve.ldff1.gather.sxtw (IntrinsicsAArch64.td:2355)
    aarch64_sve_ldff1_gather_sxtw_index,       // llvm.aarch64.sve.ldff1.gather.sxtw.index (IntrinsicsAArch64.td:2359)
    aarch64_sve_ldff1_gather_uxtw,             // llvm.aarch64.sve.ldff1.gather.uxtw (IntrinsicsAArch64.td:2356)
    aarch64_sve_ldff1_gather_uxtw_index,       // llvm.aarch64.sve.ldff1.gather.uxtw.index (IntrinsicsAArch64.td:2360)
    aarch64_sve_ldnf1,                         // llvm.aarch64.sve.ldnf1 (IntrinsicsAArch64.td:1719)
    aarch64_sve_ldnt1,                         // llvm.aarch64.sve.ldnt1 (IntrinsicsAArch64.td:1718)
    aarch64_sve_ldnt1_gather,                  // llvm.aarch64.sve.ldnt1.gather (IntrinsicsAArch64.td:2374)
    aarch64_sve_ldnt1_gather_index,            // llvm.aarch64.sve.ldnt1.gather.index (IntrinsicsAArch64.td:2377)
    aarch64_sve_ldnt1_gather_scalar_offset,    // llvm.aarch64.sve.ldnt1.gather.scalar.offset (IntrinsicsAArch64.td:2386)
    aarch64_sve_ldnt1_gather_uxtw,             // llvm.aarch64.sve.ldnt1.gather.uxtw (IntrinsicsAArch64.td:2380)
    aarch64_sve_ldnt1_pn_x2,                   // llvm.aarch64.sve.ldnt1.pn.x2 (IntrinsicsAArch64.td:2861)
    aarch64_sve_ldnt1_pn_x4,                   // llvm.aarch64.sve.ldnt1.pn.x4 (IntrinsicsAArch64.td:2862)
    aarch64_sve_lsl,                           // llvm.aarch64.sve.lsl (IntrinsicsAArch64.td:1879)
    aarch64_sve_lsl_u,                         // llvm.aarch64.sve.lsl.u (IntrinsicsAArch64.td:1880)
    aarch64_sve_lsl_wide,                      // llvm.aarch64.sve.lsl.wide (IntrinsicsAArch64.td:1881)
    aarch64_sve_lsr,                           // llvm.aarch64.sve.lsr (IntrinsicsAArch64.td:1882)
    aarch64_sve_lsr_u,                         // llvm.aarch64.sve.lsr.u (IntrinsicsAArch64.td:1883)
    aarch64_sve_lsr_wide,                      // llvm.aarch64.sve.lsr.wide (IntrinsicsAArch64.td:1884)
    aarch64_sve_luti2_lane,                    // llvm.aarch64.sve.luti2.lane (IntrinsicsAArch64.td:2787)
    aarch64_sve_luti4_lane,                    // llvm.aarch64.sve.luti4.lane (IntrinsicsAArch64.td:2788)
    aarch64_sve_luti4_lane_x2,                 // llvm.aarch64.sve.luti4.lane.x2 (IntrinsicsAArch64.td:2789)
    aarch64_sve_mad,                           // llvm.aarch64.sve.mad (IntrinsicsAArch64.td:1828)
    aarch64_sve_match,                         // llvm.aarch64.sve.match (IntrinsicsAArch64.td:2619)
    aarch64_sve_mla,                           // llvm.aarch64.sve.mla (IntrinsicsAArch64.td:1830)
    aarch64_sve_mla_lane,                      // llvm.aarch64.sve.mla.lane (IntrinsicsAArch64.td:1832)
    aarch64_sve_mla_u,                         // llvm.aarch64.sve.mla.u (IntrinsicsAArch64.td:1831)
    aarch64_sve_mls,                           // llvm.aarch64.sve.mls (IntrinsicsAArch64.td:1833)
    aarch64_sve_mls_lane,                      // llvm.aarch64.sve.mls.lane (IntrinsicsAArch64.td:1835)
    aarch64_sve_mls_u,                         // llvm.aarch64.sve.mls.u (IntrinsicsAArch64.td:1834)
    aarch64_sve_msb,                           // llvm.aarch64.sve.msb (IntrinsicsAArch64.td:1829)
    aarch64_sve_mul,                           // llvm.aarch64.sve.mul (IntrinsicsAArch64.td:1800)
    aarch64_sve_mul_lane,                      // llvm.aarch64.sve.mul.lane (IntrinsicsAArch64.td:1802)
    aarch64_sve_mul_u,                         // llvm.aarch64.sve.mul.u (IntrinsicsAArch64.td:1801)
    aarch64_sve_nand_z,                        // llvm.aarch64.sve.nand.z (IntrinsicsAArch64.td:2282)
    aarch64_sve_nbsl,                          // llvm.aarch64.sve.nbsl (IntrinsicsAArch64.td:2741)
    aarch64_sve_neg,                           // llvm.aarch64.sve.neg (IntrinsicsAArch64.td:1850)
    aarch64_sve_nmatch,                        // llvm.aarch64.sve.nmatch (IntrinsicsAArch64.td:2620)
    aarch64_sve_nor_z,                         // llvm.aarch64.sve.nor.z (IntrinsicsAArch64.td:2283)
    aarch64_sve_not,                           // llvm.aarch64.sve.not (IntrinsicsAArch64.td:2082)
    aarch64_sve_orn_z,                         // llvm.aarch64.sve.orn.z (IntrinsicsAArch64.td:2284)
    aarch64_sve_orqv,                          // llvm.aarch64.sve.orqv (IntrinsicsAArch64.td:1863)
    aarch64_sve_orr,                           // llvm.aarch64.sve.orr (IntrinsicsAArch64.td:2083)
    aarch64_sve_orr_u,                         // llvm.aarch64.sve.orr.u (IntrinsicsAArch64.td:2084)
    aarch64_sve_orr_z,                         // llvm.aarch64.sve.orr.z (IntrinsicsAArch64.td:2285)
    aarch64_sve_orv,                           // llvm.aarch64.sve.orv (IntrinsicsAArch64.td:1845)
    aarch64_sve_pext,                          // llvm.aarch64.sve.pext (IntrinsicsAArch64.td:3196)
    aarch64_sve_pext_x2,                       // llvm.aarch64.sve.pext.x2 (IntrinsicsAArch64.td:3201)
    aarch64_sve_pfirst,                        // llvm.aarch64.sve.pfirst (IntrinsicsAArch64.td:2286)
    aarch64_sve_pmlal_pair_x2,                 // llvm.aarch64.sve.pmlal.pair.x2 (IntrinsicsAArch64.td:4282)
    aarch64_sve_pmov_to_pred_lane,             // llvm.aarch64.sve.pmov.to.pred.lane (IntrinsicsAArch64.td:4024)
    aarch64_sve_pmov_to_pred_lane_zero,        // llvm.aarch64.sve.pmov.to.pred.lane.zero (IntrinsicsAArch64.td:4026)
    aarch64_sve_pmov_to_vector_lane_merging,   // llvm.aarch64.sve.pmov.to.vector.lane.merging (IntrinsicsAArch64.td:4028)
    aarch64_sve_pmov_to_vector_lane_zeroing,   // llvm.aarch64.sve.pmov.to.vector.lane.zeroing (IntrinsicsAArch64.td:4029)
    aarch64_sve_pmul,                          // llvm.aarch64.sve.pmul (IntrinsicsAArch64.td:1798)
    aarch64_sve_pmull_pair_x2,                 // llvm.aarch64.sve.pmull.pair.x2 (IntrinsicsAArch64.td:4280)
    aarch64_sve_pmullb_pair,                   // llvm.aarch64.sve.pmullb.pair (IntrinsicsAArch64.td:2730)
    aarch64_sve_pmullt_pair,                   // llvm.aarch64.sve.pmullt.pair (IntrinsicsAArch64.td:2731)
    aarch64_sve_pnext,                         // llvm.aarch64.sve.pnext (IntrinsicsAArch64.td:2287)
    aarch64_sve_prf,                           // llvm.aarch64.sve.prf (IntrinsicsAArch64.td:1740)
    aarch64_sve_prfb_gather_index,             // llvm.aarch64.sve.prfb.gather.index (IntrinsicsAArch64.td:1759)
    aarch64_sve_prfb_gather_scalar_offset,     // llvm.aarch64.sve.prfb.gather.scalar.offset (IntrinsicsAArch64.td:1765)
    aarch64_sve_prfb_gather_sxtw_index,        // llvm.aarch64.sve.prfb.gather.sxtw.index (IntrinsicsAArch64.td:1753)
    aarch64_sve_prfb_gather_uxtw_index,        // llvm.aarch64.sve.prfb.gather.uxtw.index (IntrinsicsAArch64.td:1746)
    aarch64_sve_prfd_gather_index,             // llvm.aarch64.sve.prfd.gather.index (IntrinsicsAArch64.td:1762)
    aarch64_sve_prfd_gather_scalar_offset,     // llvm.aarch64.sve.prfd.gather.scalar.offset (IntrinsicsAArch64.td:1768)
    aarch64_sve_prfd_gather_sxtw_index,        // llvm.aarch64.sve.prfd.gather.sxtw.index (IntrinsicsAArch64.td:1756)
    aarch64_sve_prfd_gather_uxtw_index,        // llvm.aarch64.sve.prfd.gather.uxtw.index (IntrinsicsAArch64.td:1749)
    aarch64_sve_prfh_gather_index,             // llvm.aarch64.sve.prfh.gather.index (IntrinsicsAArch64.td:1760)
    aarch64_sve_prfh_gather_scalar_offset,     // llvm.aarch64.sve.prfh.gather.scalar.offset (IntrinsicsAArch64.td:1766)
    aarch64_sve_prfh_gather_sxtw_index,        // llvm.aarch64.sve.prfh.gather.sxtw.index (IntrinsicsAArch64.td:1755)
    aarch64_sve_prfh_gather_uxtw_index,        // llvm.aarch64.sve.prfh.gather.uxtw.index (IntrinsicsAArch64.td:1747)
    aarch64_sve_prfw_gather_index,             // llvm.aarch64.sve.prfw.gather.index (IntrinsicsAArch64.td:1761)
    aarch64_sve_prfw_gather_scalar_offset,     // llvm.aarch64.sve.prfw.gather.scalar.offset (IntrinsicsAArch64.td:1767)
    aarch64_sve_prfw_gather_sxtw_index,        // llvm.aarch64.sve.prfw.gather.sxtw.index (IntrinsicsAArch64.td:1754)
    aarch64_sve_prfw_gather_uxtw_index,        // llvm.aarch64.sve.prfw.gather.uxtw.index (IntrinsicsAArch64.td:1748)
    aarch64_sve_psel,                          // llvm.aarch64.sve.psel (IntrinsicsAArch64.td:3177)
    aarch64_sve_ptest_any,                     // llvm.aarch64.sve.ptest.any (IntrinsicsAArch64.td:2295)
    aarch64_sve_ptest_first,                   // llvm.aarch64.sve.ptest.first (IntrinsicsAArch64.td:2296)
    aarch64_sve_ptest_last,                    // llvm.aarch64.sve.ptest.last (IntrinsicsAArch64.td:2297)
    aarch64_sve_ptrue,                         // llvm.aarch64.sve.ptrue (IntrinsicsAArch64.td:2266)
    aarch64_sve_ptrue_c16,                     // llvm.aarch64.sve.ptrue.c16 (IntrinsicsAArch64.td:3208)
    aarch64_sve_ptrue_c32,                     // llvm.aarch64.sve.ptrue.c32 (IntrinsicsAArch64.td:3210)
    aarch64_sve_ptrue_c64,                     // llvm.aarch64.sve.ptrue.c64 (IntrinsicsAArch64.td:3212)
    aarch64_sve_ptrue_c8,                      // llvm.aarch64.sve.ptrue.c8 (IntrinsicsAArch64.td:3206)
    aarch64_sve_punpkhi,                       // llvm.aarch64.sve.punpkhi (IntrinsicsAArch64.td:2288)
    aarch64_sve_punpklo,                       // llvm.aarch64.sve.punpklo (IntrinsicsAArch64.td:2289)
    aarch64_sve_raddhnb,                       // llvm.aarch64.sve.raddhnb (IntrinsicsAArch64.td:2639)
    aarch64_sve_raddhnt,                       // llvm.aarch64.sve.raddhnt (IntrinsicsAArch64.td:2640)
    aarch64_sve_rax1,                          // llvm.aarch64.sve.rax1 (IntrinsicsAArch64.td:2764)
    aarch64_sve_rbit,                          // llvm.aarch64.sve.rbit (IntrinsicsAArch64.td:2010)
    aarch64_sve_rdffr,                         // llvm.aarch64.sve.rdffr (IntrinsicsAArch64.td:1933)
    aarch64_sve_rdffr_z,                       // llvm.aarch64.sve.rdffr.z (IntrinsicsAArch64.td:1934)
    aarch64_sve_rev_b16,                       // llvm.aarch64.sve.rev.b16 (IntrinsicsAArch64.td:2031)
    aarch64_sve_rev_b32,                       // llvm.aarch64.sve.rev.b32 (IntrinsicsAArch64.td:2032)
    aarch64_sve_rev_b64,                       // llvm.aarch64.sve.rev.b64 (IntrinsicsAArch64.td:2033)
    aarch64_sve_revb,                          // llvm.aarch64.sve.revb (IntrinsicsAArch64.td:2011)
    aarch64_sve_revd,                          // llvm.aarch64.sve.revd (IntrinsicsAArch64.td:3171)
    aarch64_sve_revh,                          // llvm.aarch64.sve.revh (IntrinsicsAArch64.td:2012)
    aarch64_sve_revw,                          // llvm.aarch64.sve.revw (IntrinsicsAArch64.td:2013)
    aarch64_sve_rshrnb,                        // llvm.aarch64.sve.rshrnb (IntrinsicsAArch64.td:2652)
    aarch64_sve_rshrnt,                        // llvm.aarch64.sve.rshrnt (IntrinsicsAArch64.td:2653)
    aarch64_sve_rsubhnb,                       // llvm.aarch64.sve.rsubhnb (IntrinsicsAArch64.td:2645)
    aarch64_sve_rsubhnt,                       // llvm.aarch64.sve.rsubhnt (IntrinsicsAArch64.td:2646)
    aarch64_sve_saba,                          // llvm.aarch64.sve.saba (IntrinsicsAArch64.td:2452)
    aarch64_sve_sabalb,                        // llvm.aarch64.sve.sabalb (IntrinsicsAArch64.td:2512)
    aarch64_sve_sabalt,                        // llvm.aarch64.sve.sabalt (IntrinsicsAArch64.td:2513)
    aarch64_sve_sabd,                          // llvm.aarch64.sve.sabd (IntrinsicsAArch64.td:1823)
    aarch64_sve_sabd_u,                        // llvm.aarch64.sve.sabd.u (IntrinsicsAArch64.td:1824)
    aarch64_sve_sabdlb,                        // llvm.aarch64.sve.sabdlb (IntrinsicsAArch64.td:2514)
    aarch64_sve_sabdlt,                        // llvm.aarch64.sve.sabdlt (IntrinsicsAArch64.td:2515)
    aarch64_sve_sadalp,                        // llvm.aarch64.sve.sadalp (IntrinsicsAArch64.td:2560)
    aarch64_sve_saddlb,                        // llvm.aarch64.sve.saddlb (IntrinsicsAArch64.td:2516)
    aarch64_sve_saddlbt,                       // llvm.aarch64.sve.saddlbt (IntrinsicsAArch64.td:2578)
    aarch64_sve_saddlt,                        // llvm.aarch64.sve.saddlt (IntrinsicsAArch64.td:2517)
    aarch64_sve_saddv,                         // llvm.aarch64.sve.saddv (IntrinsicsAArch64.td:1837)
    aarch64_sve_saddwb,                        // llvm.aarch64.sve.saddwb (IntrinsicsAArch64.td:2518)
    aarch64_sve_saddwt,                        // llvm.aarch64.sve.saddwt (IntrinsicsAArch64.td:2519)
    aarch64_sve_sbclb,                         // llvm.aarch64.sve.sbclb (IntrinsicsAArch64.td:2722)
    aarch64_sve_sbclt,                         // llvm.aarch64.sve.sbclt (IntrinsicsAArch64.td:2723)
    aarch64_sve_sclamp,                        // llvm.aarch64.sve.sclamp (IntrinsicsAArch64.td:3162)
    aarch64_sve_sclamp_single_x2,              // llvm.aarch64.sve.sclamp.single.x2 (IntrinsicsAArch64.td:3817)
    aarch64_sve_sclamp_single_x4,              // llvm.aarch64.sve.sclamp.single.x4 (IntrinsicsAArch64.td:3822)
    aarch64_sve_scvtf,                         // llvm.aarch64.sve.scvtf (IntrinsicsAArch64.td:2203)
    aarch64_sve_scvtf_f16i32,                  // llvm.aarch64.sve.scvtf.f16i32 (IntrinsicsAArch64.td:2252)
    aarch64_sve_scvtf_f16i64,                  // llvm.aarch64.sve.scvtf.f16i64 (IntrinsicsAArch64.td:2253)
    aarch64_sve_scvtf_f32i64,                  // llvm.aarch64.sve.scvtf.f32i64 (IntrinsicsAArch64.td:2254)
    aarch64_sve_scvtf_f64i32,                  // llvm.aarch64.sve.scvtf.f64i32 (IntrinsicsAArch64.td:2255)
    aarch64_sve_scvtf_x2,                      // llvm.aarch64.sve.scvtf.x2 (IntrinsicsAArch64.td:3743)
    aarch64_sve_scvtf_x4,                      // llvm.aarch64.sve.scvtf.x4 (IntrinsicsAArch64.td:3747)
    aarch64_sve_sdiv,                          // llvm.aarch64.sve.sdiv (IntrinsicsAArch64.td:1808)
    aarch64_sve_sdiv_u,                        // llvm.aarch64.sve.sdiv.u (IntrinsicsAArch64.td:1809)
    aarch64_sve_sdivr,                         // llvm.aarch64.sve.sdivr (IntrinsicsAArch64.td:1812)
    aarch64_sve_sdot,                          // llvm.aarch64.sve.sdot (IntrinsicsAArch64.td:1852)
    aarch64_sve_sdot_lane,                     // llvm.aarch64.sve.sdot.lane (IntrinsicsAArch64.td:1853)
    aarch64_sve_sdot_lane_x2,                  // llvm.aarch64.sve.sdot.lane.x2 (IntrinsicsAArch64.td:3914)
    aarch64_sve_sdot_x2,                       // llvm.aarch64.sve.sdot.x2 (IntrinsicsAArch64.td:3911)
    aarch64_sve_sel,                           // llvm.aarch64.sve.sel (IntrinsicsAArch64.td:2028)
    aarch64_sve_sel_x2,                        // llvm.aarch64.sve.sel.x2 (IntrinsicsAArch64.td:3927)
    aarch64_sve_sel_x4,                        // llvm.aarch64.sve.sel.x4 (IntrinsicsAArch64.td:3928)
    aarch64_sve_setffr,                        // llvm.aarch64.sve.setffr (IntrinsicsAArch64.td:1935)
    aarch64_sve_shadd,                         // llvm.aarch64.sve.shadd (IntrinsicsAArch64.td:2453)
    aarch64_sve_shrnb,                         // llvm.aarch64.sve.shrnb (IntrinsicsAArch64.td:2649)
    aarch64_sve_shrnt,                         // llvm.aarch64.sve.shrnt (IntrinsicsAArch64.td:2650)
    aarch64_sve_shsub,                         // llvm.aarch64.sve.shsub (IntrinsicsAArch64.td:2454)
    aarch64_sve_shsub_u,                       // llvm.aarch64.sve.shsub.u (IntrinsicsAArch64.td:2455)
    aarch64_sve_shsubr,                        // llvm.aarch64.sve.shsubr (IntrinsicsAArch64.td:2456)
    aarch64_sve_sli,                           // llvm.aarch64.sve.sli (IntrinsicsAArch64.td:2457)
    aarch64_sve_sm4e,                          // llvm.aarch64.sve.sm4e (IntrinsicsAArch64.td:2768)
    aarch64_sve_sm4ekey,                       // llvm.aarch64.sve.sm4ekey (IntrinsicsAArch64.td:2772)
    aarch64_sve_smax,                          // llvm.aarch64.sve.smax (IntrinsicsAArch64.td:1815)
    aarch64_sve_smax_single_x2,                // llvm.aarch64.sve.smax.single.x2 (IntrinsicsAArch64.td:3670)
    aarch64_sve_smax_single_x4,                // llvm.aarch64.sve.smax.single.x4 (IntrinsicsAArch64.td:3671)
    aarch64_sve_smax_u,                        // llvm.aarch64.sve.smax.u (IntrinsicsAArch64.td:1816)
    aarch64_sve_smax_x2,                       // llvm.aarch64.sve.smax.x2 (IntrinsicsAArch64.td:3673)
    aarch64_sve_smax_x4,                       // llvm.aarch64.sve.smax.x4 (IntrinsicsAArch64.td:3674)
    aarch64_sve_smaxp,                         // llvm.aarch64.sve.smaxp (IntrinsicsAArch64.td:2551)
    aarch64_sve_smaxqv,                        // llvm.aarch64.sve.smaxqv (IntrinsicsAArch64.td:1867)
    aarch64_sve_smaxv,                         // llvm.aarch64.sve.smaxv (IntrinsicsAArch64.td:1840)
    aarch64_sve_smin,                          // llvm.aarch64.sve.smin (IntrinsicsAArch64.td:1819)
    aarch64_sve_smin_single_x2,                // llvm.aarch64.sve.smin.single.x2 (IntrinsicsAArch64.td:3670)
    aarch64_sve_smin_single_x4,                // llvm.aarch64.sve.smin.single.x4 (IntrinsicsAArch64.td:3671)
    aarch64_sve_smin_u,                        // llvm.aarch64.sve.smin.u (IntrinsicsAArch64.td:1820)
    aarch64_sve_smin_x2,                       // llvm.aarch64.sve.smin.x2 (IntrinsicsAArch64.td:3673)
    aarch64_sve_smin_x4,                       // llvm.aarch64.sve.smin.x4 (IntrinsicsAArch64.td:3674)
    aarch64_sve_sminp,                         // llvm.aarch64.sve.sminp (IntrinsicsAArch64.td:2552)
    aarch64_sve_sminqv,                        // llvm.aarch64.sve.sminqv (IntrinsicsAArch64.td:1869)
    aarch64_sve_sminv,                         // llvm.aarch64.sve.sminv (IntrinsicsAArch64.td:1842)
    aarch64_sve_smlalb,                        // llvm.aarch64.sve.smlalb (IntrinsicsAArch64.td:2697)
    aarch64_sve_smlalb_lane,                   // llvm.aarch64.sve.smlalb.lane (IntrinsicsAArch64.td:2677)
    aarch64_sve_smlalt,                        // llvm.aarch64.sve.smlalt (IntrinsicsAArch64.td:2698)
    aarch64_sve_smlalt_lane,                   // llvm.aarch64.sve.smlalt.lane (IntrinsicsAArch64.td:2678)
    aarch64_sve_smlslb,                        // llvm.aarch64.sve.smlslb (IntrinsicsAArch64.td:2701)
    aarch64_sve_smlslb_lane,                   // llvm.aarch64.sve.smlslb.lane (IntrinsicsAArch64.td:2681)
    aarch64_sve_smlslt,                        // llvm.aarch64.sve.smlslt (IntrinsicsAArch64.td:2702)
    aarch64_sve_smlslt_lane,                   // llvm.aarch64.sve.smlslt.lane (IntrinsicsAArch64.td:2682)
    aarch64_sve_smmla,                         // llvm.aarch64.sve.smmla (IntrinsicsAArch64.td:2809)
    aarch64_sve_smulh,                         // llvm.aarch64.sve.smulh (IntrinsicsAArch64.td:1803)
    aarch64_sve_smulh_u,                       // llvm.aarch64.sve.smulh.u (IntrinsicsAArch64.td:1804)
    aarch64_sve_smullb,                        // llvm.aarch64.sve.smullb (IntrinsicsAArch64.td:2705)
    aarch64_sve_smullb_lane,                   // llvm.aarch64.sve.smullb.lane (IntrinsicsAArch64.td:2685)
    aarch64_sve_smullt,                        // llvm.aarch64.sve.smullt (IntrinsicsAArch64.td:2706)
    aarch64_sve_smullt_lane,                   // llvm.aarch64.sve.smullt.lane (IntrinsicsAArch64.td:2686)
    aarch64_sve_splice,                        // llvm.aarch64.sve.splice (IntrinsicsAArch64.td:2034)
    aarch64_sve_sqabs,                         // llvm.aarch64.sve.sqabs (IntrinsicsAArch64.td:2458)
    aarch64_sve_sqadd,                         // llvm.aarch64.sve.sqadd (IntrinsicsAArch64.td:2459)
    aarch64_sve_sqadd_x,                       // llvm.aarch64.sve.sqadd.x (IntrinsicsAArch64.td:1858)
    aarch64_sve_sqcadd_x,                      // llvm.aarch64.sve.sqcadd.x (IntrinsicsAArch64.td:2568)
    aarch64_sve_sqcvt_x2,                      // llvm.aarch64.sve.sqcvt.x2 (IntrinsicsAArch64.td:3753)
    aarch64_sve_sqcvt_x4,                      // llvm.aarch64.sve.sqcvt.x4 (IntrinsicsAArch64.td:3756)
    aarch64_sve_sqcvtn_x2,                     // llvm.aarch64.sve.sqcvtn.x2 (IntrinsicsAArch64.td:3763)
    aarch64_sve_sqcvtn_x4,                     // llvm.aarch64.sve.sqcvtn.x4 (IntrinsicsAArch64.td:3766)
    aarch64_sve_sqcvtu_x2,                     // llvm.aarch64.sve.sqcvtu.x2 (IntrinsicsAArch64.td:3755)
    aarch64_sve_sqcvtu_x4,                     // llvm.aarch64.sve.sqcvtu.x4 (IntrinsicsAArch64.td:3758)
    aarch64_sve_sqcvtun_x2,                    // llvm.aarch64.sve.sqcvtun.x2 (IntrinsicsAArch64.td:3765)
    aarch64_sve_sqcvtun_x4,                    // llvm.aarch64.sve.sqcvtun.x4 (IntrinsicsAArch64.td:3768)
    aarch64_sve_sqdecb_n32,                    // llvm.aarch64.sve.sqdecb.n32 (IntrinsicsAArch64.td:1947)
    aarch64_sve_sqdecb_n64,                    // llvm.aarch64.sve.sqdecb.n64 (IntrinsicsAArch64.td:1948)
    aarch64_sve_sqdecd,                        // llvm.aarch64.sve.sqdecd (IntrinsicsAArch64.td:1944)
    aarch64_sve_sqdecd_n32,                    // llvm.aarch64.sve.sqdecd.n32 (IntrinsicsAArch64.td:1953)
    aarch64_sve_sqdecd_n64,                    // llvm.aarch64.sve.sqdecd.n64 (IntrinsicsAArch64.td:1954)
    aarch64_sve_sqdech,                        // llvm.aarch64.sve.sqdech (IntrinsicsAArch64.td:1942)
    aarch64_sve_sqdech_n32,                    // llvm.aarch64.sve.sqdech.n32 (IntrinsicsAArch64.td:1949)
    aarch64_sve_sqdech_n64,                    // llvm.aarch64.sve.sqdech.n64 (IntrinsicsAArch64.td:1950)
    aarch64_sve_sqdecp,                        // llvm.aarch64.sve.sqdecp (IntrinsicsAArch64.td:1945)
    aarch64_sve_sqdecp_n32,                    // llvm.aarch64.sve.sqdecp.n32 (IntrinsicsAArch64.td:1955)
    aarch64_sve_sqdecp_n64,                    // llvm.aarch64.sve.sqdecp.n64 (IntrinsicsAArch64.td:1956)
    aarch64_sve_sqdecw,                        // llvm.aarch64.sve.sqdecw (IntrinsicsAArch64.td:1943)
    aarch64_sve_sqdecw_n32,                    // llvm.aarch64.sve.sqdecw.n32 (IntrinsicsAArch64.td:1951)
    aarch64_sve_sqdecw_n64,                    // llvm.aarch64.sve.sqdecw.n64 (IntrinsicsAArch64.td:1952)
    aarch64_sve_sqdmlalb,                      // llvm.aarch64.sve.sqdmlalb (IntrinsicsAArch64.td:2710)
    aarch64_sve_sqdmlalb_lane,                 // llvm.aarch64.sve.sqdmlalb.lane (IntrinsicsAArch64.td:2689)
    aarch64_sve_sqdmlalbt,                     // llvm.aarch64.sve.sqdmlalbt (IntrinsicsAArch64.td:2716)
    aarch64_sve_sqdmlalt,                      // llvm.aarch64.sve.sqdmlalt (IntrinsicsAArch64.td:2711)
    aarch64_sve_sqdmlalt_lane,                 // llvm.aarch64.sve.sqdmlalt.lane (IntrinsicsAArch64.td:2690)
    aarch64_sve_sqdmlslb,                      // llvm.aarch64.sve.sqdmlslb (IntrinsicsAArch64.td:2712)
    aarch64_sve_sqdmlslb_lane,                 // llvm.aarch64.sve.sqdmlslb.lane (IntrinsicsAArch64.td:2691)
    aarch64_sve_sqdmlslbt,                     // llvm.aarch64.sve.sqdmlslbt (IntrinsicsAArch64.td:2717)
    aarch64_sve_sqdmlslt,                      // llvm.aarch64.sve.sqdmlslt (IntrinsicsAArch64.td:2713)
    aarch64_sve_sqdmlslt_lane,                 // llvm.aarch64.sve.sqdmlslt.lane (IntrinsicsAArch64.td:2692)
    aarch64_sve_sqdmulh,                       // llvm.aarch64.sve.sqdmulh (IntrinsicsAArch64.td:2460)
    aarch64_sve_sqdmulh_lane,                  // llvm.aarch64.sve.sqdmulh.lane (IntrinsicsAArch64.td:2461)
    aarch64_sve_sqdmulh_single_vgx2,           // llvm.aarch64.sve.sqdmulh.single.vgx2 (IntrinsicsAArch64.td:3651)
    aarch64_sve_sqdmulh_single_vgx4,           // llvm.aarch64.sve.sqdmulh.single.vgx4 (IntrinsicsAArch64.td:3652)
    aarch64_sve_sqdmulh_vgx2,                  // llvm.aarch64.sve.sqdmulh.vgx2 (IntrinsicsAArch64.td:3654)
    aarch64_sve_sqdmulh_vgx4,                  // llvm.aarch64.sve.sqdmulh.vgx4 (IntrinsicsAArch64.td:3655)
    aarch64_sve_sqdmullb,                      // llvm.aarch64.sve.sqdmullb (IntrinsicsAArch64.td:2714)
    aarch64_sve_sqdmullb_lane,                 // llvm.aarch64.sve.sqdmullb.lane (IntrinsicsAArch64.td:2693)
    aarch64_sve_sqdmullt,                      // llvm.aarch64.sve.sqdmullt (IntrinsicsAArch64.td:2715)
    aarch64_sve_sqdmullt_lane,                 // llvm.aarch64.sve.sqdmullt.lane (IntrinsicsAArch64.td:2694)
    aarch64_sve_sqincb_n32,                    // llvm.aarch64.sve.sqincb.n32 (IntrinsicsAArch64.td:1963)
    aarch64_sve_sqincb_n64,                    // llvm.aarch64.sve.sqincb.n64 (IntrinsicsAArch64.td:1964)
    aarch64_sve_sqincd,                        // llvm.aarch64.sve.sqincd (IntrinsicsAArch64.td:1960)
    aarch64_sve_sqincd_n32,                    // llvm.aarch64.sve.sqincd.n32 (IntrinsicsAArch64.td:1969)
    aarch64_sve_sqincd_n64,                    // llvm.aarch64.sve.sqincd.n64 (IntrinsicsAArch64.td:1970)
    aarch64_sve_sqinch,                        // llvm.aarch64.sve.sqinch (IntrinsicsAArch64.td:1958)
    aarch64_sve_sqinch_n32,                    // llvm.aarch64.sve.sqinch.n32 (IntrinsicsAArch64.td:1965)
    aarch64_sve_sqinch_n64,                    // llvm.aarch64.sve.sqinch.n64 (IntrinsicsAArch64.td:1966)
    aarch64_sve_sqincp,                        // llvm.aarch64.sve.sqincp (IntrinsicsAArch64.td:1961)
    aarch64_sve_sqincp_n32,                    // llvm.aarch64.sve.sqincp.n32 (IntrinsicsAArch64.td:1971)
    aarch64_sve_sqincp_n64,                    // llvm.aarch64.sve.sqincp.n64 (IntrinsicsAArch64.td:1972)
    aarch64_sve_sqincw,                        // llvm.aarch64.sve.sqincw (IntrinsicsAArch64.td:1959)
    aarch64_sve_sqincw_n32,                    // llvm.aarch64.sve.sqincw.n32 (IntrinsicsAArch64.td:1967)
    aarch64_sve_sqincw_n64,                    // llvm.aarch64.sve.sqincw.n64 (IntrinsicsAArch64.td:1968)
    aarch64_sve_sqneg,                         // llvm.aarch64.sve.sqneg (IntrinsicsAArch64.td:2462)
    aarch64_sve_sqrdcmlah_lane_x,              // llvm.aarch64.sve.sqrdcmlah.lane.x (IntrinsicsAArch64.td:2572)
    aarch64_sve_sqrdcmlah_x,                   // llvm.aarch64.sve.sqrdcmlah.x (IntrinsicsAArch64.td:2571)
    aarch64_sve_sqrdmlah,                      // llvm.aarch64.sve.sqrdmlah (IntrinsicsAArch64.td:2463)
    aarch64_sve_sqrdmlah_lane,                 // llvm.aarch64.sve.sqrdmlah.lane (IntrinsicsAArch64.td:2464)
    aarch64_sve_sqrdmlsh,                      // llvm.aarch64.sve.sqrdmlsh (IntrinsicsAArch64.td:2465)
    aarch64_sve_sqrdmlsh_lane,                 // llvm.aarch64.sve.sqrdmlsh.lane (IntrinsicsAArch64.td:2466)
    aarch64_sve_sqrdmulh,                      // llvm.aarch64.sve.sqrdmulh (IntrinsicsAArch64.td:2467)
    aarch64_sve_sqrdmulh_lane,                 // llvm.aarch64.sve.sqrdmulh.lane (IntrinsicsAArch64.td:2468)
    aarch64_sve_sqrshl,                        // llvm.aarch64.sve.sqrshl (IntrinsicsAArch64.td:2469)
    aarch64_sve_sqrshl_u,                      // llvm.aarch64.sve.sqrshl.u (IntrinsicsAArch64.td:2470)
    aarch64_sve_sqrshr_x2,                     // llvm.aarch64.sve.sqrshr.x2 (IntrinsicsAArch64.td:3565)
    aarch64_sve_sqrshr_x4,                     // llvm.aarch64.sve.sqrshr.x4 (IntrinsicsAArch64.td:3567)
    aarch64_sve_sqrshrn_x2,                    // llvm.aarch64.sve.sqrshrn.x2 (IntrinsicsAArch64.td:3570)
    aarch64_sve_sqrshrn_x4,                    // llvm.aarch64.sve.sqrshrn.x4 (IntrinsicsAArch64.td:3572)
    aarch64_sve_sqrshrnb,                      // llvm.aarch64.sve.sqrshrnb (IntrinsicsAArch64.td:2659)
    aarch64_sve_sqrshrnt,                      // llvm.aarch64.sve.sqrshrnt (IntrinsicsAArch64.td:2660)
    aarch64_sve_sqrshru_x2,                    // llvm.aarch64.sve.sqrshru.x2 (IntrinsicsAArch64.td:3575)
    aarch64_sve_sqrshru_x4,                    // llvm.aarch64.sve.sqrshru.x4 (IntrinsicsAArch64.td:3576)
    aarch64_sve_sqrshrun_x2,                   // llvm.aarch64.sve.sqrshrun.x2 (IntrinsicsAArch64.td:3578)
    aarch64_sve_sqrshrun_x4,                   // llvm.aarch64.sve.sqrshrun.x4 (IntrinsicsAArch64.td:3579)
    aarch64_sve_sqrshrunb,                     // llvm.aarch64.sve.sqrshrunb (IntrinsicsAArch64.td:2673)
    aarch64_sve_sqrshrunt,                     // llvm.aarch64.sve.sqrshrunt (IntrinsicsAArch64.td:2674)
    aarch64_sve_sqshl,                         // llvm.aarch64.sve.sqshl (IntrinsicsAArch64.td:2471)
    aarch64_sve_sqshl_u,                       // llvm.aarch64.sve.sqshl.u (IntrinsicsAArch64.td:2472)
    aarch64_sve_sqshlu,                        // llvm.aarch64.sve.sqshlu (IntrinsicsAArch64.td:2473)
    aarch64_sve_sqshrnb,                       // llvm.aarch64.sve.sqshrnb (IntrinsicsAArch64.td:2656)
    aarch64_sve_sqshrnt,                       // llvm.aarch64.sve.sqshrnt (IntrinsicsAArch64.td:2657)
    aarch64_sve_sqshrunb,                      // llvm.aarch64.sve.sqshrunb (IntrinsicsAArch64.td:2670)
    aarch64_sve_sqshrunt,                      // llvm.aarch64.sve.sqshrunt (IntrinsicsAArch64.td:2671)
    aarch64_sve_sqsub,                         // llvm.aarch64.sve.sqsub (IntrinsicsAArch64.td:2474)
    aarch64_sve_sqsub_u,                       // llvm.aarch64.sve.sqsub.u (IntrinsicsAArch64.td:2475)
    aarch64_sve_sqsub_x,                       // llvm.aarch64.sve.sqsub.x (IntrinsicsAArch64.td:1859)
    aarch64_sve_sqsubr,                        // llvm.aarch64.sve.sqsubr (IntrinsicsAArch64.td:2476)
    aarch64_sve_sqxtnb,                        // llvm.aarch64.sve.sqxtnb (IntrinsicsAArch64.td:2626)
    aarch64_sve_sqxtnt,                        // llvm.aarch64.sve.sqxtnt (IntrinsicsAArch64.td:2627)
    aarch64_sve_sqxtunb,                       // llvm.aarch64.sve.sqxtunb (IntrinsicsAArch64.td:2628)
    aarch64_sve_sqxtunt,                       // llvm.aarch64.sve.sqxtunt (IntrinsicsAArch64.td:2629)
    aarch64_sve_srhadd,                        // llvm.aarch64.sve.srhadd (IntrinsicsAArch64.td:2477)
    aarch64_sve_sri,                           // llvm.aarch64.sve.sri (IntrinsicsAArch64.td:2478)
    aarch64_sve_srshl,                         // llvm.aarch64.sve.srshl (IntrinsicsAArch64.td:2479)
    aarch64_sve_srshl_single_x2,               // llvm.aarch64.sve.srshl.single.x2 (IntrinsicsAArch64.td:3553)
    aarch64_sve_srshl_single_x4,               // llvm.aarch64.sve.srshl.single.x4 (IntrinsicsAArch64.td:3555)
    aarch64_sve_srshl_u,                       // llvm.aarch64.sve.srshl.u (IntrinsicsAArch64.td:2480)
    aarch64_sve_srshl_x2,                      // llvm.aarch64.sve.srshl.x2 (IntrinsicsAArch64.td:3558)
    aarch64_sve_srshl_x4,                      // llvm.aarch64.sve.srshl.x4 (IntrinsicsAArch64.td:3560)
    aarch64_sve_srshr,                         // llvm.aarch64.sve.srshr (IntrinsicsAArch64.td:2481)
    aarch64_sve_srsra,                         // llvm.aarch64.sve.srsra (IntrinsicsAArch64.td:2482)
    aarch64_sve_sshllb,                        // llvm.aarch64.sve.sshllb (IntrinsicsAArch64.td:2520)
    aarch64_sve_sshllt,                        // llvm.aarch64.sve.sshllt (IntrinsicsAArch64.td:2521)
    aarch64_sve_ssra,                          // llvm.aarch64.sve.ssra (IntrinsicsAArch64.td:2483)
    aarch64_sve_ssublb,                        // llvm.aarch64.sve.ssublb (IntrinsicsAArch64.td:2522)
    aarch64_sve_ssublbt,                       // llvm.aarch64.sve.ssublbt (IntrinsicsAArch64.td:2579)
    aarch64_sve_ssublt,                        // llvm.aarch64.sve.ssublt (IntrinsicsAArch64.td:2523)
    aarch64_sve_ssubltb,                       // llvm.aarch64.sve.ssubltb (IntrinsicsAArch64.td:2580)
    aarch64_sve_ssubwb,                        // llvm.aarch64.sve.ssubwb (IntrinsicsAArch64.td:2524)
    aarch64_sve_ssubwt,                        // llvm.aarch64.sve.ssubwt (IntrinsicsAArch64.td:2525)
    aarch64_sve_st1,                           // llvm.aarch64.sve.st1 (IntrinsicsAArch64.td:1729)
    aarch64_sve_st1_pn_x2,                     // llvm.aarch64.sve.st1.pn.x2 (IntrinsicsAArch64.td:2910)
    aarch64_sve_st1_pn_x4,                     // llvm.aarch64.sve.st1.pn.x4 (IntrinsicsAArch64.td:2911)
    aarch64_sve_st1_scatter,                   // llvm.aarch64.sve.st1.scatter (IntrinsicsAArch64.td:2393)
    aarch64_sve_st1_scatter_index,             // llvm.aarch64.sve.st1.scatter.index (IntrinsicsAArch64.td:2396)
    aarch64_sve_st1_scatter_scalar_offset,     // llvm.aarch64.sve.st1.scatter.scalar.offset (IntrinsicsAArch64.td:2423)
    aarch64_sve_st1_scatter_sxtw,              // llvm.aarch64.sve.st1.scatter.sxtw (IntrinsicsAArch64.td:2400)
    aarch64_sve_st1_scatter_sxtw_index,        // llvm.aarch64.sve.st1.scatter.sxtw.index (IntrinsicsAArch64.td:2407)
    aarch64_sve_st1_scatter_uxtw,              // llvm.aarch64.sve.st1.scatter.uxtw (IntrinsicsAArch64.td:2403)
    aarch64_sve_st1_scatter_uxtw_index,        // llvm.aarch64.sve.st1.scatter.uxtw.index (IntrinsicsAArch64.td:2410)
    aarch64_sve_st1dq,                         // llvm.aarch64.sve.st1dq (IntrinsicsAArch64.td:2884)
    aarch64_sve_st1q_scatter_index,            // llvm.aarch64.sve.st1q.scatter.index (IntrinsicsAArch64.td:2414)
    aarch64_sve_st1q_scatter_scalar_offset,    // llvm.aarch64.sve.st1q.scatter.scalar.offset (IntrinsicsAArch64.td:2426)
    aarch64_sve_st1q_scatter_vector_offset,    // llvm.aarch64.sve.st1q.scatter.vector.offset (IntrinsicsAArch64.td:2417)
    aarch64_sve_st1wq,                         // llvm.aarch64.sve.st1wq (IntrinsicsAArch64.td:2883)
    aarch64_sve_st2,                           // llvm.aarch64.sve.st2 (IntrinsicsAArch64.td:1730)
    aarch64_sve_st2q,                          // llvm.aarch64.sve.st2q (IntrinsicsAArch64.td:2891)
    aarch64_sve_st3,                           // llvm.aarch64.sve.st3 (IntrinsicsAArch64.td:1731)
    aarch64_sve_st3q,                          // llvm.aarch64.sve.st3q (IntrinsicsAArch64.td:2892)
    aarch64_sve_st4,                           // llvm.aarch64.sve.st4 (IntrinsicsAArch64.td:1732)
    aarch64_sve_st4q,                          // llvm.aarch64.sve.st4q (IntrinsicsAArch64.td:2893)
    aarch64_sve_stnt1,                         // llvm.aarch64.sve.stnt1 (IntrinsicsAArch64.td:1734)
    aarch64_sve_stnt1_pn_x2,                   // llvm.aarch64.sve.stnt1.pn.x2 (IntrinsicsAArch64.td:2912)
    aarch64_sve_stnt1_pn_x4,                   // llvm.aarch64.sve.stnt1.pn.x4 (IntrinsicsAArch64.td:2913)
    aarch64_sve_stnt1_scatter,                 // llvm.aarch64.sve.stnt1.scatter (IntrinsicsAArch64.td:2433)
    aarch64_sve_stnt1_scatter_index,           // llvm.aarch64.sve.stnt1.scatter.index (IntrinsicsAArch64.td:2436)
    aarch64_sve_stnt1_scatter_scalar_offset,   // llvm.aarch64.sve.stnt1.scatter.scalar.offset (IntrinsicsAArch64.td:2446)
    aarch64_sve_stnt1_scatter_uxtw,            // llvm.aarch64.sve.stnt1.scatter.uxtw (IntrinsicsAArch64.td:2440)
    aarch64_sve_sub,                           // llvm.aarch64.sve.sub (IntrinsicsAArch64.td:1794)
    aarch64_sve_sub_u,                         // llvm.aarch64.sve.sub.u (IntrinsicsAArch64.td:1795)
    aarch64_sve_subhnb,                        // llvm.aarch64.sve.subhnb (IntrinsicsAArch64.td:2642)
    aarch64_sve_subhnt,                        // llvm.aarch64.sve.subhnt (IntrinsicsAArch64.td:2643)
    aarch64_sve_subr,                          // llvm.aarch64.sve.subr (IntrinsicsAArch64.td:1796)
    aarch64_sve_sudot_lane,                    // llvm.aarch64.sve.sudot.lane (IntrinsicsAArch64.td:2814)
    aarch64_sve_sunpk_x2,                      // llvm.aarch64.sve.sunpk.x2 (IntrinsicsAArch64.td:3921)
    aarch64_sve_sunpk_x4,                      // llvm.aarch64.sve.sunpk.x4 (IntrinsicsAArch64.td:3923)
    aarch64_sve_sunpkhi,                       // llvm.aarch64.sve.sunpkhi (IntrinsicsAArch64.td:2035)
    aarch64_sve_sunpklo,                       // llvm.aarch64.sve.sunpklo (IntrinsicsAArch64.td:2036)
    aarch64_sve_suqadd,                        // llvm.aarch64.sve.suqadd (IntrinsicsAArch64.td:2484)
    aarch64_sve_sxtb,                          // llvm.aarch64.sve.sxtb (IntrinsicsAArch64.td:2090)
    aarch64_sve_sxth,                          // llvm.aarch64.sve.sxth (IntrinsicsAArch64.td:2091)
    aarch64_sve_sxtw,                          // llvm.aarch64.sve.sxtw (IntrinsicsAArch64.td:2092)
    aarch64_sve_tbl,                           // llvm.aarch64.sve.tbl (IntrinsicsAArch64.td:2037)
    aarch64_sve_tbl2,                          // llvm.aarch64.sve.tbl2 (IntrinsicsAArch64.td:2780)
    aarch64_sve_tblq,                          // llvm.aarch64.sve.tblq (IntrinsicsAArch64.td:4014)
    aarch64_sve_tbx,                           // llvm.aarch64.sve.tbx (IntrinsicsAArch64.td:2781)
    aarch64_sve_tbxq,                          // llvm.aarch64.sve.tbxq (IntrinsicsAArch64.td:4015)
    aarch64_sve_trn1,                          // llvm.aarch64.sve.trn1 (IntrinsicsAArch64.td:2038)
    aarch64_sve_trn1_b16,                      // llvm.aarch64.sve.trn1.b16 (IntrinsicsAArch64.td:2039)
    aarch64_sve_trn1_b32,                      // llvm.aarch64.sve.trn1.b32 (IntrinsicsAArch64.td:2040)
    aarch64_sve_trn1_b64,                      // llvm.aarch64.sve.trn1.b64 (IntrinsicsAArch64.td:2041)
    aarch64_sve_trn1q,                         // llvm.aarch64.sve.trn1q (IntrinsicsAArch64.td:2046)
    aarch64_sve_trn2,                          // llvm.aarch64.sve.trn2 (IntrinsicsAArch64.td:2042)
    aarch64_sve_trn2_b16,                      // llvm.aarch64.sve.trn2.b16 (IntrinsicsAArch64.td:2043)
    aarch64_sve_trn2_b32,                      // llvm.aarch64.sve.trn2.b32 (IntrinsicsAArch64.td:2044)
    aarch64_sve_trn2_b64,                      // llvm.aarch64.sve.trn2.b64 (IntrinsicsAArch64.td:2045)
    aarch64_sve_trn2q,                         // llvm.aarch64.sve.trn2q (IntrinsicsAArch64.td:2047)
    aarch64_sve_uaba,                          // llvm.aarch64.sve.uaba (IntrinsicsAArch64.td:2485)
    aarch64_sve_uabalb,                        // llvm.aarch64.sve.uabalb (IntrinsicsAArch64.td:2526)
    aarch64_sve_uabalt,                        // llvm.aarch64.sve.uabalt (IntrinsicsAArch64.td:2527)
    aarch64_sve_uabd,                          // llvm.aarch64.sve.uabd (IntrinsicsAArch64.td:1825)
    aarch64_sve_uabd_u,                        // llvm.aarch64.sve.uabd.u (IntrinsicsAArch64.td:1826)
    aarch64_sve_uabdlb,                        // llvm.aarch64.sve.uabdlb (IntrinsicsAArch64.td:2528)
    aarch64_sve_uabdlt,                        // llvm.aarch64.sve.uabdlt (IntrinsicsAArch64.td:2529)
    aarch64_sve_uadalp,                        // llvm.aarch64.sve.uadalp (IntrinsicsAArch64.td:2561)
    aarch64_sve_uaddlb,                        // llvm.aarch64.sve.uaddlb (IntrinsicsAArch64.td:2530)
    aarch64_sve_uaddlt,                        // llvm.aarch64.sve.uaddlt (IntrinsicsAArch64.td:2531)
    aarch64_sve_uaddv,                         // llvm.aarch64.sve.uaddv (IntrinsicsAArch64.td:1838)
    aarch64_sve_uaddwb,                        // llvm.aarch64.sve.uaddwb (IntrinsicsAArch64.td:2532)
    aarch64_sve_uaddwt,                        // llvm.aarch64.sve.uaddwt (IntrinsicsAArch64.td:2533)
    aarch64_sve_uclamp,                        // llvm.aarch64.sve.uclamp (IntrinsicsAArch64.td:3163)
    aarch64_sve_uclamp_single_x2,              // llvm.aarch64.sve.uclamp.single.x2 (IntrinsicsAArch64.td:3818)
    aarch64_sve_uclamp_single_x4,              // llvm.aarch64.sve.uclamp.single.x4 (IntrinsicsAArch64.td:3823)
    aarch64_sve_ucvtf,                         // llvm.aarch64.sve.ucvtf (IntrinsicsAArch64.td:2204)
    aarch64_sve_ucvtf_f16i32,                  // llvm.aarch64.sve.ucvtf.f16i32 (IntrinsicsAArch64.td:2257)
    aarch64_sve_ucvtf_f16i64,                  // llvm.aarch64.sve.ucvtf.f16i64 (IntrinsicsAArch64.td:2258)
    aarch64_sve_ucvtf_f32i64,                  // llvm.aarch64.sve.ucvtf.f32i64 (IntrinsicsAArch64.td:2259)
    aarch64_sve_ucvtf_f64i32,                  // llvm.aarch64.sve.ucvtf.f64i32 (IntrinsicsAArch64.td:2260)
    aarch64_sve_ucvtf_x2,                      // llvm.aarch64.sve.ucvtf.x2 (IntrinsicsAArch64.td:3744)
    aarch64_sve_ucvtf_x4,                      // llvm.aarch64.sve.ucvtf.x4 (IntrinsicsAArch64.td:3748)
    aarch64_sve_udiv,                          // llvm.aarch64.sve.udiv (IntrinsicsAArch64.td:1810)
    aarch64_sve_udiv_u,                        // llvm.aarch64.sve.udiv.u (IntrinsicsAArch64.td:1811)
    aarch64_sve_udivr,                         // llvm.aarch64.sve.udivr (IntrinsicsAArch64.td:1813)
    aarch64_sve_udot,                          // llvm.aarch64.sve.udot (IntrinsicsAArch64.td:1855)
    aarch64_sve_udot_lane,                     // llvm.aarch64.sve.udot.lane (IntrinsicsAArch64.td:1856)
    aarch64_sve_udot_lane_x2,                  // llvm.aarch64.sve.udot.lane.x2 (IntrinsicsAArch64.td:3915)
    aarch64_sve_udot_x2,                       // llvm.aarch64.sve.udot.x2 (IntrinsicsAArch64.td:3912)
    aarch64_sve_uhadd,                         // llvm.aarch64.sve.uhadd (IntrinsicsAArch64.td:2486)
    aarch64_sve_uhsub,                         // llvm.aarch64.sve.uhsub (IntrinsicsAArch64.td:2487)
    aarch64_sve_uhsub_u,                       // llvm.aarch64.sve.uhsub.u (IntrinsicsAArch64.td:2488)
    aarch64_sve_uhsubr,                        // llvm.aarch64.sve.uhsubr (IntrinsicsAArch64.td:2489)
    aarch64_sve_umax,                          // llvm.aarch64.sve.umax (IntrinsicsAArch64.td:1817)
    aarch64_sve_umax_single_x2,                // llvm.aarch64.sve.umax.single.x2 (IntrinsicsAArch64.td:3670)
    aarch64_sve_umax_single_x4,                // llvm.aarch64.sve.umax.single.x4 (IntrinsicsAArch64.td:3671)
    aarch64_sve_umax_u,                        // llvm.aarch64.sve.umax.u (IntrinsicsAArch64.td:1818)
    aarch64_sve_umax_x2,                       // llvm.aarch64.sve.umax.x2 (IntrinsicsAArch64.td:3673)
    aarch64_sve_umax_x4,                       // llvm.aarch64.sve.umax.x4 (IntrinsicsAArch64.td:3674)
    aarch64_sve_umaxp,                         // llvm.aarch64.sve.umaxp (IntrinsicsAArch64.td:2553)
    aarch64_sve_umaxqv,                        // llvm.aarch64.sve.umaxqv (IntrinsicsAArch64.td:1868)
    aarch64_sve_umaxv,                         // llvm.aarch64.sve.umaxv (IntrinsicsAArch64.td:1841)
    aarch64_sve_umin,                          // llvm.aarch64.sve.umin (IntrinsicsAArch64.td:1821)
    aarch64_sve_umin_single_x2,                // llvm.aarch64.sve.umin.single.x2 (IntrinsicsAArch64.td:3670)
    aarch64_sve_umin_single_x4,                // llvm.aarch64.sve.umin.single.x4 (IntrinsicsAArch64.td:3671)
    aarch64_sve_umin_u,                        // llvm.aarch64.sve.umin.u (IntrinsicsAArch64.td:1822)
    aarch64_sve_umin_x2,                       // llvm.aarch64.sve.umin.x2 (IntrinsicsAArch64.td:3673)
    aarch64_sve_umin_x4,                       // llvm.aarch64.sve.umin.x4 (IntrinsicsAArch64.td:3674)
    aarch64_sve_uminp,                         // llvm.aarch64.sve.uminp (IntrinsicsAArch64.td:2554)
    aarch64_sve_uminqv,                        // llvm.aarch64.sve.uminqv (IntrinsicsAArch64.td:1870)
    aarch64_sve_uminv,                         // llvm.aarch64.sve.uminv (IntrinsicsAArch64.td:1843)
    aarch64_sve_umlalb,                        // llvm.aarch64.sve.umlalb (IntrinsicsAArch64.td:2699)
    aarch64_sve_umlalb_lane,                   // llvm.aarch64.sve.umlalb.lane (IntrinsicsAArch64.td:2679)
    aarch64_sve_umlalt,                        // llvm.aarch64.sve.umlalt (IntrinsicsAArch64.td:2700)
    aarch64_sve_umlalt_lane,                   // llvm.aarch64.sve.umlalt.lane (IntrinsicsAArch64.td:2680)
    aarch64_sve_umlslb,                        // llvm.aarch64.sve.umlslb (IntrinsicsAArch64.td:2703)
    aarch64_sve_umlslb_lane,                   // llvm.aarch64.sve.umlslb.lane (IntrinsicsAArch64.td:2683)
    aarch64_sve_umlslt,                        // llvm.aarch64.sve.umlslt (IntrinsicsAArch64.td:2704)
    aarch64_sve_umlslt_lane,                   // llvm.aarch64.sve.umlslt.lane (IntrinsicsAArch64.td:2684)
    aarch64_sve_ummla,                         // llvm.aarch64.sve.ummla (IntrinsicsAArch64.td:2808)
    aarch64_sve_umulh,                         // llvm.aarch64.sve.umulh (IntrinsicsAArch64.td:1805)
    aarch64_sve_umulh_u,                       // llvm.aarch64.sve.umulh.u (IntrinsicsAArch64.td:1806)
    aarch64_sve_umullb,                        // llvm.aarch64.sve.umullb (IntrinsicsAArch64.td:2707)
    aarch64_sve_umullb_lane,                   // llvm.aarch64.sve.umullb.lane (IntrinsicsAArch64.td:2687)
    aarch64_sve_umullt,                        // llvm.aarch64.sve.umullt (IntrinsicsAArch64.td:2708)
    aarch64_sve_umullt_lane,                   // llvm.aarch64.sve.umullt.lane (IntrinsicsAArch64.td:2688)
    aarch64_sve_uqadd,                         // llvm.aarch64.sve.uqadd (IntrinsicsAArch64.td:2490)
    aarch64_sve_uqadd_x,                       // llvm.aarch64.sve.uqadd.x (IntrinsicsAArch64.td:1860)
    aarch64_sve_uqcvt_x2,                      // llvm.aarch64.sve.uqcvt.x2 (IntrinsicsAArch64.td:3754)
    aarch64_sve_uqcvt_x4,                      // llvm.aarch64.sve.uqcvt.x4 (IntrinsicsAArch64.td:3757)
    aarch64_sve_uqcvtn_x2,                     // llvm.aarch64.sve.uqcvtn.x2 (IntrinsicsAArch64.td:3764)
    aarch64_sve_uqcvtn_x4,                     // llvm.aarch64.sve.uqcvtn.x4 (IntrinsicsAArch64.td:3767)
    aarch64_sve_uqdecb_n32,                    // llvm.aarch64.sve.uqdecb.n32 (IntrinsicsAArch64.td:1979)
    aarch64_sve_uqdecb_n64,                    // llvm.aarch64.sve.uqdecb.n64 (IntrinsicsAArch64.td:1980)
    aarch64_sve_uqdecd,                        // llvm.aarch64.sve.uqdecd (IntrinsicsAArch64.td:1976)
    aarch64_sve_uqdecd_n32,                    // llvm.aarch64.sve.uqdecd.n32 (IntrinsicsAArch64.td:1985)
    aarch64_sve_uqdecd_n64,                    // llvm.aarch64.sve.uqdecd.n64 (IntrinsicsAArch64.td:1986)
    aarch64_sve_uqdech,                        // llvm.aarch64.sve.uqdech (IntrinsicsAArch64.td:1974)
    aarch64_sve_uqdech_n32,                    // llvm.aarch64.sve.uqdech.n32 (IntrinsicsAArch64.td:1981)
    aarch64_sve_uqdech_n64,                    // llvm.aarch64.sve.uqdech.n64 (IntrinsicsAArch64.td:1982)
    aarch64_sve_uqdecp,                        // llvm.aarch64.sve.uqdecp (IntrinsicsAArch64.td:1977)
    aarch64_sve_uqdecp_n32,                    // llvm.aarch64.sve.uqdecp.n32 (IntrinsicsAArch64.td:1987)
    aarch64_sve_uqdecp_n64,                    // llvm.aarch64.sve.uqdecp.n64 (IntrinsicsAArch64.td:1988)
    aarch64_sve_uqdecw,                        // llvm.aarch64.sve.uqdecw (IntrinsicsAArch64.td:1975)
    aarch64_sve_uqdecw_n32,                    // llvm.aarch64.sve.uqdecw.n32 (IntrinsicsAArch64.td:1983)
    aarch64_sve_uqdecw_n64,                    // llvm.aarch64.sve.uqdecw.n64 (IntrinsicsAArch64.td:1984)
    aarch64_sve_uqincb_n32,                    // llvm.aarch64.sve.uqincb.n32 (IntrinsicsAArch64.td:1995)
    aarch64_sve_uqincb_n64,                    // llvm.aarch64.sve.uqincb.n64 (IntrinsicsAArch64.td:1996)
    aarch64_sve_uqincd,                        // llvm.aarch64.sve.uqincd (IntrinsicsAArch64.td:1992)
    aarch64_sve_uqincd_n32,                    // llvm.aarch64.sve.uqincd.n32 (IntrinsicsAArch64.td:2001)
    aarch64_sve_uqincd_n64,                    // llvm.aarch64.sve.uqincd.n64 (IntrinsicsAArch64.td:2002)
    aarch64_sve_uqinch,                        // llvm.aarch64.sve.uqinch (IntrinsicsAArch64.td:1990)
    aarch64_sve_uqinch_n32,                    // llvm.aarch64.sve.uqinch.n32 (IntrinsicsAArch64.td:1997)
    aarch64_sve_uqinch_n64,                    // llvm.aarch64.sve.uqinch.n64 (IntrinsicsAArch64.td:1998)
    aarch64_sve_uqincp,                        // llvm.aarch64.sve.uqincp (IntrinsicsAArch64.td:1993)
    aarch64_sve_uqincp_n32,                    // llvm.aarch64.sve.uqincp.n32 (IntrinsicsAArch64.td:2003)
    aarch64_sve_uqincp_n64,                    // llvm.aarch64.sve.uqincp.n64 (IntrinsicsAArch64.td:2004)
    aarch64_sve_uqincw,                        // llvm.aarch64.sve.uqincw (IntrinsicsAArch64.td:1991)
    aarch64_sve_uqincw_n32,                    // llvm.aarch64.sve.uqincw.n32 (IntrinsicsAArch64.td:1999)
    aarch64_sve_uqincw_n64,                    // llvm.aarch64.sve.uqincw.n64 (IntrinsicsAArch64.td:2000)
    aarch64_sve_uqrshl,                        // llvm.aarch64.sve.uqrshl (IntrinsicsAArch64.td:2491)
    aarch64_sve_uqrshl_u,                      // llvm.aarch64.sve.uqrshl.u (IntrinsicsAArch64.td:2492)
    aarch64_sve_uqrshr_x2,                     // llvm.aarch64.sve.uqrshr.x2 (IntrinsicsAArch64.td:3566)
    aarch64_sve_uqrshr_x4,                     // llvm.aarch64.sve.uqrshr.x4 (IntrinsicsAArch64.td:3568)
    aarch64_sve_uqrshrn_x2,                    // llvm.aarch64.sve.uqrshrn.x2 (IntrinsicsAArch64.td:3571)
    aarch64_sve_uqrshrn_x4,                    // llvm.aarch64.sve.uqrshrn.x4 (IntrinsicsAArch64.td:3573)
    aarch64_sve_uqrshrnb,                      // llvm.aarch64.sve.uqrshrnb (IntrinsicsAArch64.td:2666)
    aarch64_sve_uqrshrnt,                      // llvm.aarch64.sve.uqrshrnt (IntrinsicsAArch64.td:2667)
    aarch64_sve_uqshl,                         // llvm.aarch64.sve.uqshl (IntrinsicsAArch64.td:2493)
    aarch64_sve_uqshl_u,                       // llvm.aarch64.sve.uqshl.u (IntrinsicsAArch64.td:2494)
    aarch64_sve_uqshrnb,                       // llvm.aarch64.sve.uqshrnb (IntrinsicsAArch64.td:2663)
    aarch64_sve_uqshrnt,                       // llvm.aarch64.sve.uqshrnt (IntrinsicsAArch64.td:2664)
    aarch64_sve_uqsub,                         // llvm.aarch64.sve.uqsub (IntrinsicsAArch64.td:2495)
    aarch64_sve_uqsub_u,                       // llvm.aarch64.sve.uqsub.u (IntrinsicsAArch64.td:2496)
    aarch64_sve_uqsub_x,                       // llvm.aarch64.sve.uqsub.x (IntrinsicsAArch64.td:1861)
    aarch64_sve_uqsubr,                        // llvm.aarch64.sve.uqsubr (IntrinsicsAArch64.td:2497)
    aarch64_sve_uqxtnb,                        // llvm.aarch64.sve.uqxtnb (IntrinsicsAArch64.td:2630)
    aarch64_sve_uqxtnt,                        // llvm.aarch64.sve.uqxtnt (IntrinsicsAArch64.td:2631)
    aarch64_sve_urecpe,                        // llvm.aarch64.sve.urecpe (IntrinsicsAArch64.td:2498)
    aarch64_sve_urhadd,                        // llvm.aarch64.sve.urhadd (IntrinsicsAArch64.td:2499)
    aarch64_sve_urshl,                         // llvm.aarch64.sve.urshl (IntrinsicsAArch64.td:2500)
    aarch64_sve_urshl_single_x2,               // llvm.aarch64.sve.urshl.single.x2 (IntrinsicsAArch64.td:3554)
    aarch64_sve_urshl_single_x4,               // llvm.aarch64.sve.urshl.single.x4 (IntrinsicsAArch64.td:3556)
    aarch64_sve_urshl_u,                       // llvm.aarch64.sve.urshl.u (IntrinsicsAArch64.td:2501)
    aarch64_sve_urshl_x2,                      // llvm.aarch64.sve.urshl.x2 (IntrinsicsAArch64.td:3559)
    aarch64_sve_urshl_x4,                      // llvm.aarch64.sve.urshl.x4 (IntrinsicsAArch64.td:3561)
    aarch64_sve_urshr,                         // llvm.aarch64.sve.urshr (IntrinsicsAArch64.td:2502)
    aarch64_sve_ursqrte,                       // llvm.aarch64.sve.ursqrte (IntrinsicsAArch64.td:2503)
    aarch64_sve_ursra,                         // llvm.aarch64.sve.ursra (IntrinsicsAArch64.td:2504)
    aarch64_sve_usdot,                         // llvm.aarch64.sve.usdot (IntrinsicsAArch64.td:2812)
    aarch64_sve_usdot_lane,                    // llvm.aarch64.sve.usdot.lane (IntrinsicsAArch64.td:2813)
    aarch64_sve_ushllb,                        // llvm.aarch64.sve.ushllb (IntrinsicsAArch64.td:2534)
    aarch64_sve_ushllt,                        // llvm.aarch64.sve.ushllt (IntrinsicsAArch64.td:2535)
    aarch64_sve_usmmla,                        // llvm.aarch64.sve.usmmla (IntrinsicsAArch64.td:2810)
    aarch64_sve_usqadd,                        // llvm.aarch64.sve.usqadd (IntrinsicsAArch64.td:2505)
    aarch64_sve_usra,                          // llvm.aarch64.sve.usra (IntrinsicsAArch64.td:2506)
    aarch64_sve_usublb,                        // llvm.aarch64.sve.usublb (IntrinsicsAArch64.td:2536)
    aarch64_sve_usublt,                        // llvm.aarch64.sve.usublt (IntrinsicsAArch64.td:2537)
    aarch64_sve_usubwb,                        // llvm.aarch64.sve.usubwb (IntrinsicsAArch64.td:2538)
    aarch64_sve_usubwt,                        // llvm.aarch64.sve.usubwt (IntrinsicsAArch64.td:2539)
    aarch64_sve_uunpk_x2,                      // llvm.aarch64.sve.uunpk.x2 (IntrinsicsAArch64.td:3922)
    aarch64_sve_uunpk_x4,                      // llvm.aarch64.sve.uunpk.x4 (IntrinsicsAArch64.td:3924)
    aarch64_sve_uunpkhi,                       // llvm.aarch64.sve.uunpkhi (IntrinsicsAArch64.td:2048)
    aarch64_sve_uunpklo,                       // llvm.aarch64.sve.uunpklo (IntrinsicsAArch64.td:2049)
    aarch64_sve_uxtb,                          // llvm.aarch64.sve.uxtb (IntrinsicsAArch64.td:2093)
    aarch64_sve_uxth,                          // llvm.aarch64.sve.uxth (IntrinsicsAArch64.td:2094)
    aarch64_sve_uxtw,                          // llvm.aarch64.sve.uxtw (IntrinsicsAArch64.td:2095)
    aarch64_sve_uzp_x2,                        // llvm.aarch64.sve.uzp.x2 (IntrinsicsAArch64.td:3905)
    aarch64_sve_uzp_x4,                        // llvm.aarch64.sve.uzp.x4 (IntrinsicsAArch64.td:3907)
    aarch64_sve_uzp1,                          // llvm.aarch64.sve.uzp1 (IntrinsicsAArch64.td:2050)
    aarch64_sve_uzp1_b16,                      // llvm.aarch64.sve.uzp1.b16 (IntrinsicsAArch64.td:2051)
    aarch64_sve_uzp1_b32,                      // llvm.aarch64.sve.uzp1.b32 (IntrinsicsAArch64.td:2052)
    aarch64_sve_uzp1_b64,                      // llvm.aarch64.sve.uzp1.b64 (IntrinsicsAArch64.td:2053)
    aarch64_sve_uzp1q,                         // llvm.aarch64.sve.uzp1q (IntrinsicsAArch64.td:2058)
    aarch64_sve_uzp2,                          // llvm.aarch64.sve.uzp2 (IntrinsicsAArch64.td:2054)
    aarch64_sve_uzp2_b16,                      // llvm.aarch64.sve.uzp2.b16 (IntrinsicsAArch64.td:2055)
    aarch64_sve_uzp2_b32,                      // llvm.aarch64.sve.uzp2.b32 (IntrinsicsAArch64.td:2056)
    aarch64_sve_uzp2_b64,                      // llvm.aarch64.sve.uzp2.b64 (IntrinsicsAArch64.td:2057)
    aarch64_sve_uzp2q,                         // llvm.aarch64.sve.uzp2q (IntrinsicsAArch64.td:2059)
    aarch64_sve_uzpq_x2,                       // llvm.aarch64.sve.uzpq.x2 (IntrinsicsAArch64.td:3906)
    aarch64_sve_uzpq_x4,                       // llvm.aarch64.sve.uzpq.x4 (IntrinsicsAArch64.td:3908)
    aarch64_sve_uzpq1,                         // llvm.aarch64.sve.uzpq1 (IntrinsicsAArch64.td:4008)
    aarch64_sve_uzpq2,                         // llvm.aarch64.sve.uzpq2 (IntrinsicsAArch64.td:4009)
    aarch64_sve_whilege,                       // llvm.aarch64.sve.whilege (IntrinsicsAArch64.td:2105)
    aarch64_sve_whilege_c16,                   // llvm.aarch64.sve.whilege.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilege_c32,                   // llvm.aarch64.sve.whilege.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilege_c64,                   // llvm.aarch64.sve.whilege.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilege_c8,                    // llvm.aarch64.sve.whilege.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilege_x2,                    // llvm.aarch64.sve.whilege.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilegt,                       // llvm.aarch64.sve.whilegt (IntrinsicsAArch64.td:2106)
    aarch64_sve_whilegt_c16,                   // llvm.aarch64.sve.whilegt.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilegt_c32,                   // llvm.aarch64.sve.whilegt.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilegt_c64,                   // llvm.aarch64.sve.whilegt.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilegt_c8,                    // llvm.aarch64.sve.whilegt.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilegt_x2,                    // llvm.aarch64.sve.whilegt.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilehi,                       // llvm.aarch64.sve.whilehi (IntrinsicsAArch64.td:2108)
    aarch64_sve_whilehi_c16,                   // llvm.aarch64.sve.whilehi.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehi_c32,                   // llvm.aarch64.sve.whilehi.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehi_c64,                   // llvm.aarch64.sve.whilehi.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehi_c8,                    // llvm.aarch64.sve.whilehi.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehi_x2,                    // llvm.aarch64.sve.whilehi.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilehs,                       // llvm.aarch64.sve.whilehs (IntrinsicsAArch64.td:2107)
    aarch64_sve_whilehs_c16,                   // llvm.aarch64.sve.whilehs.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehs_c32,                   // llvm.aarch64.sve.whilehs.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehs_c64,                   // llvm.aarch64.sve.whilehs.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehs_c8,                    // llvm.aarch64.sve.whilehs.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilehs_x2,                    // llvm.aarch64.sve.whilehs.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilele,                       // llvm.aarch64.sve.whilele (IntrinsicsAArch64.td:2101)
    aarch64_sve_whilele_c16,                   // llvm.aarch64.sve.whilele.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilele_c32,                   // llvm.aarch64.sve.whilele.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilele_c64,                   // llvm.aarch64.sve.whilele.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilele_c8,                    // llvm.aarch64.sve.whilele.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilele_x2,                    // llvm.aarch64.sve.whilele.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilelo,                       // llvm.aarch64.sve.whilelo (IntrinsicsAArch64.td:2102)
    aarch64_sve_whilelo_c16,                   // llvm.aarch64.sve.whilelo.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelo_c32,                   // llvm.aarch64.sve.whilelo.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelo_c64,                   // llvm.aarch64.sve.whilelo.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelo_c8,                    // llvm.aarch64.sve.whilelo.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelo_x2,                    // llvm.aarch64.sve.whilelo.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilels,                       // llvm.aarch64.sve.whilels (IntrinsicsAArch64.td:2103)
    aarch64_sve_whilels_c16,                   // llvm.aarch64.sve.whilels.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilels_c32,                   // llvm.aarch64.sve.whilels.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilels_c64,                   // llvm.aarch64.sve.whilels.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilels_c8,                    // llvm.aarch64.sve.whilels.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilels_x2,                    // llvm.aarch64.sve.whilels.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilelt,                       // llvm.aarch64.sve.whilelt (IntrinsicsAArch64.td:2104)
    aarch64_sve_whilelt_c16,                   // llvm.aarch64.sve.whilelt.c16 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelt_c32,                   // llvm.aarch64.sve.whilelt.c32 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelt_c64,                   // llvm.aarch64.sve.whilelt.c64 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelt_c8,                    // llvm.aarch64.sve.whilelt.c8 (IntrinsicsAArch64.td:3231)
    aarch64_sve_whilelt_x2,                    // llvm.aarch64.sve.whilelt.x2 (IntrinsicsAArch64.td:3187)
    aarch64_sve_whilerw_b,                     // llvm.aarch64.sve.whilerw.b (IntrinsicsAArch64.td:2920)
    aarch64_sve_whilerw_d,                     // llvm.aarch64.sve.whilerw.d (IntrinsicsAArch64.td:2923)
    aarch64_sve_whilerw_h,                     // llvm.aarch64.sve.whilerw.h (IntrinsicsAArch64.td:2921)
    aarch64_sve_whilerw_s,                     // llvm.aarch64.sve.whilerw.s (IntrinsicsAArch64.td:2922)
    aarch64_sve_whilewr_b,                     // llvm.aarch64.sve.whilewr.b (IntrinsicsAArch64.td:2924)
    aarch64_sve_whilewr_d,                     // llvm.aarch64.sve.whilewr.d (IntrinsicsAArch64.td:2927)
    aarch64_sve_whilewr_h,                     // llvm.aarch64.sve.whilewr.h (IntrinsicsAArch64.td:2925)
    aarch64_sve_whilewr_s,                     // llvm.aarch64.sve.whilewr.s (IntrinsicsAArch64.td:2926)
    aarch64_sve_wrffr,                         // llvm.aarch64.sve.wrffr (IntrinsicsAArch64.td:1936)
    aarch64_sve_xar,                           // llvm.aarch64.sve.xar (IntrinsicsAArch64.td:2742)
    aarch64_sve_zip_x2,                        // llvm.aarch64.sve.zip.x2 (IntrinsicsAArch64.td:3901)
    aarch64_sve_zip_x4,                        // llvm.aarch64.sve.zip.x4 (IntrinsicsAArch64.td:3903)
    aarch64_sve_zip1,                          // llvm.aarch64.sve.zip1 (IntrinsicsAArch64.td:2060)
    aarch64_sve_zip1_b16,                      // llvm.aarch64.sve.zip1.b16 (IntrinsicsAArch64.td:2061)
    aarch64_sve_zip1_b32,                      // llvm.aarch64.sve.zip1.b32 (IntrinsicsAArch64.td:2062)
    aarch64_sve_zip1_b64,                      // llvm.aarch64.sve.zip1.b64 (IntrinsicsAArch64.td:2063)
    aarch64_sve_zip1q,                         // llvm.aarch64.sve.zip1q (IntrinsicsAArch64.td:2068)
    aarch64_sve_zip2,                          // llvm.aarch64.sve.zip2 (IntrinsicsAArch64.td:2064)
    aarch64_sve_zip2_b16,                      // llvm.aarch64.sve.zip2.b16 (IntrinsicsAArch64.td:2065)
    aarch64_sve_zip2_b32,                      // llvm.aarch64.sve.zip2.b32 (IntrinsicsAArch64.td:2066)
    aarch64_sve_zip2_b64,                      // llvm.aarch64.sve.zip2.b64 (IntrinsicsAArch64.td:2067)
    aarch64_sve_zip2q,                         // llvm.aarch64.sve.zip2q (IntrinsicsAArch64.td:2069)
    aarch64_sve_zipq_x2,                       // llvm.aarch64.sve.zipq.x2 (IntrinsicsAArch64.td:3902)
    aarch64_sve_zipq_x4,                       // llvm.aarch64.sve.zipq.x4 (IntrinsicsAArch64.td:3904)
    aarch64_sve_zipq1,                         // llvm.aarch64.sve.zipq1 (IntrinsicsAArch64.td:4006)
    aarch64_sve_zipq2,                         // llvm.aarch64.sve.zipq2 (IntrinsicsAArch64.td:4007)
    aarch64_tagp,                              // llvm.aarch64.tagp (IntrinsicsAArch64.td:926)
    aarch64_udiv,                              // llvm.aarch64.udiv (IntrinsicsAArch64.td:39)
}; // enum
} // namespace llvm::Intrinsic
#endif

